#include <inttypes.h>
#include <glcd/glcd.h>
#include <glcd/lfsr.h>
#include <font/nums.h>
#include <font/f9x14.h>
#include <font/f15x22.h>
#include <font/f8x11.h>

// four different lines
void testLines(uint8_t iteration) {

    for (uint8_t i = 0; i < iteration; i++) {
      glcdClearScreen(0);                          // clear only on in clipping rect
      glcdSetColor(0, SCREEN_COLOR);
      glcdSetColor(1, BLACK);
      glcdSetColor(2, GOLD);
      glcdSetColor(3, RED);
      for (glcdCoord_t x = SCREEN_LEFT; x <= SCREEN_RIGHT; x++) {
        glcdSetFgColor(YELLOW);
        glcdLine(x, SCREEN_TOP, x, SCREEN_BOTTOM);
        glcdSetFgColor(GREEN);
        glcdLine(SCREEN_RIGHT - x, SCREEN_TOP, SCREEN_RIGHT - x, SCREEN_BOTTOM);
        glcdSetFgColor(BLUE);
        glcdLine(SCREEN_LEFT, SCREEN_TOP, x, SCREEN_BOTTOM);
        glcdSetFgColor(RED);
        glcdLine(SCREEN_RIGHT, SCREEN_BOTTOM, SCREEN_RIGHT - x + SCREEN_LEFT, SCREEN_TOP);
      }
    }
}


// 255 random lines
void testLines2(uint8_t iteration) {

    for (uint8_t i = 0; i < iteration; i++) {
      glcdClearScreen(0);
      for (uint8_t j = 0; j < 255; j++) {
        glcdSetFgColor(lfsr(16));
        glcdLine(lfsr(7) +2, lfsr(7) +2, lfsr(7) +2, lfsr(7) +2);
      }
    }
}

// animated ellipse shape
void testEllipses(uint8_t iteration) {

   glcdColor_t c[7];

   c[0] = YELLOW;
   c[1] = RED;
   c[2] = BLUE;
   c[3] = GREEN;
   c[4] = YELLOW;
   c[5] = RED;
   c[6] = BLUE;

   int8_t i, j = 0, count, k = 1, d = 1;

   for (; iteration > 0; iteration--) {
     glcdSetBkColor(NONE);
     for (count = 0; count < 3; count++) {
       for (i = 67; i > 0; i -= k) {
         glcdSetFgColor(c[j]);
         glcdSetFgColor(c[j +1]);
         glcdEllipse(65, 65, i, 67 - i);
         glcdSetFgColor(c[j +2]);
         glcdEllipse(65, 65, 67 - i, i);
       }
       if (++j >= 4) {j = 0;}
     }
     for (count = 0; count < 3; count++) {
       for (i = 67; i > 0; i -= k) {
         glcdSetFgColor(c[j]);
         glcdSetBkColor(c[j +1]);
         glcdEllipse(65, 65, i, 67 - i);
         glcdSetBkColor(c[j +2]);
         glcdEllipse(65, 65, 67 - i, i);
       }
       if (++j >= 4) {j = 0;}
     }
     k += d;
     if ((k > 5) | (k == 1)) {d = -d;}
   }
}

// random ellipses and circles with random border-/filling color
void testEllipses2(uint8_t iteration) {

    for (; iteration > 0; iteration--) {
      glcdClearScreen(0);
      for (uint8_t i = 0; i < 255; i++) {
        glcdSetColors(lfsr(16), lfsr(16));
        glcdEllipse(lfsr(7) +3, lfsr(7) +lfsr(5)+lfsr(4), lfsr(6), lfsr(6));
      }
    }
}

// random rectangles with random border-/filling color
void testRects(uint8_t iteration) {

    for (; iteration > 0; iteration--) {
      glcdClearScreen(0);
      for (uint8_t i = 0; i < 255; i++) {
        glcdSetColors(lfsr(16), lfsr(16));
        glcdRectangle(lfsr(7) +3, lfsr(7) +3, 
                  lfsr(7) +3, lfsr(7)+lfsr(5)+lfsr(4));
      }
    }
}

// Rotate a rectangle form source orientation to dest orientation such that
// the rectangle is on display always on same location. Please remember the orientation
// of the display in this library is not relative and thus the clipping rect is relative
// to the current orientation set. This simplify normaly the work with different orientations
// on same code. Means the same source with painting can be directly used with different orientations
// without any changes on coordinates. But for this demonstration we have to take care about this,
// because we want always printing on same display locations with different orientations.
// Follow function is'nt included directly in the library, but could be sometimes important to know.

void glcdRotateRect(glcdRect_t *rect, uint8_t source, uint8_t dest) {

    if ((source & 3) != (dest & 3)) {

      glcdCoord_t x1=0, x2=0, y1=0, y2=0;

      switch (source & 3) {
        case 0: {
          x1 = (*rect).X1;
          y1 = (*rect).Y1;
          x2 = (*rect).X2;
          y2 = (*rect).Y2;
          break;
        }
        case 1: {
          x1 = 175 - (*rect).Y2;
          x2 = 175 - (*rect).Y1;
          y1 = (*rect).X1;
          y2 = (*rect).X2;
          break;
        }
        case 2: {
          x1 = 131 - (*rect).X2;
          x2 = 131 - (*rect).X1;
          y1 = (*rect).Y2 - 1;
          y2 = (*rect).Y1 - 1;
          break;
        }
        case 3: {
          x1 = (*rect).Y1;
          x2 = (*rect).Y2;
          y1 = 131 - (*rect).X2;
          y2 = 131 - (*rect).X1;
          break;
        }
      }

      switch (dest & 3) {
        case 0: {
          (*rect).X1 = x1;
          (*rect).Y1 = y1;
          (*rect).X2 = x2;
          (*rect).Y2 = y2;
          break;
        }
        case 1: {
          (*rect).X1 = y1;
          (*rect).X2 = y2;
          (*rect).Y1 = 131 - x2;
          (*rect).Y2 = 131 - x1;
          break;
        }
        case 2: {
          (*rect).X1 = 131 - x2;
          (*rect).X2 = 131 - x1;
          (*rect).Y1 = y2 + 1;
          (*rect).Y2 = y1 + 1;
          break;
        }
        case 3: {
          (*rect).X1 = 175 - y2;
          (*rect).X2 = 175 - y1;
          (*rect).Y1 = x1;
          (*rect).Y2 = x2;
          break;
        }
      }
    }
}

void glcdNewOrientation(uint8_t orientation) {

    glcdRotateRect(&glcd_Clip, glcd_MemCtrl, orientation);
    glcdSetOrientation(orientation);
}

// display random 4 color font symbols with tranparancy and random rotated by 0,90,180 or 270 degree
void testSymbols(uint8_t iteration) {

    uint8_t mem = glcd_MemCtrl;     // save glcd_MemCtrl, thus orientation in 2 LSB's

    glcd_Flags.AutoLineFeed = 0;

    glcdSelectFont(nums, 0);        // font is stored in FLASH, thus no need for own read callback
    glcdSetBkColor(NONE);
    for (; iteration > 0; iteration--) {
      glcdClearScreen(0);
      for (uint8_t i = 0; i < 255; i++) {
        glcdNewOrientation(lfsr(2));
        glcdSetColor(1, lfsr(16));
        glcdSetColor(2, lfsr(16));
        glcdSetColor(3, lfsr(16));
        glcdMoveTo(lfsr(7), lfsr(7)+lfsr(5)+lfsr(4));
        glcdDrawChar(lfsr(4) % 11 + 32);
      }
    }
    glcdNewOrientation(mem);
}



// print text centered horizontal and vertical into bounds r
// demontrate the use of glcdCharsWidth()
void glcdPrintCenter(glcdRect_t r, char *text, uint8_t InFlashStored) {

    r.X1 += (r.X2 - r.X1 - glcdCharsWidth(text, InFlashStored)) / 2;
    r.Y1 += (r.Y2 - r.Y1 - glcd_FontHeight) / 2;
    glcdMoveTo(r.X1, r.Y1);
    glcdPrint(text, InFlashStored);
}


// demontrate own font read callback
uint8_t myRead(glcdFontData_t index) {

    return(pgm_read_byte(f9x14 + index));
}


void demoScreen_2(void)
{
   glcdRect_t r;
   
   #define LT 5  // frame line thickness
   #define HT 50 // inner height of the frame

   // write Text into the frame
   glcdSetFgColor(WHITE);
   glcdSetFrColor(BLUE);
   glcdSetBkColor(BLUE);

   glcdSetRect(r, 15, 15, SCREEN_WIDTH-15, 15+18);
   glcdMoveTo(r.X1 + 2, r.Y1 + 2);
   glcdSelectFont(f15x22, 0);           // font is stored in FLASH, demontrate read callback
   glcdPrintCenter(r, PSTR("MegaEIB"), 1);


}

void demoScreen(void)
{
   glcdRect_t r;
   
  //
  // draw a frame
  //
   #define LT 5  // frame line thickness
   #define HT 50 // inner height of the frame
   // inner area of the frame
   glcdSetRect(r, 15, 15, SCREEN_WIDTH-15, 15+HT);

   // frame colors
   glcdSetFgColor(RGB(0x00, 0x80, 0x00));
   glcdSetFrColor(RGB(0x00, 0x80, 0x00));
   glcdSetBkColor(RGB(0x00, 0x80, 0x00));
   
   glcdRectangle(r.X1-LT, r.Y1-LT, r.X2+LT, r.Y1);
   glcdRectangle(r.X1-LT, r.Y1,    r.X1,    r.Y2);
   glcdRectangle(r.X1-LT, r.Y2,    r.X2+LT, r.Y2+LT);
   glcdRectangle(r.X2, r.Y1,       r.X2+LT, r.Y2+LT);


// fill inner frame
//   glcdSetBkColor(BLUE);
//   glcdRectangle(r.X1, r.Y1, r.X2, r.Y2);


   // write Text into the frame
   glcdSetFgColor(BLUE);
   glcdSetFrColor(BLUE);
   glcdSetBkColor(SCREEN_COLOR);

   glcdSetRect(r, 15, 15, SCREEN_WIDTH-15, 15+18);
   glcdMoveTo(r.X1 + 2, r.Y1 + 2);
   glcdSelectFont(f9x14, 0);           // font is stored in FLASH, demontrate read callback
   glcdPrintCenter(r, PSTR("glcd for"), 1);

   glcdSetFgColor(RGB(0xFF, 0x00, 0x00));
   glcdSetFrColor(RGB(0x00, 0x10, 0xFF));
   glcdSetBkColor(SCREEN_COLOR);

   glcdSetRect(r, 15, 15+18, SCREEN_WIDTH-15, 15+HT);
   glcdMoveTo(r.X1 + 2, r.Y1 + 2);
   glcdSelectFont(f15x22, 0);           // font is stored in FLASH, demontrate read callback
   glcdPrintCenter(r, PSTR("MegaEIB"), 1);


  // draw note sheet
  #define TOP 90
  #define GRID 8
  
  glcdSetColors(BLACK, NONE);
  
  glcdLine(30, TOP, SCREEN_WIDTH-30, TOP);
  glcdLine(30, TOP+1*GRID, SCREEN_WIDTH-30, TOP+1*GRID);
  glcdLine(30, TOP+2*GRID, SCREEN_WIDTH-30, TOP+2*GRID);
  glcdLine(30, TOP+3*GRID, SCREEN_WIDTH-30, TOP+3*GRID);
  glcdLine(30, TOP+4*GRID, SCREEN_WIDTH-30, TOP+4*GRID);

  glcdSetColors(BLACK, BLACK);
  // tone C
  glcdEllipse(40, TOP+5*GRID, GRID/2+1, GRID/2-1);   // ellipse at x,y with radius a,b
  glcdLine(40-GRID/2-4, TOP+5*GRID, 40+GRID/2+4, TOP+5*GRID);
  glcdLine(40+GRID/2+1, TOP+5*GRID, 40+GRID/2+1, TOP+5*GRID-4*GRID); 
  // tone E
  glcdEllipse(55, TOP+4*GRID, GRID/2+1, GRID/2-1);   // ellipse at x,y with radius a,b
  glcdLine(55+GRID/2+1, TOP+4*GRID, 55+GRID/2+1, TOP+4*GRID-4*GRID); 
  // tone G
  glcdEllipse(70, TOP+3*GRID, GRID/2+1, GRID/2-1);   // ellipse at x,y with radius a,b
  glcdLine(70+GRID/2+1, TOP+3*GRID, 70+GRID/2+1, TOP+3*GRID-4*GRID); 
  // dur cEGC
  glcdSetColors(RGB(0x80,0,0), RGB(0x80,0,0));
  glcdEllipse(85, TOP+1*GRID+GRID/2, GRID/2+1, GRID/2-1);   // ellipse at x,y with radius a,b
  glcdLine(85-GRID/2-1, TOP+1*GRID+GRID/2, 85-GRID/2-1, TOP+1*GRID+GRID/2+4*GRID); 

  glcdEllipse(85, TOP+3*GRID+0*GRID/2, GRID/2+1, GRID/2-1);   // ellipse at x,y with radius a,b
  glcdEllipse(85, TOP+4*GRID+0*GRID/2, GRID/2+1, GRID/2-1);   // ellipse at x,y with radius a,b
  glcdEllipse(85, TOP+5*GRID+0*GRID/2, GRID/2+1, GRID/2-1);   // ellipse at x,y with radius a,b
  glcdLine(85-GRID/2-4, TOP+5*GRID, 85+GRID/2+4, TOP+5*GRID);




   glcdSetColors(BLACK, NONE);
   glcdSetRect(r, 15, 145, SCREEN_WIDTH-15, 145+20);
   glcdMoveTo(r.X1 + 2, r.Y1 + 2);
   glcdSelectFont(f9x14, 0);           // font is stored in FLASH, demontrate read callback
   glcdPrintCenter(r, PSTR("by Christian Kranz"), 1);


   glcdSetColors(BLACK, NONE);
   glcdSetRect(r, 15, 158, SCREEN_WIDTH-15, 158+20);
   glcdMoveTo(r.X1 + 2, r.Y1 + 2);
   glcdSelectFont(f8x11, 0);           // font is stored in FLASH, demontrate read callback
   glcdPrintCenter(r, PSTR("cnkz@yahoo.com"), 1);


}


// paint on the four possible orientation, as shown the coordinates are always the same
void testOrientation(void) {

    uint8_t mem = glcd_MemCtrl;          // save glcd_MemCtrl
    glcdFlags_t flags = glcd_Flags;      // save glcd_Flags

    glcd_Flags.All = 0;                  // all bits off, no clipping, no fixed font and no autolinefeed

    glcdRect_t r;
    glcdSetRect(r, 1, 1, 64, 64);

    glcdClearScreen(0);
    glcdSelectFont(0, myRead);           // font is stored in FLASH, demontrate read callback


    glcdSetOrientation(0);
    glcdSetColors(BLACK, NONE);
    glcdRectangle(r.X1, r.Y1, r.X2, r.Y2);
    glcdLine(r.X1, r.Y1, r.X2, r.Y2);
    glcdCircle(r.X1, r.Y1, 20);
    glcdMoveTo(r.X1 + 2, r.Y1 + 2);
    glcdPrintCenter(r, PSTR("0 Grad"), 1);
/*
    glcdSetOrientation(1);
    glcdSetColors(RED, NONE);
    glcdRectangle(r.X1, r.Y1, r.X2, r.Y2);
    glcdLine(r.X1, r.Y1, r.X2, r.Y2);
    glcdCircle(r.X1, r.Y1, 20);
    glcdMoveTo(r.X1 + 2, r.Y1 + 2);
    glcdPrintCenter(r, PSTR("90 Grad"), 1);

    glcdSetOrientation(2);
    glcdSetColors(GREEN, NONE);
    glcdRectangle(r.X1, r.Y1, r.X2, r.Y2);
    glcdLine(r.X1, r.Y1, r.X2, r.Y2);
    glcdCircle(r.X1, r.Y1, 20);
    glcdMoveTo(r.X1 + 2, r.Y1 + 2);
    glcdPrintCenter(r, PSTR("180 Grad"), 1);

    glcdSetOrientation(3);
    glcdSetColors(YELLOW, NONE);
    glcdRectangle(r.X1, r.Y1, r.X2, r.Y2);
    glcdLine(r.X1, r.Y1, r.X2, r.Y2);
    glcdCircle(r.X1, r.Y1, 20);
    glcdMoveTo(r.X1 + 2, r.Y1 + 2);
    glcdPrintCenter(r, PSTR("270 Grad"), 1);
*/
    glcdWait(2000);       // 2 seconds
    glcd_Flags = flags;
    glcdSetOrientation(mem);
}

// paint own bitmaps
void testBitmaps(void) {

    uint8_t Bitmap[512];
    glcdCoord_t width = glcd_Clip.X2 - glcd_Clip.X1 +1;
    glcdCoord_t height = glcd_Clip.Y2 - glcd_Clip.Y1 +1;
    int16_t i,j;

    for (i = 0; i < 512; i++) {      // create a bitmap
      Bitmap[i] = i * 2;
    }

    glcdSetAddr(glcd_Clip.X1, glcd_Clip.Y1, glcd_Clip.X2, glcd_Clip.Y2);  // bounds of bitmap on screen

    for (i = 0; i < 256; i++) {
      for (j = 0; j < height; j++) {
        glcdDisplayBuffer(&Bitmap[i + j], width, 0);
      }
    }

}


void testBitmaps_2(void) {
	uint8_t x=0, y=0;
	glcdColor_t pix;
	uint16_t i=0;
	
uint16_t Bitmap[] = 
{0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,
0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,
0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,
0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0,0xFBE0}; //52
	
	for(uint16_t i=0; i<52; i++) {

		glcdSetPixel(x, y++, Bitmap[i]);
		
		if(y == 0) {
			y=175;
			x++;
		}
	}
}

void testBitmaps_3(void) {
	uint8_t x=0, y=0;
	glcdColor_t pix;
	
	//const prog_uint16_t Bitmap[23232] PROGMEM;
	static const uint16_t Bitmap[] PROGMEM = 
{0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xBEBD,0x8D17,0x7453,0x6BAF,0x5B6D,0x4AAB,
0x532E,0x4AEB,0x3A49,0x3209,0x424A,0x2947,0x2144,0x31A3,0x31E4,0x31E6,0x4269,0x3A69,0x21C8,0x4228,0x31E7,
0x3A48,0x3A27,0x2165,0x3A26,0x4286,0x29E6,0x4268,0x6B87,0x72E5,0x72C6,0x72E8,0x5247,0x5AE8,0x4286,0x4206,
0x7328,0xAC0A,0x9408,0x7B68,0x7BC9,0xA4AC,0x944B,0x72A8,0x9C0C,0xB46C,0x8B89,0x93E9,0x7B88,0x6B88,0x6B67,
0x7389,0x6B86,0x29E4,0x4226,0xCCD0,0x832B,0x0903,0x31C5,0x41C4,0x1923,0x1924,0x1923,0x1963,0x1122,0x10E3,
0x1903,0x4A67,0x7C26,0x7482,0x6344,0x3A43,0x3AA3,0x3A25,0x3984,0x62A7,0x7325,0x31A3,0x1104,0x1103,0x2924,
0x7BAA,0xB58F,0x9CEC,0x6B88,0x4A47,0x39E5,0x31A4,0x2963,0x31A4,0x39C5,0x39C4,0x49E3,0x39A1,0x4A43,0x4A64,
0x4AA3,0x5B22,0x73E4,0x8426,0x8BE8,0x6B65,0xB5AC,0x9CCB,0x8C6B,0x6B68,0x6B47,0x5285,0x39E3,0x41E3,0x51E4,
0x5205,0x7B6B,0x83AB,0x738B,0x39E3,0x6344,0x4225,0x1102,0x10E1,0x10E1,0x1102,0x1141,0x1100,0x1941,0x1901,
0x1120,0x3240,0x5B22,0x39E4,0x31E4,0x42E2,0x21E0,0x1922,0x1920,0x2142,0x1961,0x2181,0x3201,0x31E0,0x21A0,
0x2180,0x2180,0x3A63,0x31E6,0x1104,0x08E1,0x08C0,0x08C0,0x08C0,0x1101,0x1122,0xDFDF,0xDFDF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,
0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xE7DF,0xC6FD,0xAE1A,0x9D77,0x7432,0x636F,0x638F,0x636F,0x532D,0x4AAB,
0x4A8A,0x3A49,0x31A7,0x29E7,0x29A7,0x29A8,0x4A89,0x4289,0x3A49,0x634A,0x5B09,0x6349,0x6B89,0x4A88,0x5B08,
0x3246,0x2186,0x5B08,0x4AE5,0x2A25,0x2A04,0x6B09,0xCD0E,0xB4AC,0x93E7,0x8BA8,0x72E6,0x93AB,0x83AA,0x52C5,
0x7368,0xA4AC,0xA4CD,0xA42C,0x940B,0x9C8C,0x7BEA,0x7368,0x73E7,0x6347,0x7BC8,0x6306,0x3205,0x3A27,0x2A05,
0x5266,0x8B4A,0x5228,0x4A05,0x3183,0x1104,0x1903,0x10E3,0x08C3,0x10E3,0x2104,0x4A46,0x6C03,0x5360,0x6BC5,
0x83EC,0x4AC6,0x5B24,0x29A3,0x5245,0x4A24,0x5AA5,0x4A87,0x29C4,0x1983,0x29A4,0x3203,0x6385,0x9D08,0xA52F,
0x7BAD,0x4205,0x31A4,0x2982,0x2161,0x2161,0x2161,0x2161,0x2961,0x31A1,0x39C1,0x39C1,0x5223,0x41E1,0x4A43,
0x4A63,0x52E2,0x7C47,0x4224,0x41E5,0x39A4,0x2963,0x2143,0x2902,0x2143,0x2922,0x39A3,0x39C3,0x49C5,0x4A26,
0x2942,0x4242,0x3A04,0x08C2,0x08C1,0x08C1,0x08C1,0x08C1,0x1101,0x2A60,0x3AA1,0x21A1,0x29A2,0x3221,0x29E0,
0x2122,0x3A23,0x6BE6,0x5B62,0x42A0,0x29E0,0x1961,0x1941,0x2162,0x2964,0x3A82,0x42A1,0x4262,0x1922,0x1945,
0x08E2,0x08C0,0x08E1,0x08A1,0x08E1,0x1921,0x10E1,0xDFBF,0xDFDF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,
0xE7DF,0xD75F,0xAE7C,0x9DBA,0x8D16,0x7434,0x7C54,0x7411,0x5B8F,0x42CC,0x424A,0x424A,0x426B,0x428B,0x3A4B,
0x3209,0x29A7,0x52CA,0x632B,0x5B29,0x5B28,0x5B29,0x52E8,0x5B28,0x6B89,0x5B08,0x62C9,0x62C8,0x6347,0x42C5,
0x31A6,0x39C6,0x62C8,0x7307,0x83AA,0xA388,0x7366,0x4283,0xACCF,0x946B,0x6B48,0x8BEB,0xA4AD,0x9CCC,0x946B,
0x94AA,0x8C6A,0x8449,0x73E7,0x73E6,0x6BC7,0x6328,0x4245,0x3A25,0x4AA7,0x3205,0x1964,0x5A27,0xAC2F,0x6266,
0x6244,0x2143,0x1103,0x10E2,0x08E2,0x08A2,0x5AE7,0x7CA3,0x8D05,0x7C66,0x94CD,0xB58F,0x6325,0x3183,0x2123,
0x39E4,0x5285,0x6306,0x7BA8,0x6306,0x6329,0x4A87,0x52E8,0x8C2D,0xC5D3,0xA50F,0x4AC4,0x3A22,0x2181,0x2180,
0x2162,0x1962,0x1942,0x1942,0x2142,0x2142,0x1942,0x2922,0x3163,0x3163,0x4A04,0x4A83,0x4AA2,0x4A45,0x2124,
0x2964,0x1903,0x1923,0x1902,0x1902,0x18E2,0x1902,0x1902,0x2121,0x3183,0x39E4,0x29A3,0x31E2,0x2160,0x1100,
0x10E0,0x10E0,0x08E0,0x1941,0x2182,0x21C0,0x3A42,0x29A1,0x4262,0x29C0,0x5302,0x73C4,0x7403,0x5B61,0x3220,
0x1981,0x21A1,0x1941,0x1101,0x3223,0x42C4,0x5C02,0x53C0,0x2A20,0x2182,0x1104,0x08A1,0x08A1,0x08E2,0x08C1,
0x10E1,0x2160,0x1960,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xE7FF,0xEFFF,0xEFFF,0xE7DF,0xCEFE,0xCEFE,
0xBE9D,0xC69E,0xBE9D,0x9D99,0x8496,0x7C54,0x7C14,0x7C33,0x6BD0,0x6BAF,0x73F0,0x5B2C,0x2187,0x3A29,0x6B8B,
0x5B29,0x4AE8,0x4288,0x530A,0x42A7,0x52E8,0x52E8,0x93EB,0xB449,0x9369,0x8B69,0x6A47,0x4A26,0x3A45,0x6AE8,
0xABC9,0x7285,0x4284,0x4284,0x6B47,0x4284,0x6327,0x8C2B,0x9C8C,0x944B,0x8C6B,0x8C6A,0x8C69,0x7C28,0x73E8,
0x7BE8,0x63A7,0x6327,0x52E6,0x4AC6,0x3A25,0x3A25,0x31E6,0x31E5,0x62C9,0x6226,0x39A3,0x2144,0x1964,0x1924,
0x2946,0x7B8F,0x846C,0x63E1,0x73E7,0x3A24,0x6306,0xA509,0x7C46,0x6B67,0x4AA4,0x62E7,0x5266,0x41E5,0x31A5,
0x29A3,0x73C9,0x73C9,0x6348,0x8C2A,0x6B64,0x3A41,0x2162,0x2984,0x1943,0x1942,0x1941,0x1920,0x2162,0x2183,
0x1923,0x1123,0x1924,0x18E4,0x3A05,0x63C5,0x63C3,0x5C01,0x6421,0x39C2,0x2945,0x2985,0x2124,0x1903,0x1922,
0x2122,0x1902,0x1902,0x1922,0x2143,0x2963,0x3202,0x3AA1,0x3202,0x1921,0x1101,0x10E1,0x10E1,0x1100,0x2161,
0x2181,0x2141,0x2180,0x29A0,0x2180,0x2160,0x3200,0x3A20,0x2160,0x10E0,0x1101,0x2983,0x1942,0x2221,0x21E0,
0x1940,0x1920,0x21E0,0x3AC1,0x3242,0x2145,0x1101,0x1920,0x1120,0x1101,0x08E0,0x08E0,0x10E0,0x08E0,0xDFBF,
0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,
0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xD79E,0xBEBC,0xBEBC,0xC6BB,0xAE3B,0xB67A,0xAE17,0x9D97,
0xADF9,0xAE19,0x7C90,0x73CC,0x73AD,0x5B4C,0x5B4D,0x532A,0x3207,0x3A0A,0x4AA9,0x3A87,0x52C7,0x3A47,0x52E8,
0x4287,0x732A,0xA44C,0xC530,0xBC8C,0xD50C,0x8B88,0x41E5,0x52E5,0x7367,0xABEA,0x72A6,0x4264,0x3A43,0x5285,
0x39E4,0x29C4,0x4A86,0x8C0B,0x9C6C,0x946B,0x948C,0x948B,0x8449,0x8C49,0x8428,0x8C68,0x8428,0x6B46,0x6BA7,
0x4AA5,0x4AA6,0x52C6,0x4A86,0x29C5,0x2165,0x51E6,0x3A05,0x6366,0x7C45,0x63A7,0x9CAE,0x844C,0x29C3,0x08E2,
0x08C2,0x00A2,0x41C6,0x6247,0x83E9,0xA449,0x8424,0x7425,0x52A4,0x6343,0x4B02,0x2163,0x3A26,0x7C29,0x6B47,
0xAD6E,0x6B68,0x4A84,0x52C4,0x52C4,0x4264,0x29A4,0x1122,0x1942,0x1941,0x1961,0x1941,0x1943,0x29C2,0x3AA2,
0x3A44,0x29E4,0x2982,0x21A2,0x29E2,0x29A2,0x2964,0x2963,0x2964,0x2164,0x2143,0x2143,0x2163,0x2963,0x2944,
0x2123,0x1902,0x31E5,0x3203,0x3240,0x4261,0x31C2,0x1900,0x1920,0x2161,0x29A1,0x2160,0x2140,0x1940,0x1921,
0x18E3,0x2164,0x4A85,0x39E2,0x1921,0x1901,0x10C1,0x31C1,0x1101,0x1922,0x1921,0x1100,0x1100,0x1920,0x1961,
0x3A84,0x5305,0x3A41,0x2180,0x10E0,0x1100,0x1922,0x39C5,0x2142,0x08E0,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,
0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,
0xEFFF,0xDFDF,0xB67A,0x9D78,0xA59A,0x9598,0x9558,0xA5B9,0x84D3,0x530C,0x6B8E,0x7430,0x7410,0x5B2D,0x634C,
0x5B0A,0x4ACA,0x426A,0x3228,0x3A49,0x6B6D,0x52CA,0x4288,0x4AA7,0x3A27,0x3A47,0x4A88,0xAC8D,0x9386,0xA4AE,
0xB44A,0x7B06,0x4AA5,0x5B26,0x6385,0x8C49,0xACCC,0x8C6B,0x6346,0x3204,0x4A66,0x31E4,0x29A4,0x52A6,0x83CA,
0x8C2A,0x944B,0x9C8B,0x9CCC,0x94AA,0x8C69,0x8468,0x6BA6,0x6B66,0x6B27,0x6B47,0x5306,0x52E6,0x52E5,0x4246,
0x29A5,0x4247,0x6BC6,0x7463,0x5BA2,0x3202,0x1982,0x2182,0x08C1,0x10C3,0x1103,0x08E2,0x08E2,0x49E6,0x2923,
0x2983,0x8347,0x5AE5,0x73C6,0x6B85,0x7BC4,0x7C80,0x53A0,0x63C5,0x5B67,0x6C03,0x73C9,0x948B,0x7BC8,0x6B45,
0x73C5,0x6BA3,0x4AA3,0x2163,0x1923,0x1943,0x1922,0x1941,0x1982,0x1141,0x3AE0,0x5344,0x5B27,0x5343,0x31E3,
0x2144,0x1964,0x1943,0x1922,0x2122,0x2943,0x2943,0x2943,0x3182,0x29A2,0x29A2,0x29A2,0x3A23,0x73C7,0x6BE3,
0x5B41,0x42A1,0x3260,0x3A40,0x31E2,0x2182,0x1941,0x41E4,0x39A6,0x08E1,0x1923,0x1922,0x21A1,0x3A61,0x29A0,
0x2983,0x10C1,0x08C1,0x1101,0x3A02,0x52E3,0x29E1,0x29C0,0x21A0,0x21C0,0x1942,0x10E3,0x29E1,0x3281,0x3AE0,
0x1920,0x08A0,0x6B6B,0x4A47,0x10E1,0x0880,0xD7DF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,
0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xC6FD,0xAE1B,0xAE1B,
0x9559,0x9539,0x9D5A,0x84F5,0x636F,0x7C14,0x8474,0x7C54,0x5B2E,0x7C35,0x6BF1,0x530E,0x42AC,0x4AAB,0x3228,
0x5B0C,0x7BED,0x7BCB,0x5309,0x3A47,0x52A8,0x52E9,0x52E8,0x52A9,0x3A27,0x4247,0x6B09,0x4A87,0x6B89,0x6BC8,
0x6366,0x5B65,0x5B84,0x63C4,0x7C45,0x7424,0x6B06,0x31C4,0x3A25,0x73A8,0x8C0A,0x8C0B,0x8C4B,0x9CCC,0xA50C,
0x8C69,0x7BE7,0x7C07,0x6346,0x7BCA,0x7388,0x52C5,0x4AC6,0x4AA6,0x5305,0x4A86,0x630A,0x6BE6,0x42E1,0x21C3,
0x1103,0x1104,0x1123,0x1103,0x1103,0x1123,0x1123,0x1102,0x1102,0x41E6,0x49C5,0x3183,0x2964,0x6385,0x6421,
0x6460,0x63C4,0x83C7,0x7C84,0x7D22,0x7C68,0x7424,0x7404,0x6BC5,0x73E7,0x6346,0x4AC4,0x3203,0x39E3,0x31E4,
0x2985,0x2985,0x2123,0x1903,0x2184,0x2963,0x31A2,0x6327,0x5B08,0x3A62,0x3223,0x1123,0x1102,0x1902,0x1102,
0x1901,0x1901,0x2121,0x2141,0x2161,0x3202,0x3AC1,0x4281,0x5301,0x42E0,0x4B21,0x73C7,0x6BC7,0x6C60,0x7C83,
0x4242,0x2161,0x4225,0x7389,0x83CB,0x10E2,0x1121,0x21A0,0x29C0,0x6383,0x52C5,0x08A1,0x08A1,0x1940,0x19A0,
0x3A60,0x3A40,0x3200,0x1961,0x1921,0x1903,0x08A3,0x2963,0x39A3,0x39C2,0x3A23,0x2982,0x31E4,0x2162,0x31C2,
0x39E3,0x3A02,0xD7BF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xEFFF,0xDF9F,0xB63C,0xBE9E,0xB67C,0x9578,0x8516,0x6BF0,
0x6B91,0x8475,0x7CB5,0x7C54,0x7C75,0x74B4,0x3A8B,0x42AC,0x3A6A,0x3A6C,0x4AED,0x7BED,0x7C0C,0x5B4A,0x4AA7,
0x4268,0x5AE9,0x3207,0x4288,0x5AE9,0x3A07,0x4267,0x4AA8,0x5AE9,0x9D49,0x8D07,0x8D09,0x9526,0x7405,0x6BE3,
0x6C04,0x8CA5,0x9388,0x6327,0x6BA7,0x7C08,0x8C29,0x9C6D,0x9CAD,0x94AC,0x948B,0x8429,0x8449,0x73E6,0x6367,
0x8BA9,0x6B07,0x6B68,0x73E9,0x6367,0x5306,0x4AE6,0x4A86,0x29C4,0x1945,0x1944,0x1944,0x1944,0x1123,0x1103,
0x1103,0x1103,0x1103,0x1102,0x08A2,0x41A5,0x938C,0xA42C,0x73C5,0x7C47,0x6C22,0x4B60,0x5363,0x6BC4,0x6364,
0x2201,0x4262,0x63C2,0x7C63,0x7C67,0x5B06,0x4A45,0x31A4,0x29C3,0x3A03,0x3A03,0x29A3,0x29A2,0x29A2,0x2982,
0x29A2,0x31A2,0x31C3,0x4224,0x4A85,0x2161,0x1142,0x10E2,0x1102,0x1102,0x1922,0x1922,0x1941,0x2181,0x29A2,
0x29A1,0x29C0,0x3220,0x4340,0x5BC0,0x5360,0x5B43,0xCDF1,0x8466,0x7424,0x5B62,0x2160,0x29C1,0x63A4,0x7422,
0x6C01,0x1920,0x1121,0x2180,0x3222,0x3A82,0x1941,0x08A2,0x08A0,0x18E2,0x18C2,0x2102,0x3184,0x2922,0x31C2,
0x5285,0x7348,0x6B48,0x73C6,0x94A8,0x6BE4,0x7425,0x7385,0x42C2,0x3A02,0x42A1,0x42C1,0x5343,0xD7BF,0xDFBF,
0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xE7DF,0xAE5C,0x8CD7,0x7C97,0x9D1A,0xBE1C,0xB65D,0x9539,0x8D18,
0x5B91,0x5B52,0x6373,0x428F,0x428E,0x428D,0x73F0,0x73EC,0x840D,0x6B8A,0x6309,0x6B6A,0x6B8A,0x5B08,0x52A8,
0x52CA,0x4A89,0x4287,0x3A47,0x5AE8,0x6C06,0x32C0,0x63C4,0x7425,0x5B66,0x7424,0x5362,0x7BE7,0x938A,0x7327,
0x7422,0x7425,0x946A,0x9C8D,0x842A,0x8C4B,0x8C4A,0x8C6A,0x8448,0x73C7,0x7BE8,0x9BE9,0x83C8,0x73C7,0x6BA7,
0x73A9,0x73C9,0x6B67,0x4AA4,0x31E4,0x2164,0x1944,0x1943,0x1143,0x1123,0x1103,0x10E3,0x1103,0x10E2,0x10A2,
0x5A68,0xAD2F,0xC60E,0xBD0D,0x7AC7,0xA50B,0xC610,0x9CAE,0x7BCB,0x4AA6,0x3222,0x3A44,0x3243,0x42C6,0x3243,
0x4AE6,0x5B48,0x2182,0x1122,0x1122,0x2963,0x2963,0x2162,0x2963,0x2963,0x2983,0x2983,0x2983,0x31C3,0x31A2,
0x3163,0x2983,0x29A3,0x2162,0x2182,0x2181,0x21A1,0x29A1,0x2181,0x29A1,0x2981,0x1940,0x1940,0x21C0,0x3A40,
0x4B20,0x5B60,0x8464,0xA48A,0x8C06,0xAD4E,0x948D,0x6B4B,0x5AA8,0x52A2,0x3A60,0x3200,0x1960,0x08A2,0x2965,
0x2946,0x4A08,0x4A27,0x31C4,0x52C4,0x844A,0x8447,0x8CA8,0x7C26,0x6362,0x5341,0x5341,0x5382,0x6BA3,0x6362,
0x6323,0x4AC2,0x5305,0x3A23,0x3A04,0x31A3,0x31C3,0x1940,0x2961,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,
0xE7FF,0xEFFF,0xEFFF,0xEFDF,0xEFDF,0xDF9F,0xE7BF,0xF7FF,0xF7FF,0xE7BF,0xCEFE,0xD6DD,0xEFBF,0xEFBF,0xE77F,
0xCEDD,0xB5FA,0x9D76,0x6B8D,0x7BCD,0x5B29,0x6328,0x5B08,0x5B28,0x5308,0x52E8,0x4A88,0x4248,0x3A07,0x31C6,
0x4267,0x5B45,0x3A83,0x3A81,0x5B44,0x8C89,0x8CC6,0x7C84,0x8C87,0x8368,0x4A05,0x6364,0x6383,0x83E9,0x944C,
0x946C,0x8C6B,0x842A,0x8429,0x7C08,0x73C8,0x6B87,0x8B27,0x7306,0x7388,0x73A8,0x73A9,0x7BE5,0x7C05,0x73E5,
0x6B86,0x6307,0x5AA8,0x41E6,0x31C6,0x31A6,0x2945,0x2924,0x2124,0x2164,0x8C6C,0xA54C,0x6366,0x4263,0x5284,
0x8B27,0x6305,0x8C87,0x9CA9,0xAD2D,0x4AA7,0x2984,0x3A25,0x29C1,0x3A65,0x21C4,0x2183,0x4A86,0x6346,0x4283,
0x3A44,0x1942,0x1923,0x1101,0x10E2,0x18E3,0x18E2,0x1903,0x5AA6,0x7BE8,0x7BC6,0x7C05,0x5B63,0x4AA2,0x31E1,
0x21A1,0x2181,0x2161,0x2141,0x1921,0x1901,0x1101,0x1100,0x1901,0x1940,0x2180,0x3A02,0x94EA,0xDEF4,0xCE33,
0xDED2,0xE774,0xE775,0xE754,0xDEF3,0xBDF2,0x6B0C,0x734B,0x73A8,0x8405,0x9467,0x73E5,0x8C47,0x73E6,0x7BE6,
0x6B84,0x42E1,0x3A80,0x3A41,0x31C1,0x31A1,0x29A1,0x4224,0x2982,0x4203,0x5267,0x736A,0x9C8F,0x9CAF,0x9C8F,
0x9CB0,0x946E,0x8C4F,0x6B49,0x42A2,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7FF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,
0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xF7FF,0xF7FF,0xF7FF,0xF7FF,0xF7FF,0xFFFF,0xFFFF,0xB67B,0x8471,
0x73AC,0x4268,0x3A47,0x3A27,0x4A88,0x4267,0x3A48,0x4A89,0x4248,0x31E7,0x5AEA,0x73EA,0x4AA4,0x3A25,0x5B46,
0x63C4,0x7423,0x8487,0x8488,0x6326,0x6AA6,0x52A5,0x6BA5,0x5B66,0x8C2B,0x8C2B,0x944B,0x948C,0x842A,0x7BC9,
0x7BC8,0x7387,0x7387,0x7B07,0x62A5,0x83C9,0xA42B,0xC5F2,0x948A,0x8407,0x73A7,0x6365,0x73A5,0x73A6,0x73A7,
0x73A7,0x7387,0x62E6,0x5A86,0x49E5,0x52A6,0x7C28,0x3A44,0x1942,0x39E5,0x2983,0x5A23,0x6263,0x3181,0x3183,
0x31C4,0x31C5,0x52A7,0x63A6,0x29E2,0x29C3,0x3A24,0x31C3,0x41E5,0x4A45,0x5B27,0x4264,0x738B,0x83AF,0x4226,
0x4A85,0x6367,0x6383,0x7C25,0x9D46,0x84C3,0x63C2,0x42C0,0x2A00,0x1961,0x1941,0x1941,0x1901,0x1921,0x1901,
0x1901,0x2181,0x2161,0x2962,0x2981,0x29E1,0x52A4,0x7AE9,0xA50B,0xE773,0xD712,0xC66E,0xADCA,0x94E8,0x7C25,
0x6BC4,0x6BA5,0x94AC,0xC58E,0x9CE5,0x94E1,0x6BA1,0x5B21,0x6324,0x52C2,0x6324,0x6305,0x4282,0x4AA2,0x4AA2,
0x4AC2,0x5B42,0x73A2,0x7384,0x7C08,0x9CED,0xAD8F,0xC630,0xC690,0xCE90,0xCE8F,0xCEB0,0xCEB1,0xDEF3,0xCE72,
0x6C05,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xDFDF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,
0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xF7FF,0xE7BF,0xB659,0x94B0,0x6B6B,0x4288,0x3A48,0x3A48,
0x4288,0x52A7,0x3A27,0x4A88,0x3A06,0x6BA8,0xB60B,0x7C85,0x3A25,0x3A26,0x73E8,0x7465,0x4B42,0x6384,0x5B46,
0x62C7,0x51E5,0x4AC4,0x5325,0x4286,0x840B,0x9CCD,0x73C9,0x7BC9,0x840A,0x73C9,0x73C8,0x73C8,0x8C2A,0x8C0A,
0x7349,0x8C69,0x8346,0x946A,0x9D0A,0xA52A,0x8C88,0x8446,0x83E7,0x83E7,0x6B85,0x5B04,0x4A83,0x4AA3,0x4AC3,
0x7BA7,0x7BE8,0x5AE5,0x4283,0x4AC4,0x83A9,0x7308,0x31C1,0x5A64,0x3A24,0x3A23,0x3A44,0x5B46,0x84E4,0x6364,
0x4245,0x4284,0x4A83,0x8C0A,0xA4AE,0xA46E,0xBDB1,0x7368,0x8C67,0xA589,0x9D46,0x9544,0x7C82,0x7400,0x5320,
0x3240,0x29A2,0x1922,0x1122,0x1122,0x1101,0x1921,0x1921,0x1120,0x1100,0x1901,0x10E1,0x2161,0x6B88,0x7C29,
0x63A4,0x42A2,0x7B2A,0x5186,0x4163,0x73C5,0x84A6,0x6363,0x3A40,0x31C0,0x2980,0x3181,0x2960,0x3180,0x39A0,
0x2960,0x31E0,0x3A60,0x4B00,0x5BC2,0x5BC1,0x5BC0,0x5BC0,0x6C00,0x7422,0x63C1,0x5BC0,0x5BA0,0x63A0,0x9D08,
0xCE90,0xC66F,0xB5ED,0xADAC,0xA58C,0xB5CC,0xBDEE,0xB5CF,0x9D2C,0xA56D,0xA50D,0x6308,0xD7BF,0xD7BF,0xDFBF,
0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,
0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,
0xEFFF,0xEFFF,0xEFFF,0xF7FF,0xE7DF,0xAE18,0x6BAB,0x634B,0x4268,0x4AA9,0x4267,0x3226,0x31E6,0x2986,0x3206,
0x3206,0x7C0A,0x84A6,0x7C27,0x9CEF,0x9D4D,0x63C3,0x5380,0x4B21,0x5B62,0x3203,0x4A45,0x5A27,0x31C5,0x3A07,
0x4AA9,0x7BEA,0xA4ED,0x8C6B,0x7BEA,0x73C8,0x7BE9,0x6B87,0x73A8,0x8C0A,0x9BC9,0x7BEA,0x8449,0x6326,0x6AC6,
0x4AA4,0x3A24,0x3A23,0x4A64,0x4262,0x4AC3,0x5303,0x4AA2,0x4282,0x6386,0x73E6,0x7423,0x7423,0x7402,0x7401,
0x7422,0x8C25,0x7B07,0x3A41,0x4282,0x3A61,0x5B41,0x7C42,0x8462,0x7C23,0x7C05,0x8C68,0x8428,0x8C49,0xAD6A,
0xA566,0x8CE4,0x7C23,0x6BA3,0x5B62,0x5B81,0x4AE0,0x3A20,0x31E1,0x39C1,0x3181,0x2161,0x1923,0x1922,0x1942,
0x1942,0x1922,0x1121,0x1921,0x1921,0x3A04,0x5AE6,0x3A03,0x1921,0x5343,0x42E0,0x42E2,0xAD8C,0x832B,0x5187,
0x28C4,0x2122,0x2960,0x2140,0x2140,0x31A1,0x52A5,0x3182,0x2941,0x2121,0x1901,0x2160,0x2980,0x2140,0x2160,
0x2180,0x29C0,0x3261,0x29C0,0x29A0,0x31A0,0x2140,0x1900,0x4202,0xAD4E,0xCE92,0xB58E,0xA54C,0x950B,0xA50B,
0x9C8B,0x8C6B,0x73A8,0x6B68,0x738A,0x7BAD,0x4A46,0x39C4,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7FF,0xE7DF,0xE7FF,0xE7FF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,
0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xF7FF,
0xF7FF,0xB619,0x532C,0x4AEB,0x4AC9,0x4AA9,0x29A6,0x39E7,0x29A6,0x49A7,0x49E7,0x5B28,0x5B46,0x3261,0x4AE3,
0x9529,0x9528,0x7404,0x5B63,0x5B44,0x6B8A,0x738A,0x738A,0x946C,0x6B68,0x6329,0x5B0A,0x52A7,0x52A6,0x4AA5,
0x4265,0x4244,0x4245,0x4A86,0x52C6,0x8327,0x8B69,0x6B49,0x6327,0x6B68,0x6AE7,0x4A65,0x3A65,0x3225,0x29A5,
0x2165,0x1944,0x4225,0x5B08,0x6B6B,0x9CD0,0x52C8,0x1902,0x1943,0x1943,0x1943,0x2143,0x3963,0x7AA7,0x5A27,
0x1102,0x1924,0x2143,0x736A,0xA50C,0xA54B,0xA54A,0x8465,0x6B83,0x7421,0x63A1,0x3A41,0x2961,0x4225,0x7388,
0x6326,0x5AC6,0x52C4,0x5284,0x5266,0x39A2,0x39C3,0x31C1,0x29A1,0x2182,0x2183,0x2983,0x2162,0x29A2,0x4226,
0x842A,0x9527,0x7442,0x4280,0x1101,0x1121,0x1101,0x3221,0x6C02,0x6A28,0x30C4,0x20C3,0x18A3,0x2101,0x2120,
0x2120,0x62E4,0xE733,0xA4D0,0x5A25,0x2922,0x10A1,0x29A1,0x29C0,0x31C3,0x4243,0x1900,0x1920,0x1920,0x10E0,
0x10C0,0x08A1,0x0860,0x39A3,0xB590,0xC672,0x9D2D,0x8C6A,0x8C6A,0x6326,0x5AC5,0x83CB,0x62E9,0x5AC9,0x5287,
0x5B08,0x4226,0x2142,0x29A3,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,
0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xF7FF,0xF7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xF7FF,0xF7FF,0xD71D,0x6BF1,
0x4289,0x3A27,0x2186,0x31C6,0x5A48,0xE451,0xBBEE,0x5AA9,0x7BEB,0x73CA,0x94AD,0xA54C,0x9D29,0x9CE9,0x8468,
0x8466,0x8467,0x8426,0x6B66,0x52C5,0x3A03,0x4A88,0x6B8C,0x7BCC,0x83EA,0x7BEA,0x73A9,0x7BCA,0x7BAA,0x83EB,
0x944C,0x8348,0x7308,0x94AB,0x8C6A,0x8C49,0x73C8,0x5B47,0x5305,0x3A45,0x29C5,0x29A4,0x2185,0x29E6,0x3225,
0x5B48,0x73EA,0x6B88,0x73EA,0x5305,0x4AC3,0x31C4,0x2983,0x4AC4,0x6A66,0x82EA,0x736B,0x842A,0x52E5,0x9489,
0x7C06,0x4AC2,0x3202,0x5B65,0x6402,0x42E3,0x29A4,0x1923,0x1943,0x4284,0x6BC7,0x3A84,0x4AA3,0x6BA8,0x5B08,
0x2983,0x3A05,0x6388,0x5364,0x42A0,0x3A20,0x29C0,0x4A63,0x5284,0x39C1,0x2942,0x31C1,0x2160,0x08C0,0x0881,
0x10E1,0x1101,0x1101,0x1941,0x1941,0x4966,0x1863,0x1062,0x18C2,0x2101,0x2940,0x2940,0x5AC3,0xB5CD,0xD6F1,
0xAD4D,0x4A24,0x4A03,0x41E4,0x20E1,0x5221,0x4221,0x1900,0x10C0,0x10C1,0x10C0,0x10C1,0x10A2,0x2122,0x8C6A,
0xB5AF,0x948B,0x73A9,0x6306,0x5245,0x3964,0x3184,0x41E5,0x39A5,0x2963,0x3163,0x2102,0x2942,0x31A3,0x5AE7,
0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,
0xCEDA,0xE79B,0xEFFD,0xF7FF,0xF7FF,0xF7FF,0xF7FF,0xF7FF,0xF7FF,0xFFFF,0xCEFC,0x73CE,0x5AEB,0x6B4C,0x7BCD,
0xACAF,0xD54D,0xC50D,0x9C4B,0x94AC,0xA50A,0x8468,0x73C7,0x73C8,0x73C5,0x5B81,0x5303,0x4AC2,0x63A2,0x2983,
0x2963,0x2144,0x2165,0x31C5,0x7389,0x948B,0x842A,0x7BE9,0x6BA9,0x7389,0x7388,0x6B6A,0x5AC9,0x6AA7,0x7368,
0x5AE6,0x52C5,0x4AA4,0x4264,0x4264,0x3A24,0x31E3,0x31E4,0x2185,0x2183,0x1963,0x1922,0x1922,0x31E3,0x5304,
0x4282,0x3241,0x4A85,0x3A24,0x4AC3,0x4A84,0x6A87,0x6325,0x5304,0x3A84,0x29E0,0x21A1,0x2183,0x2A05,0x3B01,
0x2A21,0x1903,0x1104,0x1963,0x1922,0x1101,0x2162,0x3203,0x4AC4,0x8C4C,0x7BAB,0x7BAC,0xAD31,0x7B8D,0x4227,
0x2182,0x31E1,0x5B05,0x5B05,0x6286,0x7B8C,0x7C0C,0x7BCA,0x39A6,0x0862,0x0062,0x08A1,0x10E1,0x1121,0x1101,
0x1121,0x2122,0x1883,0x1062,0x18A2,0x2141,0x2981,0x2981,0x31A2,0x3A02,0x6324,0x6BC6,0x7C26,0x94C8,0x7C26,
0x9AA5,0xEA65,0x99E4,0x41A4,0x2942,0x3162,0x2922,0x3162,0x31A2,0x52A2,0x7405,0x73A6,0x5266,0x3163,0x3984,
0x2102,0x2923,0x20E2,0x18C2,0x20E2,0x20E2,0x2942,0x2942,0x2942,0x39C2,0x29C2,0xD7BF,0xD7BF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xE7BF,0x73CD,0x5B4A,0x63A9,0x740B,
0xAD71,0xC694,0xD6B2,0xC652,0xC634,0xBE17,0xA511,0x8C6D,0x9CAD,0x8C6A,0x93E9,0xDC28,0xDC4B,0xED71,0xDA46,
0x9B07,0x63E4,0x42C3,0x3222,0x5304,0x73E5,0x63A3,0x42C2,0x42A3,0x5B47,0x39E5,0x5307,0x39C5,0x4226,0x52C7,
0x83AA,0x842A,0x73C8,0x6347,0x6367,0x6347,0x7368,0x736A,0x6B4A,0x7286,0x6B28,0x5AC7,0x52A6,0x5286,0x4A65,
0x3A05,0x39E5,0x39E4,0x29A3,0x10E3,0x1103,0x1922,0x1922,0x1902,0x1901,0x1902,0x2965,0x738B,0x8C6C,0x7C06,
0x52E4,0x5306,0x4A26,0x49E5,0x4AC5,0x4284,0x5B83,0x6385,0x42A4,0x2202,0x3AC4,0x4285,0x5B66,0x3A23,0x10E1,
0x2162,0x29A3,0x39E5,0x736A,0xC5D1,0xE713,0xE731,0xE730,0xCE6D,0xD68F,0xC5D0,0x73A8,0x5B25,0x4264,0x4A05,
0xA42D,0xC5F1,0xD6F2,0xC66F,0xB5CD,0x94AE,0x526B,0x0883,0x0081,0x08A2,0x10C2,0x10E1,0x1121,0x18E2,0x1083,
0x18C2,0x2162,0x2162,0x2182,0x2181,0x1920,0x31A1,0x52A3,0x4A23,0x5223,0x92E3,0xFB67,0xFA26,0xFAC7,0xCB49,
0x4A22,0x4A42,0x3982,0x2921,0x3981,0x4200,0x31C0,0x3982,0x3902,0x20C2,0x20C2,0x10A2,0x18C1,0x18C1,0x18E2,
0x18C2,0x18C1,0x2121,0x52C3,0x52C1,0x4260,0x42C1,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,
0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFDF,0x52EC,0x2165,0x2985,0x41A9,0x8C12,0xB38B,0xCB46,0xB1E4,
0xDA87,0xED34,0xEFBF,0x9556,0x6BAB,0x62A8,0xB2EB,0xFC4B,0xFCEE,0xF349,0xF1E6,0xD244,0x6363,0x5343,0x42E1,
0x5342,0x4AC4,0x5B63,0x5B23,0x52C4,0x6B08,0x6AC6,0x8C47,0x5AE6,0x5B27,0x4AE7,0x7B8A,0x8C4B,0x8C4B,0x73C9,
0x6B87,0x7388,0x83EA,0x944B,0x9C8B,0x7AE8,0x7B89,0x948A,0x94AB,0x7BE8,0x73E7,0x6326,0x4AA5,0x4265,0x4245,
0x2144,0x1902,0x1902,0x1922,0x1921,0x18E1,0x5287,0x842A,0x7C08,0x6366,0x73A9,0x6B6B,0x73CA,0x52A7,0x5A66,
0x3223,0x5B25,0x7C29,0x844B,0x63C8,0x2221,0x4284,0x6385,0x5342,0x5B62,0x3A24,0x31E4,0x7368,0xC60F,0xDEF0,
0xCE8D,0xB5AA,0x8C86,0x7BE4,0x6B44,0x6B45,0x7BA5,0x8409,0x29A4,0x08C1,0x5A69,0x7B09,0x62C6,0x6B65,0x6344,
0x73A4,0x8C67,0xA54B,0x6B4A,0x3A06,0x39C5,0x29A2,0x29A1,0x31E0,0x29A1,0x2102,0x18E2,0x1902,0x2143,0x2102,
0x4202,0x4AA2,0x4A62,0x52A2,0x5AA3,0x7224,0xE265,0xFAA6,0xD8C4,0xD904,0xD924,0x7902,0x4141,0x3982,0x3981,
0x49E1,0x4A21,0x3161,0x20E2,0x28E2,0x20C2,0x18C2,0x18E1,0x18E2,0x18E2,0x2102,0x2122,0x2962,0x3A01,0x3220,
0x4261,0x52E4,0x4A81,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,
0xDFDF,0xE7DF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,
0xEFFF,0xEFFF,0xF7FF,0x9D36,0x7330,0x8BF4,0xCE3D,0xF75D,0xE28B,0xF247,0xD146,0xC8E5,0xE124,0xF3EF,0xA48F,
0x5B69,0xA32B,0xFD0F,0xFCCD,0xFAE5,0xF246,0xEA65,0xE144,0xC2E6,0x5B85,0x19C2,0x29E2,0x42A4,0x6BC6,0x5B24,
0x5A65,0x49E6,0x5A25,0x49E4,0x4A64,0x7387,0x7389,0x83CB,0x946C,0x8C4B,0x8C2B,0x944B,0x9C8C,0x9C8B,0x9C8B,
0x9CCC,0x8348,0x83C8,0xA50B,0x9489,0x7BE7,0x6345,0x5B05,0x4A65,0x4A85,0x4A85,0x4A66,0x5286,0x4224,0x3182,
0x3183,0x5AA5,0x9D09,0x94C9,0x7BE9,0x8409,0x8C8B,0x7C09,0x73E8,0x4286,0x4205,0x3204,0x6327,0x73AA,0x6366,
0x3AA2,0x4B04,0x5BA2,0x42C1,0x63C5,0x8466,0x3A64,0x7BC9,0xB5AE,0xB5EE,0x7C06,0x6344,0x3A02,0x2981,0x2961,
0x2981,0x41C3,0x39A2,0x2982,0x1101,0x1102,0x628A,0x6AA9,0x5227,0x3921,0x3941,0x4160,0x3900,0x4960,0x7B63,
0xB56A,0x948A,0x3A20,0x5AE0,0x7BC3,0x8C04,0x7364,0x7BA4,0x83A5,0x7BA5,0x7384,0x8405,0x8423,0x7C02,0x73A2,
0x6B40,0xC301,0xFB45,0xF9C4,0xD083,0xC8A3,0xF1C4,0xFAC5,0xC9C4,0x6942,0x3181,0x31A1,0x3A21,0x4AA1,0x4A64,
0x3165,0x20E2,0x2102,0x2122,0x2122,0x2942,0x2963,0x3183,0x39E5,0x2963,0x2141,0x4AA5,0x3A05,0x2160,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,
0xF7FF,0xF7FF,0xF7FF,0xFC6F,0xF1E7,0xD106,0xC0E6,0xC106,0xC8C5,0xD0A4,0xE9E5,0x92A9,0xE3CB,0xFC8B,0xFB67,
0xFA85,0xFB05,0xF224,0xF1E3,0xD124,0x72E4,0x2A23,0x29E2,0x2A22,0x5B65,0x7326,0x6246,0x4A05,0x3183,0x3183,
0x31A4,0x5245,0x62E7,0x7BAA,0x8C4B,0x9CAC,0x9C6B,0x942B,0x944B,0x946B,0xA4CC,0x9CCB,0x93CA,0x93EA,0xA52C,
0xAD0E,0xA4CE,0x8C6B,0x8C8A,0x8C67,0x8C67,0x94C9,0xA52A,0xA568,0x8464,0xA50B,0xA54C,0xA549,0x8466,0x9467,
0x8428,0x73A9,0xA52E,0x4286,0x21A2,0x21A3,0x3A05,0x4247,0x52C6,0x738A,0x5324,0x3B00,0x4284,0x32A1,0x32C0,
0x21A1,0x4244,0x52A5,0x94CB,0xA56C,0x6B86,0x29A2,0x2122,0x2142,0x2142,0x2142,0x2961,0x2981,0x2982,0x1943,
0x10E2,0x08A1,0x626A,0x6A6B,0x4165,0x4122,0x4922,0x4901,0x4901,0x5102,0x6181,0x59C1,0x41A1,0x4980,0x51A0,
0x59E0,0x6A61,0x5A20,0x6AA1,0x6AA2,0x4A00,0x4A00,0x4A00,0x39C0,0x4A20,0x39E1,0x71A1,0xFAC4,0xFB45,0xE964,
0xC063,0xD8E3,0xFAC3,0xFB25,0xFA84,0xD924,0x7083,0x20C2,0x2162,0x5B81,0x84E2,0x7BAB,0x3985,0x5AE6,0x4245,
0x2943,0x2143,0x2943,0x31A3,0x8C6C,0x52A6,0x1960,0x2120,0x4A66,0x31E5,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,
0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xFCD1,0xFB08,
0xFB69,0xFAE8,0xE166,0xC0C5,0xC8E5,0xD0C5,0xE8E4,0xFA65,0xFB66,0xF1C3,0xFAE5,0xFB25,0xFA03,0xD903,0xC8C4,
0xD945,0xC265,0x4AC5,0x42C3,0x2A02,0x4A83,0x5265,0x49C5,0x3984,0x2943,0x2944,0x39A4,0x39A4,0x5A87,0x7389,
0x8C4B,0x948B,0x946C,0x8C2B,0x8C2B,0x942B,0x944B,0x946B,0x8C4A,0x9CCD,0x9CCB,0x8C6A,0x83EA,0x7BE8,0x73A8,
0x7C0A,0xA52E,0x8C87,0x6365,0x52C5,0x9D0A,0xADCA,0x6BA5,0x4223,0x5285,0x52C4,0x42C2,0x4B24,0x4AC6,0x2182,
0x2163,0x2185,0x39E6,0x4267,0x31E4,0x31C3,0x5B04,0x4AE3,0x39C6,0x4A28,0x630A,0x840B,0xB54D,0xAD4D,0x7C48,
0x29A3,0x1923,0x2143,0x1922,0x2122,0x2142,0x2162,0x2982,0x2963,0x2164,0x1944,0x2143,0x52A7,0x7B6C,0x628A,
0x4124,0x4942,0x5141,0x5121,0x5121,0x5942,0x4143,0x20E2,0x20E2,0x41C4,0x5AC2,0x4AC1,0x31A1,0x2941,0x2141,
0x2121,0x1922,0x1901,0x18E0,0x10E0,0x2963,0x2964,0xA9A4,0xFAE4,0xFAC4,0xD8C3,0xC883,0xE0C2,0xFA01,0xFA63,
0xF162,0xD8E3,0xF143,0xA8A3,0x4103,0x3A81,0x42C0,0x4AC3,0x6365,0x2142,0x1901,0x18E2,0x2102,0x5B25,0x6C06,
0x5343,0x3201,0x39E2,0xBDB1,0x8C4F,0x31E5,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,
0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xF6FB,0xFBCC,0xFB6A,0xFAE9,0xFB69,0xFB89,0xD145,
0xC8A5,0xD0E5,0xD8C4,0xF1C4,0xF1A2,0xE0C3,0xFAE5,0xFAA3,0xF183,0xE9A4,0xF224,0xE9A4,0xD1C6,0x8BA6,0x73E6,
0x42C3,0x4283,0x5265,0x39E4,0x31A4,0x3164,0x2123,0x2983,0x2143,0x39C5,0x7388,0x8C6A,0x8C6B,0x7BCA,0x7BC9,
0x83EA,0x8C2B,0xA4CD,0x944B,0x7BE9,0x8C4B,0x7BE9,0x8409,0x946D,0xAD6F,0x9CEA,0x9CEB,0x8409,0x7389,0x7BAB,
0x8C4B,0x5B25,0x31C3,0x4205,0x73A6,0x5343,0x3AC1,0x2202,0x1963,0x1103,0x2185,0x1944,0x2984,0x52C7,0x5B04,
0x6BA7,0x4A86,0x31A2,0x4A63,0x73A6,0x9CA9,0x9CEA,0x8C26,0x6B64,0x6344,0x31E2,0x1924,0x2143,0x2163,0x2163,
0x2162,0x2183,0x29C3,0x29A3,0x2142,0x31A4,0x6B8A,0x3A04,0x52E5,0x5246,0x49E7,0x3924,0x4963,0x4963,0x4963,
0x4183,0x4A04,0x4282,0x3220,0x4B00,0x63C1,0x63C1,0x42A0,0x1940,0x08C1,0x10E1,0x1101,0x1921,0x10E1,0x10E1,
0x1902,0x29E3,0x8A26,0xFA45,0xFA63,0xF1C3,0xC063,0xD8A2,0xE8A1,0xE8C1,0xF142,0xE922,0xE102,0xF963,0xF123,
0x80A3,0x18E2,0x2161,0x4281,0x3A01,0x4205,0x52C6,0x73E7,0x5B64,0x3AC1,0x3240,0x3A22,0x6B4A,0xAD31,0xD697,
0x4A47,0x3222,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,
0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,
0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xFD73,0xFC0A,0xFBEA,0xFBAA,0xFB07,0xFB07,0xF2A7,0xD0C5,0xD0A5,0xD884,0xD8C3,
0xC882,0xC882,0xF204,0xFA63,0xFA63,0xE9E3,0xE9E4,0xE205,0xF206,0xA326,0x6BC5,0x6384,0x4AC4,0x3A24,0x31C3,
0x4245,0x39E5,0x20E4,0x18E4,0x2123,0x31C4,0x6BA7,0x844A,0x842A,0x7BC9,0x83EA,0x944B,0x944B,0x944B,0x83EA,
0x944C,0xB56E,0x94C8,0x7C05,0x94AA,0x8447,0x7BC7,0x7BC8,0x7BE9,0x840B,0x6B47,0x4AA4,0x2984,0x2985,0x4245,
0x3A02,0x21C4,0x29A5,0x1943,0x29A4,0x3A43,0x31E4,0x29C3,0x52C5,0x8C88,0xADAD,0x9509,0x6383,0x6B67,0x7BAA,
0x41E3,0x41E3,0x5B23,0x4AA3,0x2983,0x1902,0x5288,0x52C7,0x2983,0x29C3,0x31E4,0x31C4,0x4224,0x39E5,0x6329,
0x6B87,0x5304,0x5324,0x1960,0x1101,0x2943,0x3985,0x6B48,0x4A25,0x39E2,0x52E2,0x29A0,0x5323,0x7C25,0x4283,
0x3A41,0x5B23,0x31C2,0x10A1,0x10E1,0x1902,0x1901,0x1101,0x10E1,0x10E1,0x10E2,0x1942,0x6183,0xD9A3,0xFA03,
0xF9C3,0xE942,0xD083,0xE0A2,0xE0A1,0xD882,0xD0A2,0xE922,0xF962,0xF963,0xD0C4,0xB8E4,0x6A22,0x63C2,0x84E4,
0x73E6,0x6BE6,0x5BA4,0x5302,0x5B61,0x6BA4,0x7C27,0x9D0C,0x9529,0x9528,0x7C66,0x5BA3,0x4AE2,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xF77D,
0xFC4D,0xFB49,0xFB49,0xFB69,0xFB89,0xFB68,0xFAC5,0xE125,0xEA07,0xF266,0xC883,0xA043,0xB063,0xB8E3,0xFAA4,
0xFA23,0xE9C3,0xF244,0xF225,0xFA46,0xB2C5,0x5B25,0x52E4,0x4263,0x3223,0x4284,0x4AE4,0x3A24,0x29A4,0x29C3,
0x31C4,0x4245,0x73C9,0x946B,0x8C2A,0x8C2B,0x8C0C,0xA4AE,0xACEE,0xA50C,0xA50B,0xAD6B,0x94A8,0x8407,0x83E7,
0x7367,0x6306,0x5B07,0x5B06,0x4244,0x3A03,0x29A2,0x31A3,0x31A3,0x29A4,0x1963,0x1943,0x2183,0x29A2,0x2182,
0x2182,0x29C2,0x5287,0x8C4C,0x9CCA,0xAD6A,0x94C6,0x6BC3,0x5BC0,0x8C4B,0x7BCB,0x5245,0x7B6A,0x7B6A,0x5229,
0x49C7,0x5247,0x73A7,0x3222,0x1923,0x2162,0x29A2,0x29A4,0x29A2,0x73E7,0x8466,0x3A61,0x2181,0x1902,0x2162,
0x2142,0x1943,0x3A25,0x5B25,0x3202,0x2A00,0x63A2,0x52E4,0x5B07,0x31C4,0x10C1,0x1922,0x2142,0x1942,0x1902,
0x18E1,0x1921,0x1901,0x1901,0x1101,0x10E1,0x08C2,0x4902,0xE9A4,0xFA03,0xF9E3,0xFA23,0xF122,0xD083,0xD882,
0xD882,0xD082,0xC882,0xF122,0xF122,0xC083,0xA064,0xA084,0xB9C3,0xE466,0xD488,0x8383,0x5362,0x63A4,0x7C44,
0x84E4,0x8CE6,0x7C64,0x5360,0x7424,0x7C07,0x3201,0x31E2,0x31E4,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,
0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xF73B,0xFC2C,0xFB8B,0xFB4A,0xFB69,
0xFB47,0xFB47,0xFAE6,0xF267,0xD164,0xD164,0xB0A3,0x9043,0x9083,0x7843,0xEA04,0xFA84,0xFA63,0xFAA5,0xFB05,
0xFAC4,0xBA45,0x5B46,0x4AC4,0x4AC4,0x4AC4,0x5B45,0x4AE4,0x3A44,0x3224,0x3203,0x3A44,0x5AE8,0x83CA,0x94AC,
0xAD2E,0xAD2D,0xA50C,0xAD4D,0xA50A,0x94C9,0x8408,0x83C9,0x842A,0x7BE8,0x7387,0x73A8,0x52A6,0x3A24,0x39E4,
0x31A3,0x39E3,0x31E3,0x31C3,0x29C4,0x2184,0x2144,0x2143,0x1922,0x2944,0x4A48,0x736C,0x8C4B,0xAD6C,0x9D08,
0x5B42,0x3A22,0x52A3,0x6443,0x3AA2,0x2924,0x31A5,0x4226,0x946A,0x9C8A,0xA48A,0xBD4B,0xA4C7,0x4222,0x18E2,
0x2143,0x2983,0x29A3,0x2161,0x29C1,0x3241,0x29A1,0x2984,0x2944,0x2144,0x2162,0x1941,0x1941,0x2983,0x1921,
0x10E1,0x29E0,0x3A62,0x31C4,0x2164,0x10C3,0x10C2,0x10C2,0x10E3,0x1922,0x1901,0x1901,0x1901,0x5AE8,0x31C4,
0x08C0,0x10C1,0x18C1,0xC144,0xF9E4,0xF9C2,0xF982,0xFA42,0xF0E2,0xD082,0xD082,0xD082,0xD082,0xC062,0xD0A2,
0xD0A2,0xA043,0x9063,0x9863,0xD9A4,0xFAC6,0xE984,0xE264,0xCBE5,0x73E1,0x5360,0x42C0,0x3AA0,0x29E0,0x6B67,
0xB593,0x630B,0x2123,0x1922,0x1962,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,
0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFBE,0xFC6E,0xFBCB,0xFC2B,0xFC2A,0xFBA8,0xFAE6,0xFAA6,0xF183,
0xD082,0xA044,0x9863,0x7843,0x6043,0x7043,0xF1C4,0xFA43,0xFA84,0xFAA4,0xFA85,0xFA64,0xB9C4,0x6387,0x63A7,
0x5B26,0x4AC4,0x3A64,0x3A63,0x31E4,0x3A25,0x5AC8,0x6309,0x83EB,0xA50E,0xBDCF,0x9D0A,0x9489,0x946A,0x8C0A,
0x8C0B,0x8C2B,0x7B89,0x6B67,0x73A8,0x83E9,0x83E9,0x52C7,0x31E5,0x5285,0x5AA6,0x4A85,0x4A83,0x4A43,0x3204,
0x29C4,0x1922,0x2144,0x4A48,0x6B4A,0x9CAD,0xAD8C,0x8CA6,0x5B61,0x3A42,0x21A3,0x1944,0x1924,0x4A87,0x4B04,
0x1924,0x10E3,0x1924,0x2986,0x39A5,0x5285,0x6B06,0x7B08,0x49A4,0x41E6,0x6B2A,0x5B08,0x2181,0x2981,0x2982,
0x2183,0x3184,0x4A06,0x4265,0x29C2,0x2160,0x1940,0x1922,0x2983,0x3A24,0x1902,0x29E2,0x2A01,0x1922,0x29A3,
0x1943,0x08C2,0x10E3,0x18E3,0x1902,0x1922,0x1923,0x29A1,0x2A01,0x3223,0x1960,0x10C2,0x10C2,0x8123,0xD8E5,
0xE124,0xF8E2,0xF102,0xF981,0xE0A2,0xC862,0xD081,0xD082,0xD082,0xC862,0xC062,0xD8C2,0xA043,0x9043,0xB8A3,
0xF224,0xF1E4,0xD123,0xF204,0xE1A4,0xA244,0x49E2,0x2960,0x3A00,0x4223,0x8C6C,0x4A67,0x2142,0x1901,0x1121,
0x1921,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xE7DF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,
0xEFFF,0xEFFF,0xEFFF,0xF5D5,0xFC8C,0xFC2B,0xFC2A,0xFBE9,0xFB68,0xF162,0xF961,0xF942,0xC083,0x8843,0x5063,
0x3862,0x7843,0xF964,0xFA44,0xFA44,0xFA45,0xF225,0xE9A4,0xB923,0x6B67,0x6367,0x5B26,0x5B07,0x5B27,0x52C7,
0x736A,0xA4ED,0x9D0A,0x8447,0x6B85,0x8429,0x8C6A,0x8C4B,0x840B,0x83EA,0x8C2B,0x8C0A,0x83E9,0x8C0A,0x8C0A,
0x8409,0x8409,0x7BCA,0x4225,0x5286,0x4A86,0x52A5,0x52C4,0x4AA3,0x4A83,0x4263,0x4205,0x732B,0xAD31,0xBE0E,
0x8CA6,0x5B43,0x4265,0x29A5,0x31E7,0x29A6,0x1943,0x2183,0x3204,0x42E2,0x3224,0x1943,0x2164,0x2186,0x1963,
0x1984,0x2164,0x2124,0x1924,0x52C8,0xB58E,0x73E4,0x31E2,0x2182,0x1941,0x31C2,0x29A3,0x3A23,0x6362,0x6BA3,
0x4225,0x1903,0x10E3,0x1904,0x29C4,0x1942,0x1102,0x1922,0x2162,0x1902,0x10C2,0x1081,0x10C1,0x10E1,0x2122,
0x31A3,0x2143,0x2123,0x4262,0x4242,0x10C2,0x18E3,0x10E3,0x38E2,0xE9A4,0xA885,0xD0C3,0xF8E2,0xF961,0xF941,
0xE0A2,0xD061,0xD861,0xD881,0xD881,0xC862,0xC062,0xA842,0x9842,0xA862,0xE9E3,0xFAE4,0xFA03,0xFA23,0xF1E4,
0xD144,0xB945,0xC208,0x61C6,0x4263,0x29A3,0x39E4,0x2982,0x2962,0x1901,0x1921,0x2141,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFDF,
0xFDB4,0xFC2B,0xFB69,0xFBAA,0xFA84,0xF9A1,0xF9E1,0xF981,0xF8E2,0xA843,0x4843,0x30E3,0x68E3,0xB123,0xD163,
0xD9A3,0xE1C4,0xD164,0xC123,0xD2A9,0xA4AC,0x9CCB,0xA50B,0x9CE8,0x8466,0x8C48,0x6BA6,0x52A5,0x3A43,0x3204,
0x3A46,0x7BEA,0x8C6A,0x948B,0x9CAD,0x948B,0x946B,0x8409,0x8409,0x8C2B,0x842A,0x73C8,0x840A,0x6307,0x5AC7,
0x7368,0x5B06,0x6326,0x5285,0x52A6,0x7BCB,0xAD30,0xAD6C,0x8CC6,0x6363,0x4243,0x3A06,0x2185,0x29A5,0x29A4,
0x52C6,0x94CC,0x52C9,0x31A6,0x5BA6,0x3AE2,0x2183,0x21A4,0x21A5,0x1943,0x1963,0x2184,0x21A5,0x21A4,0x29C2,
0x5303,0x42C1,0x3203,0x2164,0x2965,0x6B47,0x5B05,0x3202,0x31E3,0x29A3,0x4286,0x4A67,0x39C6,0x1904,0x1923,
0x1902,0x1903,0x18E2,0x1922,0x1901,0x31E2,0x1902,0x10C2,0x29A3,0x3222,0x3A63,0x52C4,0x2142,0x18C2,0x3163,
0x41E4,0x20E3,0x18C2,0x2143,0x99C5,0xF143,0x9844,0xB863,0xE8E2,0xF961,0xE8A2,0xD061,0xD861,0xD881,0xD881,
0xD081,0xC862,0xB842,0x9822,0xC081,0xF1C2,0xFB04,0xFA43,0xD943,0xC903,0xE183,0xB8E3,0xB904,0xFB08,0xAAC7,
0x39C2,0x1921,0x2142,0x3942,0x2922,0x1922,0x1921,0x2121,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFDF,0xFCD2,0xFB8B,0xFB8A,
0xF9E4,0xFA21,0xFA01,0xF962,0xE8C3,0xB063,0x5043,0x5863,0x80A3,0xA924,0xB9A4,0xB9C4,0xBA04,0xBA25,0xB9E4,
0xAB26,0x7BE6,0x6B65,0x8428,0x5B25,0x5305,0x6328,0x5AE7,0x3A46,0x1984,0x29A4,0x52C6,0x6B88,0x948B,0x9CCC,
0x948B,0x946B,0x8C4B,0x8C2A,0x8429,0x7BC8,0x6B87,0x6B67,0x7367,0x62E7,0x5A88,0x7BA9,0x7BC9,0x9CCC,0xAD6E,
0x9CEA,0xA529,0x8446,0x4AA1,0x21C0,0x2963,0x31A6,0x1944,0x1123,0x10E2,0x10E2,0x10E2,0x4245,0x3A06,0x4A88,
0x3AA4,0x1943,0x1943,0x2184,0x2185,0x2144,0x2185,0x29C3,0x29E2,0x29C1,0x2181,0x2162,0x2143,0x5A26,0x8C2B,
0x8466,0x7424,0x3A43,0x1942,0x4A87,0x52A9,0x1102,0x2143,0x2144,0x10E3,0x1101,0x1900,0x1902,0x10E2,0x1902,
0x10E1,0x1941,0x29C3,0x4144,0x79C5,0x79A3,0x5964,0x3122,0x2142,0x4A86,0x5B27,0x6BA6,0x6BA4,0x5B63,0x8385,
0xF2A6,0xF143,0xD0C4,0xC064,0xE0C2,0xF0E1,0xD881,0xD861,0xD861,0xD061,0xC861,0xC862,0xC062,0xA842,0xA842,
0xE101,0xFA62,0xE9A3,0xD0E3,0xB0A3,0xD123,0xC903,0x8864,0xB924,0xFA66,0x9185,0x2903,0x18E1,0x2102,0x2122,
0x1902,0x18E1,0x10E1,0x10E1,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,
0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEF9E,0xFEDB,0xE38E,0xF183,0xF9E2,0xF9C3,0xFA65,
0xE163,0xB863,0x7843,0x7843,0x9843,0xD0A4,0xFA05,0xFA45,0xFA46,0xEA05,0xE9C5,0xA9E4,0x6367,0x5B27,0x5B27,
0x5347,0x5B47,0x73E9,0x6B87,0x3224,0x21A4,0x29E5,0x52A7,0x6B89,0x94AA,0x8C8A,0x8C4A,0x840A,0x7BC9,0x8C0A,
0x83EB,0x73A9,0x7BAA,0x946C,0xA4EE,0xAD2E,0x94AB,0xA509,0xA528,0xA548,0x8465,0x6362,0x4AC1,0x4243,0x4203,
0x31C2,0x2985,0x1944,0x1104,0x1103,0x08C2,0x0881,0x3185,0x4228,0x29E7,0x3A27,0x1903,0x08E2,0x10E2,0x2944,
0x2984,0x29A3,0x29A2,0x2181,0x2161,0x2162,0x2163,0x1122,0x5267,0xA4EC,0x73E5,0x4A62,0x31A4,0x1102,0x1901,
0x4AA5,0x6B8B,0x1923,0x1921,0x10E2,0x10E2,0x2982,0x2142,0x3103,0x38C3,0x38E3,0x6143,0x6123,0x79C2,0xEA66,
0xFA26,0xFA26,0xF1E5,0xD1E5,0xD2E6,0xE3C7,0xEBC5,0xD302,0x9AC1,0x4241,0x9A03,0xF904,0xF123,0xF9C3,0xE904,
0xD863,0xD862,0xD061,0xD861,0xD061,0xC861,0xC862,0xC062,0xB862,0xB042,0xB842,0xC082,0xD0E2,0xB882,0xB0A3,
0xA883,0xB0C3,0x9863,0x8864,0xB0E4,0xC104,0x7044,0x30C2,0x2122,0x10E1,0x10C1,0x10C1,0x10C0,0x08A0,0x10C1,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,
0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xE75D,0xC22B,0xF267,0xFB46,0xFBC6,0xFBE6,0xFA64,0xC8C3,0x9044,0x9843,
0xB064,0xB863,0xE145,0xFA26,0xFAA6,0xF246,0xD1A5,0x7286,0x6C07,0x6367,0x6347,0x6367,0x6367,0x63A9,0x5B48,
0x3245,0x21A4,0x31C5,0x52A7,0x7BEA,0x8C6A,0x8C6B,0x9CAC,0x8C2C,0x9C8F,0xB54F,0xAD0D,0x9489,0x9D0B,0xAD8C,
0x9D0A,0x8446,0x6BA4,0x52E3,0x52E3,0x6B67,0x7388,0x4A65,0x4244,0x4223,0x39C4,0x2984,0x2143,0x18E3,0x18E3,
0x18E2,0x3185,0x83CE,0xAD12,0x5B0B,0x1964,0x10E2,0x3185,0x5AC9,0x73AA,0x6365,0x3202,0x29A2,0x29A2,0x29A3,
0x2984,0x29A3,0x31A4,0x31C4,0x9CEC,0x5B03,0x39E5,0x31A6,0x2964,0x2943,0x2103,0x4A86,0x9D10,0x1924,0x10E2,
0x10E2,0x10E1,0x2101,0x6144,0xDA05,0xEA46,0xE246,0xFA65,0xFAA6,0xFA45,0xFA63,0xFA84,0xFA84,0xFA64,0xFA84,
0xFAA4,0xFA83,0xFA43,0xF9E2,0xF9A3,0xBA45,0xDA46,0xE063,0xD083,0xF962,0xF9A3,0xF183,0xD862,0xD041,0xD061,
0xC861,0xC062,0xC862,0xB862,0xB862,0xB862,0xB062,0xA042,0x9843,0xA063,0xA063,0x9863,0x9064,0x9064,0x8884,
0x9884,0x8884,0x7844,0x8226,0x5B09,0x0881,0x0882,0x08A2,0x08A1,0x0080,0x2983,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,
0xF7FF,0xCCB4,0xD1A9,0xFC89,0xFC67,0xFC26,0xFBE6,0xFAC4,0xD0E3,0xD0A3,0xE0A3,0xC8A4,0xC906,0xE165,0xF1A6,
0xFA27,0xFA47,0xB286,0x4AC5,0x6BE7,0x6386,0x7BE8,0x8409,0x73C8,0x5327,0x4B07,0x3265,0x29A5,0x31E6,0x5AE8,
0x7BE9,0x9CAD,0xBD51,0xBD70,0xBDD2,0xC5F0,0x9CE9,0x7C04,0x73E5,0x8407,0x8408,0x7367,0x6B48,0x7348,0x5AE7,
0x4226,0x3A04,0x4A65,0x4225,0x3A25,0x39E4,0x31A3,0x2983,0x31A4,0x2985,0x2144,0x5247,0xAD11,0x842C,0x4225,
0x2163,0x52C9,0x7BCB,0xAD4D,0xA58A,0x6BE3,0x4262,0x29A3,0x2183,0x2164,0x2164,0x2183,0x1962,0x1941,0x6B68,
0x8448,0x2963,0x2985,0x31E5,0x29A4,0x31A4,0x31A4,0x2142,0x4A86,0x2123,0x08C2,0x10C2,0x31A3,0x92E9,0xFA26,
0xFA84,0xFAA4,0xFAC4,0xFAC4,0xFAC4,0xFAA3,0xFAA3,0xFA63,0xFA42,0xFA42,0xFA42,0xFA62,0xFA22,0xFA02,0xF9C2,
0xF9E2,0xFA43,0xF963,0xE063,0xD863,0xE082,0xF102,0xF143,0xC842,0xC841,0xD041,0xC842,0xC862,0xC062,0xB842,
0xB862,0xB063,0xA862,0x9843,0x9063,0x9043,0x9063,0x9063,0x9063,0x8863,0x8063,0x8063,0x8063,0x8884,0xAA27,
0x5A67,0x0881,0x08A2,0x08A2,0x0882,0x1902,0x10E1,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xF7FF,0xCB4F,0xE289,0xFCA7,
0xFC07,0xFBE8,0xFC2A,0xFAE5,0xF922,0xF923,0xD904,0xB0C6,0xB106,0xC9C7,0xC287,0xC247,0x9246,0x4245,0x4285,
0x5306,0x5B46,0x6B87,0x5B07,0x6328,0x5307,0x3A85,0x21C5,0x2164,0x5248,0x940F,0xBDB2,0xC612,0xB58D,0x8447,
0x8C48,0x8C49,0x8C2A,0x9C8C,0x840A,0x8C0A,0x7BA9,0x7BC9,0x7BC9,0x7BA8,0x5AE6,0x52A6,0x4245,0x4245,0x4245,
0x3A04,0x31C4,0x29A3,0x2983,0x2984,0x2983,0x2984,0x39E4,0x3A05,0x52C7,0x6B68,0x9CCC,0xA56B,0x7C25,0x4281,
0x2161,0x3184,0x2985,0x4227,0x29A5,0x1942,0x2162,0x1962,0x1942,0x1923,0x5AE7,0x73C6,0x2964,0x1903,0x2184,
0x3A26,0x3185,0x2124,0x2143,0x18E1,0x2923,0x4A26,0x6B88,0xA569,0xEBE8,0xFA25,0xFA24,0xFA44,0xFA63,0xFA63,
0xFA64,0xFA43,0xFA42,0xFA43,0xF9E3,0xF9E3,0xF9E2,0xF9C2,0xF9C2,0xF9C3,0xF9C3,0xF9E2,0xFA03,0xF964,0xE863,
0xE062,0xE062,0xD042,0xC063,0xC8A3,0xE081,0xD041,0xC841,0xC041,0xB842,0xB042,0xB062,0xA863,0xA043,0x9843,
0x9863,0x9042,0x8842,0x9043,0x8863,0x8063,0x8063,0x8064,0x90C4,0xA9C8,0xBA09,0x8986,0x3982,0x39C4,0x2143,
0x1922,0x0880,0x00A0,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,
0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xF6FA,0xE269,0xFBA8,0xFC67,0xFB89,0xFDB5,0xFE97,0xFB29,
0xF103,0xD105,0xB8C5,0xA8C5,0xA0C6,0xA0E7,0x6AA6,0x4B26,0x5307,0x3204,0x3204,0x4265,0x52E7,0x52E6,0x6366,
0x5B47,0x4266,0x29C5,0x4229,0x8BCF,0xD636,0xBDAE,0x8C67,0x8446,0x8C29,0xA4EC,0xA4CC,0x9CAB,0x944B,0x9C8C,
0x840A,0x8C2A,0x83E9,0x7BC8,0x7BA8,0x6B47,0x6307,0x5AE5,0x4A84,0x4A85,0x3A23,0x4244,0x3A04,0x3A04,0x29C2,
0x3A24,0x4A85,0x4A84,0x6347,0x9D0B,0xA54A,0x8CA5,0x73C3,0x6B24,0x7348,0x73CA,0x8C4B,0x9CCD,0x4265,0x3A24,
0x21A2,0x1962,0x1942,0x1943,0x1924,0x2144,0x4206,0x5B06,0x4243,0x2123,0x1962,0x31E6,0x29A4,0x08E2,0x3164,
0x5265,0xA4EC,0xA589,0x7C23,0xAAA1,0xF9E3,0xFA03,0xF9E3,0xFA03,0xF9C3,0xF9A3,0xF9A3,0xF983,0xF9C3,0xF9E3,
0xF9E3,0xF9A3,0xF983,0xF9C2,0xF9E2,0xF9C2,0xF983,0xF982,0xF9A3,0xF123,0xD023,0xD842,0xE042,0xD841,0xC042,
0xC0A3,0xF0E2,0xC021,0xC021,0xB841,0xB041,0xB042,0xA842,0xA862,0xA862,0xA042,0xA062,0x9022,0x9022,0x9042,
0x8842,0x8043,0x8043,0x8063,0x9925,0xB1A7,0xA946,0x80E5,0x39E2,0x6365,0x21A1,0x1100,0x08A0,0x0080,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7DF,0xEFFF,0xEFFF,0xEFFF,
0xEFFF,0xEFFF,0xEFFF,0xF574,0xFB27,0xFBA6,0xFC4B,0xFDD3,0xFCEE,0xFBE9,0xE1A4,0xC8C4,0xB8C4,0xB0C4,0xA8C5,
0xA0E6,0xA0E7,0x7226,0x5B66,0x4AC5,0x3A65,0x3A44,0x6B68,0x7BA9,0x7388,0x94C8,0x8C0A,0x8BCE,0xB573,0xC5F0,
0x9D09,0x6365,0x6B46,0x8C69,0x8C89,0x9CAC,0xACED,0xA4CD,0xA48C,0x946B,0x9CCC,0x944A,0x7BC9,0x7368,0x83A9,
0x7BA9,0x7388,0x6B47,0x52E4,0x4AA2,0x4263,0x3A42,0x4223,0x4A44,0x62E6,0x7BC9,0x9CEB,0x9D08,0x6362,0x6B85,
0x63A1,0x6361,0x6344,0x7388,0x948D,0xB5B0,0x840A,0x5B06,0x5B26,0x31E4,0x1963,0x1943,0x1904,0x1924,0x2165,
0x2184,0x2164,0x2123,0x2984,0x52C4,0x5B44,0x4283,0x4226,0x2164,0x1923,0x5B06,0x94C8,0x73E3,0x4AA2,0x69C3,
0xF1E5,0xFA24,0xFA64,0xFA64,0xFA23,0xF9C3,0xF9A3,0xF983,0xF963,0xF982,0xF9A3,0xF9C2,0xFA02,0xFA03,0xFA02,
0xFA02,0xF9E2,0xF963,0xF942,0xF963,0xF923,0xC823,0xC823,0xE062,0xE062,0xD022,0xB043,0xA842,0xB021,0xB821,
0xB821,0xB021,0xB041,0xB841,0xB041,0xA842,0xB062,0xA842,0x9821,0x9022,0x8842,0x8842,0x8843,0x8042,0x8043,
0x8884,0x8084,0x90A5,0x9964,0x2981,0x1140,0x1100,0x1921,0x2142,0x31C2,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xDFDF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xF77D,0xFBAC,
0xFBA9,0xFCAB,0xFCEB,0xFB87,0xFAA5,0xFC89,0xEAA6,0xC0C5,0xB8A4,0xB0C4,0xA8C5,0xA0E6,0xA106,0x5A45,0x5B46,
0x4AA6,0x29E4,0x3A44,0x3203,0x6B48,0x942D,0xBDB3,0xCE11,0xB5AC,0x94A7,0x5AC3,0x29A3,0x2985,0x4A86,0x7C27,
0x7C48,0x9CAB,0xB54E,0xAD0D,0x9CCC,0x9C6B,0x944B,0x83E9,0x83CB,0x944B,0x94AA,0x8407,0x52C3,0x4242,0x4242,
0x4223,0x4223,0x4A64,0x73AA,0x9CEB,0x94C8,0x8CA7,0x6383,0x4A62,0x29C1,0x31C3,0x4A47,0x738B,0x842D,0x9CCF,
0xCE74,0x73AA,0x31C4,0x3A23,0x52A5,0x2985,0x10C3,0x1903,0x1964,0x2185,0x2145,0x1923,0x1924,0x1923,0x2944,
0x31A5,0x3A44,0x52E4,0x5B05,0x39C3,0x2141,0x31C1,0x52C1,0x4A82,0x29C1,0xA9E4,0xFA66,0xFA85,0xFA64,0xFA24,
0xFA24,0xF9E3,0xF9C3,0xF9A3,0xF9A2,0xF9E2,0xF9E2,0xF9C2,0xF9E2,0xFA02,0xFA02,0xF9E1,0xF9A2,0xF962,0xF962,
0xF982,0xF962,0xD043,0xC003,0xD022,0xA042,0x9022,0x9023,0x9023,0xA821,0xB021,0xA821,0xA821,0xB041,0xB841,
0xA841,0xB042,0xA862,0x9842,0x8842,0x8842,0x8842,0x9042,0x9042,0x8022,0x7842,0x8063,0x8084,0xA0E5,0xA124,
0x20C2,0x08C0,0x10E0,0x29A1,0x4A82,0x4243,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,
0xE7FF,0xE7FF,0xE7FF,0xE7DF,0xEFDF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEEDB,0xFBE9,0xFC67,0xFC45,0xFB44,0xFAE6,
0xFC07,0xFAE4,0xD9A5,0xE1C6,0xC105,0xB0C4,0xA8C5,0xA906,0x8206,0x5305,0x6386,0x52E4,0x3203,0x4A87,0x83EE,
0xB551,0xBDAF,0xAD8A,0x8444,0x6BA4,0x6BA7,0x4265,0x29C5,0x2184,0x3205,0x7C08,0x7C07,0x8C4A,0xACEE,0xA4ED,
0xA4CD,0xA4ED,0xB56D,0xAD2B,0xAD4B,0x9D08,0x7403,0x5B22,0x5B04,0x52A5,0x5AC6,0x840B,0x9CAC,0xA52A,0x8CC6,
0x6381,0x5B23,0x4A64,0x4A26,0x6329,0x5B08,0x7BEB,0x94AB,0x7C09,0x7444,0x7C47,0x6B87,0x39E4,0x39E3,0x31A3,
0x1924,0x2144,0x2185,0x2986,0x1964,0x10E3,0x2104,0x3185,0x2964,0x2964,0x39C5,0x31A4,0x3183,0x31A3,0x2961,
0x2120,0x2981,0x4A82,0x4281,0x4240,0x6324,0xDA86,0xFA85,0xFA84,0xF9C3,0xF963,0xF982,0xF9A3,0xF9C3,0xF9C3,
0xFA02,0xFA02,0xFA02,0xFA02,0xF9C2,0xF9C2,0xF9E1,0xF982,0xF942,0xF962,0xF963,0xF9A2,0xF982,0xD843,0xC023,
0xA863,0x9023,0xA022,0x7022,0x7842,0x9802,0x9801,0xA001,0xA000,0xB021,0xA821,0xA841,0xA841,0xA042,0x9842,
0x9042,0x8842,0x9862,0xB8A2,0xB8A2,0xA883,0x8022,0x7863,0x8084,0x98E5,0x80C4,0x20E3,0x10E1,0x10E1,0x10E0,
0x08A0,0x08A1,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFDF,0xDFBF,
0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7FF,0xEEBA,0xFD73,0xFE97,0xF6FA,0xEF9E,0xEFFF,
0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xEFFF,0xFE77,0xFC05,0xFBC3,0xFB24,0xFB46,0xFC27,0xFB04,0xE163,0xE1E5,0xFAC5,
0xEA05,0xB126,0x91C9,0x6A06,0x5B86,0x6386,0x4AC5,0x6B6A,0xA4CF,0xBDAF,0xB58C,0x7C04,0x8446,0x8407,0x5B25,
0x6367,0x6BE6,0x3AA4,0x19A4,0x2184,0x4226,0x844B,0x8C8B,0xA50D,0xB58D,0xA50A,0xAD4A,0xAD69,0x94E7,0x8405,
0x73A5,0x7BA7,0x83C9,0x7BA8,0x7BC8,0x9C8C,0xAD4D,0xA569,0x94E4,0x7C44,0x6363,0x73C6,0x7BE7,0x73C6,0x9D0A,
0x9508,0x7C26,0x94C8,0x84C7,0x8487,0x6386,0x4244,0x31C4,0x29A3,0x31A4,0x31E5,0x29C5,0x2984,0x2143,0x1904,
0x1102,0x39E6,0x7BA8,0x7C27,0x52C6,0x3A04,0x31A3,0x2941,0x3182,0x31A3,0x39E5,0x52A5,0x73C4,0x6B83,0x6B25,
0x948A,0xC54C,0xFB27,0xFAA5,0xFAA5,0xFA24,0xFA04,0xF9E3,0xF9E3,0xFA03,0xFA03,0xF9E2,0xF9C2,0xF9A2,0xF9A2,
0xF982,0xF9A2,0xF9C1,0xF982,0xF962,0xF9A2,0xF9A2,0xF982,0xF922,0xD863,0xA823,0x8843,0xA822,0xB063,0x48A3,
0x5042,0x9822,0x9801,0xB021,0xA001,0xA001,0xA021,0xA821,0xA021,0xA841,0xA042,0x9042,0x9041,0xA862,0xD902,
0xD902,0xB8A3,0x8022,0x7842,0x8063,0x8863,0x7863,0x28E3,0x0903,0x1102,0x1100,0x08E0,0x08A0,0xD79F,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7FF,0xEF1C,0xF3ED,0xFB67,0xFC09,0xFCEC,0xFDB2,0xF6D9,0xF75D,0xEFDF,0xEFFF,
0xEFDF,0xFC09,0xFB21,0xFB03,0xFAE5,0xFBC6,0xFB84,0xFA23,0xF2C5,0xFB65,0xF283,0xF267,0xD30B,0x8CB1,0x42A7,
0x4AA6,0x8C2C,0x8C6D,0xBE0F,0xAD6A,0x6342,0x52A2,0x7C29,0x950A,0x7C26,0x6BC7,0x5B46,0x6BA8,0x52A6,0x4AA8,
0x5AC8,0x948C,0xBDD0,0xB5AC,0x94C7,0x9CC7,0x9CE9,0xA4EA,0x948B,0x8C2C,0x948D,0x8C4C,0x8C0A,0x9C8D,0xAD0F,
0xB58E,0xBE0E,0x9D2A,0x94AA,0x94A9,0x7C43,0x7C44,0x7424,0x6401,0x5BA1,0x5B62,0x6B85,0x7BE8,0x7BC9,0x6B28,
0x4225,0x39C7,0x29A5,0x29C4,0x31E4,0x31E4,0x31E4,0x29C3,0x39C4,0x39C5,0x39E5,0x52C4,0x5B04,0x4A83,0x39A1,
0x39C1,0x4A43,0x52A4,0x6B45,0x6344,0x4A44,0x8C0B,0x52A4,0x4A43,0x31A2,0x31A1,0x52E3,0x9222,0xFAA5,0xFA64,
0xFA24,0xFA04,0xFA23,0xFA63,0xFA43,0xFA22,0xF9C3,0xF962,0xF9A2,0xF9C2,0xF9A2,0xF982,0xF9A2,0xF9C1,0xF9A2,
0xF943,0xF982,0xF982,0xE0C3,0xF0E3,0xD863,0x9803,0x9002,0x8043,0x68C4,0x40E4,0x5022,0x6822,0x9022,0xB021,
0x9801,0x9801,0xA001,0xA001,0xA821,0xA021,0x9821,0x9821,0x9842,0x9842,0xC8C2,0xD0E2,0xA883,0xA082,0xA083,
0x9883,0xA0A3,0x8043,0x2882,0x08E3,0x1101,0x10C0,0x08A1,0x08C1,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,
0xE7DF,0xE7FF,0xEE79,0xFB48,0xFAE7,0xFB67,0xFB86,0xFBE7,0xFC69,0xFCEF,0xFE9A,0xEFBF,0xFB27,0xFA61,0xFA23,
0xFAA4,0xFB45,0xFA83,0xFB04,0xFB84,0xFA62,0xE182,0xD1A4,0xD205,0xCC4F,0x9D13,0xB592,0xC60D,0xBC65,0x7AC3,
0x41E5,0x29A5,0x5B26,0x8CA7,0x7404,0x7403,0x8488,0x4AE5,0x6B67,0xA4AF,0xAD4D,0x7BC5,0x6B45,0x7BE8,0x73C6,
0x840A,0xAD0D,0xB56E,0xAD4D,0x7BEA,0x52E7,0x83EA,0xBDB1,0xCE13,0xC611,0xB5AB,0xAD4C,0xA52E,0x9CED,0x7BE9,
0x6BA7,0x6364,0x4AA2,0x3A04,0x3223,0x3223,0x29A3,0x2983,0x2962,0x1922,0x1103,0x18E4,0x31A6,0x29A5,0x2162,
0x2162,0x2162,0x2982,0x2981,0x31A2,0x41C3,0x3183,0x31A1,0x4203,0x41E4,0x41E5,0x4A65,0x52A6,0x4A65,0x4A86,
0x4A24,0x5A66,0x8C2A,0x39C2,0x2101,0x2121,0x4203,0x52E8,0xB206,0xFA65,0xFA23,0xFA03,0xF9C3,0xF9E3,0xFA22,
0xF9E3,0xF9A2,0xF923,0xF963,0xF9C2,0xF9E1,0xF9C2,0xF923,0xF922,0xF962,0xF942,0xF922,0xF943,0xF903,0xC063,
0xF0C3,0xD863,0x9003,0x9023,0x7063,0x60E4,0x2863,0x3822,0x5822,0xA043,0xB022,0xB021,0x9801,0x9001,0xA001,
0xA020,0xA020,0xA021,0x9821,0x9821,0x9821,0xB081,0xF141,0xF161,0xF9E2,0xF1C2,0xF1E3,0xD164,0x7843,0x2082,
0x08A1,0x10C0,0x08A1,0x08C1,0x10C1,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7FF,0xE77E,0xEBCD,
0xFB48,0xFBA7,0xFBC6,0xFB26,0xFB66,0xFBA5,0xFC07,0xFCED,0xFAE7,0xF981,0xFA03,0xFB04,0xFAA3,0xFA83,0xFB03,
0xF221,0xD961,0xD183,0xE245,0xF283,0xFAE4,0xC4A7,0xABA6,0xA9C4,0xFA45,0x99A3,0x29E4,0x3A24,0x3204,0x6BC4,
0x6C04,0x5323,0x6364,0x4A84,0x83EA,0xAD2C,0x7348,0x62C8,0x7348,0x842A,0x7C28,0x8C2A,0xAD2D,0xAD6E,0x8C6A,
0x6307,0x734B,0xB510,0xB5CD,0xA549,0xADAB,0xAD8A,0x9CAB,0x946C,0x7BA7,0x7385,0x7BE6,0x6B84,0x52C2,0x4263,
0x4243,0x3A22,0x2982,0x2142,0x5246,0x6B87,0x6BC6,0x18E4,0x2125,0x2145,0x2142,0x2162,0x2162,0x2982,0x2961,
0x31A2,0x39E4,0x3A05,0x6346,0x4A65,0x31E5,0x29A4,0x1943,0x2984,0x31E7,0x2984,0x31A4,0x3162,0x2121,0x4A63,
0x52A3,0x2963,0x2983,0x5AA5,0xDA66,0xF9E4,0xF9A3,0xF983,0xF9C3,0xF9E3,0xF163,0xD8E3,0xE0C3,0xF143,0xF983,
0xF9C2,0xF9A2,0xF942,0xF923,0xF903,0xF103,0xF0E3,0xF902,0xF903,0xF8E3,0xF0C3,0xE8A3,0xE063,0x7823,0x6105,
0x68C4,0x50E4,0x2862,0x3822,0x4002,0x9042,0xB862,0xE081,0xB821,0x9001,0x9801,0x9800,0x9801,0x9001,0x9021,
0x9841,0x9842,0x9842,0xD902,0xFA21,0xFA22,0xF9E2,0xF1C2,0xA883,0x4882,0x10C2,0x08A1,0x0880,0x08A1,0x10E2,
0x0881,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xCB6E,0xC127,0xD1A7,0xE206,0xEA66,
0xFBA7,0xFBC6,0xFB25,0xFAC4,0xFAC3,0xF9A2,0xF982,0xFA63,0xFAE4,0xFAE2,0xFA61,0xE9A1,0xFA62,0xF243,0xEA03,
0xF223,0xF243,0xEA22,0xC105,0xC8E5,0xF1A4,0xC1A3,0x29A4,0x2163,0x52C8,0x8C87,0x83A3,0x42A1,0x5323,0x5B05,
0xB52E,0x946A,0x5AE6,0x4A67,0x5286,0x7BC8,0x8C6A,0xA4CD,0xAD2B,0x8BCB,0xA4B2,0xCE15,0xB58D,0xA569,0xA529,
0x8C68,0x8C69,0x62C5,0x5A26,0x838B,0x7BE7,0x7C06,0x8426,0x7BE5,0x5AE3,0x4A82,0x3A22,0x4243,0x736A,0x8429,
0x7C24,0xAD8A,0x73E6,0x20E4,0x18C4,0x2124,0x2142,0x2962,0x2981,0x29A2,0x31C2,0x3A04,0x31E4,0x2984,0x29A4,
0x1103,0x1123,0x1943,0x2183,0x31E4,0x39E5,0x2922,0x2962,0x2162,0x3184,0x4A06,0x4A85,0x4284,0x29E3,0x41C3,
0xE1E4,0xF9E4,0xF9C4,0xF9C3,0xF983,0xF103,0xD8C3,0xC883,0xD8C3,0xF102,0xF962,0xF982,0xE0C2,0xD882,0xE8C2,
0xF942,0xF963,0xF963,0xF962,0xE0C3,0xC884,0xF0C3,0xD883,0xD043,0x9803,0x5822,0x6022,0x4822,0x2021,0x2022,
0x2801,0x7022,0x9022,0xA021,0xB021,0x8801,0x8001,0x8801,0x9021,0x8801,0x9021,0x9821,0x9822,0x9822,0xB082,
0xE962,0xD942,0xD943,0xD0E2,0x9843,0x28A1,0x08C2,0x08A1,0x0882,0x0882,0x0881,0x1082,0xCF9F,0xD79F,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFBF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE79E,0xD2EC,0xC147,0xC167,0xC947,0xD986,0xE1A6,0xEA26,0xFAE5,0xFA43,
0xE943,0xD8E3,0xD8A3,0xFAA6,0xFBA5,0xFA62,0xE181,0xE9A2,0xE9A2,0xD942,0xD163,0xD983,0xD184,0xD185,0xF1E6,
0xF226,0xF184,0xE1A4,0x39C5,0x2164,0x31C5,0xAB88,0xFCAC,0x7B05,0x5304,0xA50A,0xA46B,0x9489,0x6B26,0x39A6,
0x6B0B,0xA4CE,0x944A,0x9C6D,0xB570,0xB56E,0xAD2D,0xAD2D,0xC62F,0x8449,0x6347,0x5285,0x4A04,0x4164,0x6268,
0x8C2A,0x946A,0x8C48,0x8426,0x7BC5,0x52C4,0x5AA4,0x944C,0xA50C,0x9507,0x6BC4,0x6327,0x5B08,0x29A4,0x1903,
0x18E3,0x2985,0x2963,0x29A3,0x2983,0x2163,0x1943,0x08E2,0x08C2,0x10E3,0x1103,0x1924,0x2144,0x2943,0x2962,
0x2941,0x2962,0x2983,0x2164,0x1943,0x1923,0x2123,0x2124,0x2965,0x29A5,0x5985,0xF1C4,0xF9C4,0xF9E3,0xF983,
0xE0C3,0xB864,0xB064,0xC883,0xF0E2,0xF902,0xF0E2,0xD8A3,0xC883,0xD083,0xE082,0xE8A2,0xF0C3,0xF0C3,0xD0A3,
0xC083,0xC063,0xD883,0x9843,0x8043,0x9803,0x8003,0x7003,0x5002,0x2801,0x1801,0x1001,0x5021,0x9022,0x8801,
0x8001,0x7001,0x7801,0x8001,0x8801,0x8821,0x9821,0x9821,0x9021,0x9042,0x9042,0x9042,0xA083,0xC923,0xB8A4,
0x7862,0x3982,0x2122,0x2122,0x2963,0x31C2,0x52A3,0x5AC3,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,
0xE7DF,0xE7BF,0xE34D,0xC967,0xC167,0xD166,0xD166,0xD946,0xD925,0xD925,0xE9C4,0xE163,0xC063,0xD9E7,0xFC26,
0xE202,0xE982,0xE142,0xD102,0xC903,0xC943,0xD144,0xD144,0xC964,0xE287,0xFAC6,0xFAE6,0xFA24,0xD924,0x49C5,
0x4A48,0x944D,0xE42A,0xFD90,0xDBA9,0x8BE7,0xB56D,0xAC6D,0xACEF,0x9C6C,0xBD52,0xC5B2,0xBDAE,0xB58C,0xC5EF,
0xAD4A,0x9467,0xA4EC,0xB5AE,0x7BA8,0x41C4,0x3143,0x2943,0x3143,0x5206,0x8C0C,0x9CAB,0x9CAA,0x8407,0x7BA6,
0x83C8,0x842A,0x6345,0x9508,0x6343,0x3A01,0x2183,0x2183,0x1122,0x1102,0x1122,0x1904,0x2124,0x2163,0x1923,
0x1103,0x1103,0x10E3,0x10E2,0x1903,0x1923,0x1923,0x2163,0x2962,0x2941,0x2121,0x2965,0x29A5,0x1944,0x1123,
0x1123,0x1123,0x1922,0x1122,0x1903,0x1123,0x6123,0xF984,0xF983,0xF943,0xD8A4,0xA843,0xB064,0xB864,0xC883,
0xD883,0xD082,0xC862,0xC043,0xD083,0xF0E2,0xF0C2,0xF0A2,0xE083,0xD884,0xE0A3,0xD883,0xB864,0x7064,0xA823,
0x9003,0x7023,0x6022,0x7862,0x6062,0x4021,0x2001,0x0801,0x3021,0x9822,0x8802,0x8001,0x7001,0x7001,0x7801,
0x8001,0x8821,0x8821,0x8822,0x8822,0x8842,0x8842,0x8022,0xC103,0xE984,0xA883,0x8283,0x73C3,0x6B62,0x6342,
0x6381,0x6BC1,0x7402,0x7402,0xCF9F,0xCF9F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE77E,0xFBEC,0xE1E7,
0xC987,0xD166,0xE185,0xE165,0xE145,0xE144,0xD904,0xD8E4,0xD986,0xFC67,0xDA42,0x9823,0xB8A3,0xE9C3,0xE9E3,
0xE1C3,0xE224,0xEA63,0xF284,0xFB67,0xFC48,0xFB05,0xFAE6,0xFAC5,0xD8C3,0x6184,0x5288,0xBB89,0xFCAA,0xFCCD,
0xFBC8,0xE3C7,0xA4CB,0x9CAC,0xBD2F,0xA4AC,0xB5AC,0xA549,0x8465,0x8444,0x8C47,0xA4AA,0xACEA,0xA4A8,0x6B24,
0x2922,0x2923,0x3943,0x3964,0x5227,0x8BEC,0xA4CD,0x9C8B,0x9CAA,0x9489,0xA50B,0xB5AB,0x9D29,0x4AA2,0x4261,
0x3222,0x31E3,0x2162,0x1943,0x1964,0x1143,0x1123,0x1103,0x1123,0x1123,0x1102,0x1102,0x1103,0x1923,0x1923,
0x2164,0x3183,0x2962,0x2941,0x1902,0x2123,0x1924,0x1944,0x1943,0x1943,0x1942,0x1963,0x1963,0x1942,0x1921,
0x1922,0x10E2,0x48E2,0xE8E3,0xF0A3,0xD883,0xA844,0x9843,0xA044,0xC884,0xF903,0xF922,0xE0A2,0xC843,0xC063,
0xF0E2,0xF922,0xF922,0xF8E2,0xD063,0xE0A3,0xF8E2,0xC063,0x5843,0x3864,0x9823,0x8083,0x70E6,0x5945,0x7183,
0x6142,0x40E2,0x41A6,0x1883,0x2021,0xA022,0x9001,0x8001,0x7001,0x7001,0x7801,0x8001,0x8001,0x8021,0x8021,
0x8822,0x9042,0x8842,0x8822,0xC0C2,0xC0E4,0x78A2,0x4220,0x3A20,0x7BA4,0x31E0,0x3A20,0x6304,0x2980,0x29A0,
0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,
0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7FF,0xEEBA,0xFBCA,0xF2C7,0xD187,0xD986,0xE165,0xE185,
0xE165,0xE964,0xE144,0xE0E4,0xFAA6,0xDA43,0x9022,0x7063,0x8043,0xD983,0xFA83,0xFB44,0xFB64,0xFB03,0xFBC6,
0xFCA9,0xFBE6,0xFA44,0xFAA5,0xFAA4,0xF962,0x9904,0x49A6,0xDB8A,0xFCCB,0xFD2E,0xF3E8,0xD3E7,0xAD0A,0xAD6B,
0x8C86,0x7404,0x4AA1,0x4A05,0x72E8,0x7B68,0x83C8,0x8C08,0x944A,0xA48D,0x946C,0x83AB,0x7B4A,0x7309,0x9C2D,
0xACCD,0xA4CA,0xAD6B,0xAD69,0xA548,0x8484,0x7C03,0x6383,0x5B02,0x4A83,0x4A83,0x3A44,0x31E6,0x29C5,0x21A5,
0x2186,0x1965,0x1944,0x1944,0x1944,0x1943,0x1122,0x1943,0x2163,0x2963,0x2963,0x2942,0x2142,0x2943,0x2965,
0x1924,0x1923,0x2983,0x2983,0x2163,0x2162,0x2163,0x1942,0x1942,0x1922,0x1122,0x1902,0x1102,0x40E2,0xE0C3,
0xF0C3,0xE0C3,0xC884,0xB864,0xB884,0xF122,0xF942,0xF962,0xF943,0xF903,0xF942,0xF942,0xF8E2,0xF8E2,0xE8C2,
0xE0C3,0xF902,0xE8C3,0xC864,0xA043,0x9023,0x8043,0x40C4,0x38E4,0x30E5,0x38C3,0x4122,0x30E2,0x28E3,0x1862,
0x1821,0xA842,0xA002,0x8001,0x7001,0x6801,0x7001,0x7801,0x8001,0x8001,0x8002,0x8822,0x8022,0x8843,0x8843,
0x9063,0x80E2,0x3141,0x1901,0x10E0,0x4A04,0x2943,0x1901,0x2121,0x18C1,0x10A1,0xCF9F,0xD79F,0xD79F,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFBF,0xDFBF,0xDFDF,
0xDFDF,0xDFDF,0xE7DF,0xDFFF,0xEE99,0xFC0B,0xF328,0xD166,0xD966,0xE165,0xE165,0xE145,0xE125,0xD8E4,0xE125,
0xE1E5,0x9863,0x7043,0x5863,0x5823,0xA8E4,0xFAE4,0xFB24,0xFAC3,0xFB25,0xFC48,0xFB86,0xEA03,0xE9C4,0xFAC8,
0xFB6A,0xF3EC,0xD4EF,0xB54D,0xCD6B,0xBD29,0x9C65,0x93E3,0x9382,0x7B23,0x5A84,0x4A24,0x42C4,0x2184,0x2986,
0x52A8,0x7BEA,0x8C6A,0x9CAB,0xAD4D,0xAD4D,0x94AB,0xA4AD,0xBD2F,0xC5EE,0x9D27,0x9CA7,0x83E5,0x8C48,0x83E8,
0x7386,0x6B65,0x73E5,0x5B24,0x6306,0x8C8C,0xA550,0x532B,0x428A,0x3A69,0x3A69,0x3A69,0x3A29,0x2986,0x1944,
0x1943,0x1943,0x2163,0x2983,0x2942,0x2121,0x2942,0x2163,0x2984,0x31C4,0x31E4,0x29A3,0x2983,0x2163,0x2163,
0x1943,0x1943,0x1942,0x1943,0x1942,0x1942,0x1922,0x1902,0x1101,0x30E1,0xD903,0xE8E4,0xD0A3,0xC884,0xB864,
0xE8E3,0xF942,0xF903,0xF0C3,0xF0E2,0xF923,0xF143,0xD0A3,0xB063,0xB042,0xC862,0xF0E2,0xF0C3,0xA844,0xA844,
0xC043,0xC023,0x8043,0x2883,0x2083,0x4146,0x4166,0x30C1,0x28A1,0x2061,0x1882,0x1042,0xA042,0xA802,0x8001,
0x6801,0x5801,0x6801,0x7001,0x7801,0x7801,0x8022,0x8022,0x8022,0x8843,0x8843,0x8842,0x7881,0x40A1,0x10C1,
0x08A1,0x4244,0x31A5,0x10C1,0x08C0,0x1101,0x08C1,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xE7DF,0xE7DF,0xE7FF,
0xF658,0xFCAB,0xFC6A,0xE206,0xD146,0xD966,0xD966,0xD945,0xD924,0xC8A4,0xF2A8,0xDA46,0x7843,0x6043,0x3862,
0x3862,0x8084,0xB8E4,0xB904,0xD9A4,0xFB66,0xFB65,0xF263,0xE307,0xEDB3,0xDE33,0xB4CA,0xB448,0xCC68,0xDBE6,
0xDBA6,0xE3A8,0xE263,0xE204,0xF1E4,0x9A05,0x4A45,0x39E5,0x3A64,0x1984,0x1945,0x6329,0x8C8B,0x8C8A,0xA50C,
0xAD4C,0xA52C,0xA4ED,0xBD50,0xCE31,0x5AC2,0x62E5,0x8BEA,0x8BCA,0x8408,0x83E7,0x83C8,0x73A6,0x6B86,0x5304,
0x6B08,0xB570,0x7C2C,0x4289,0x3228,0x3206,0x31E6,0x31C5,0x39C6,0x39C6,0x39C6,0x2144,0x2982,0x31A0,0x2981,
0x2983,0x31C3,0x31A3,0x2983,0x2983,0x2142,0x1943,0x1923,0x1943,0x1943,0x1942,0x1942,0x1943,0x1943,0x1123,
0x1123,0x1903,0x1943,0x1102,0x1922,0x2942,0xC1A5,0xE0C3,0xC883,0xB064,0xC8A4,0xF103,0xE0C3,0xB863,0xA843,
0xA843,0xB042,0xA043,0x9023,0x9023,0xA822,0xB822,0xD882,0xB862,0x7823,0x9843,0x8843,0xA024,0x6043,0x2063,
0x18A3,0x3945,0x30E4,0x3902,0x3102,0x2061,0x1883,0x2042,0xB862,0xA001,0x8001,0x7001,0x5801,0x6001,0x6801,
0x7001,0x7802,0x7802,0x7821,0x8042,0x8842,0x9041,0x9041,0x9841,0x9861,0x5882,0x10C2,0x31E3,0x1903,0x10A1,
0x1922,0x1101,0x08C1,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFBF,0xDFDF,0xE7DF,0xE7DF,0xDFFF,0xEEBA,0xFCAC,0xFCCA,0xF286,
0xD146,0xD966,0xD946,0xD945,0xD105,0xC8C6,0xFC0B,0xD246,0x7042,0x6843,0x4062,0x38C2,0x60C2,0x7102,0x7922,
0x7922,0x89A3,0x89A3,0x89A3,0xA265,0xBB66,0xCA83,0xE2A5,0xFC4B,0xEA67,0xE964,0xFB66,0xFAA3,0xF9C2,0xE9A3,
0xE9C5,0xA9E4,0x4A63,0x4263,0x3245,0x2A04,0x29C4,0x6B69,0x8C4B,0x8C6A,0x9CCC,0xAD4C,0xA52C,0xA4AC,0xD652,
0xA4EC,0x7AE7,0x8BEB,0x942A,0x7BA7,0x6BA5,0x73C6,0x7BC7,0x73A6,0x73A6,0x6344,0x5A87,0x52A6,0x4AA7,0x2A27,
0x29E6,0x29C5,0x29A4,0x31A4,0x31A4,0x31A4,0x39C5,0x3164,0x3182,0x39C2,0x31A3,0x2963,0x2163,0x1923,0x1903,
0x1103,0x1103,0x1103,0x1923,0x1942,0x1942,0x1922,0x1123,0x1102,0x1123,0x1103,0x1103,0x1924,0x2142,0x4243,
0x52C4,0x3A23,0x91A4,0xC884,0xB863,0xA843,0xA863,0xA043,0xA044,0xA044,0xA043,0x9823,0x9002,0x9022,0xA043,
0xB863,0xD882,0xE082,0xE062,0xB043,0x9023,0x9824,0xA044,0xB044,0xA023,0x4063,0x18A3,0x3104,0x30C4,0x4164,
0x3965,0x1841,0x1042,0x1822,0x9043,0x9001,0x8001,0x7001,0x4801,0x5001,0x6001,0x6801,0x7001,0x7801,0x8021,
0x8042,0x8842,0x9041,0x9041,0x9041,0xA882,0xC8C2,0x70C3,0x18E3,0x10E2,0x10C1,0x10E1,0x08C1,0x10E1,0xCF9F,
0xD79F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFFF,0xEEFB,0xFCED,0xFD0B,0xFB88,0xD166,0xC967,0xC946,0xD126,
0xC0E5,0xC927,0xFC0C,0xC1A5,0x8042,0x6863,0x4062,0x2882,0x6083,0x88C3,0x88E3,0x9104,0x9104,0xA104,0xB144,
0xD9C4,0xD943,0xE9C7,0xFC8D,0xEB69,0xD042,0xE9C5,0xFB64,0xFAE3,0xFA82,0xFAA4,0xFAA4,0xB1A4,0x41C4,0x39E3,
0x42A5,0x4AE7,0x3225,0x5AE8,0x946B,0x94AB,0x9CCB,0xA4EC,0xA50D,0x9C8C,0xCDF0,0xB54C,0x9C2B,0x8C09,0x8C29,
0x9449,0x7BE6,0x7BE7,0x7BC6,0x7BC6,0x6364,0x52C4,0x62A7,0x41C6,0x29A5,0x29E6,0x29C5,0x29C4,0x29A4,0x29A4,
0x31A4,0x39C4,0x39E5,0x2184,0x1923,0x1943,0x1123,0x08E2,0x1103,0x1103,0x1123,0x1123,0x1943,0x1943,0x1963,
0x2143,0x1122,0x0902,0x10E2,0x1923,0x2144,0x2164,0x2182,0x3201,0x3201,0x4243,0x29A3,0x1923,0x68E4,0x9864,
0x9044,0x9843,0x9823,0x9843,0x9843,0x9843,0x9022,0x9023,0xA042,0xA863,0xD0A3,0xF102,0xF922,0xF922,0xE8C2,
0xA843,0x9824,0x9823,0x9044,0xC084,0xD043,0x9843,0x40A3,0x28C4,0x3883,0x3842,0x2021,0x1021,0x1821,0x1821,
0x6022,0x9002,0x8001,0x6001,0x4001,0x5001,0x6001,0x6801,0x7001,0x7801,0x8021,0x8042,0x8842,0x8841,0x8841,
0x8841,0x9862,0xB881,0xC0C2,0x68C3,0x1922,0x2182,0x1901,0x10E1,0x18E2,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFBF,0xDFBF,0xDFDF,
0xDFDF,0xDFDF,0xDFFF,0xEEFB,0xFD0D,0xFD4C,0xFC6A,0xD9C7,0xD187,0xC966,0xC926,0xB8C5,0xD9E9,0xFC4D,0xB965,
0x7843,0x7063,0x6063,0x3842,0x6843,0xB0C5,0xB904,0xB105,0xB925,0xB925,0xB924,0xB944,0xC987,0xFD73,0xF3A9,
0xE0A3,0xE103,0xFBA6,0xFAE3,0xFA23,0xFA22,0xFA62,0xF1A2,0xA923,0x39A5,0x31C4,0x4B06,0x4B27,0x3A46,0x5B08,
0x948B,0x948A,0x948A,0x948A,0xA4EC,0xA4AC,0xB4EE,0x9CEA,0xACCC,0x9409,0x8408,0x8C49,0x8408,0x7BE8,0x7BC7,
0x6B86,0x5B24,0x52E4,0x5247,0x2945,0x2184,0x29A5,0x29C5,0x29C4,0x29C4,0x31A4,0x31E5,0x31E5,0x2184,0x1943,
0x1103,0x1103,0x1122,0x1102,0x1102,0x1122,0x1144,0x1944,0x1964,0x1944,0x1104,0x18E3,0x2164,0x31C5,0x2983,
0x31A3,0x31E4,0x2162,0x2982,0x2163,0x1923,0x1903,0x29A4,0x21A4,0x5904,0x8865,0x8065,0x8044,0x9043,0x9043,
0x8843,0x8823,0xA883,0xD902,0xE903,0xF122,0xF942,0xF942,0xF942,0xF102,0xB883,0x8823,0xA043,0xB043,0xC883,
0xD883,0xE063,0xE063,0xA823,0x6823,0x6022,0x3002,0x1001,0x2001,0x2801,0x2001,0x5822,0x9802,0x8001,0x5801,
0x4801,0x5001,0x6001,0x6801,0x7001,0x7821,0x8022,0x8042,0x8842,0x8841,0x8841,0x8821,0x9042,0x9842,0xA882,
0x90A2,0x30C2,0x1103,0x1923,0x1903,0x1903,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xE7BF,
0xFDD5,0xFD0C,0xFCCB,0xDA07,0xC987,0xC946,0xC905,0xC0C5,0xD187,0xFBAC,0xA965,0x7043,0x7063,0x6863,0x5043,
0x6043,0xA0A4,0xB904,0xB125,0xB125,0xB125,0xB145,0xB104,0xD249,0xF40B,0xD8C2,0xF8A3,0xD984,0xFB02,0xF161,
0xE102,0xE102,0xE122,0xE122,0x6904,0x3985,0x39A5,0x3A86,0x4286,0x3A26,0x52A7,0x840A,0x94AA,0x9CCA,0x9CAB,
0xA50C,0xB52D,0xBD0F,0x83CA,0x73A7,0x7BA8,0x8BEA,0x946B,0x8C4A,0x8408,0x73A7,0x6B86,0x6326,0x5B05,0x4A26,
0x2105,0x2164,0x29C5,0x29E5,0x29C5,0x29C5,0x3A07,0x4207,0x2165,0x1943,0x1163,0x1923,0x1103,0x1103,0x1102,
0x0902,0x1102,0x1924,0x2984,0x3A26,0x4225,0x52A5,0x6B88,0x7BE8,0x6B46,0x31C2,0x1921,0x31A5,0x3A06,0x4A67,
0x4A47,0x1923,0x1943,0x3A03,0x29C4,0x4904,0xA085,0x9064,0x9884,0xA083,0x9064,0x9043,0xC8C3,0xF982,0xF962,
0xF123,0xF922,0xF922,0xE923,0xD0A3,0xA843,0x8843,0x8823,0x9843,0xA044,0xB043,0xC044,0xA864,0xA044,0x9023,
0x7823,0x4022,0x1821,0x2801,0x2802,0x3021,0x30A3,0x6843,0xC842,0x9801,0x5001,0x4801,0x5801,0x6001,0x6801,
0x7022,0x7822,0x8042,0x8042,0x8842,0x8841,0x8841,0x8821,0x9042,0x8841,0x8861,0x9863,0x6882,0x10C3,0x10E2,
0x08C1,0x08A0,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xE7BF,0xFD72,0xFCCB,0xF328,
0xD9A7,0xC9AA,0xBA0B,0x88E5,0xA0E6,0xE28A,0xA145,0x7063,0x7063,0x6063,0x5063,0x6843,0x9864,0xB0E4,0xB105,
0xB125,0xB125,0xB925,0xB925,0xC9A6,0xB8C4,0xC062,0xB863,0xB8E3,0xF9A2,0xE922,0xE922,0xD902,0xD8E2,0xB965,
0x5228,0x39A6,0x41E6,0x39C6,0x3A25,0x2A06,0x5B08,0x94AA,0x94CB,0xA4EC,0xA4EC,0xAD2C,0xAD2C,0xA4CC,0xACCD,
0x83CA,0x52A7,0x4225,0x5AC7,0x7368,0x7368,0x62E6,0x5AC5,0x6B07,0x7369,0xA52D,0x4A27,0x2144,0x3227,0x3A48,
0x4268,0x6B6A,0x9C8E,0x8C4D,0x736B,0x31C6,0x1123,0x1123,0x1103,0x08E3,0x08E3,0x1923,0x31E5,0x7BEC,0x8C4B,
0x73E6,0x4AC3,0x4223,0x31A3,0x31C5,0x2123,0x10C2,0x39E5,0x7BEA,0x6347,0x52E5,0x29A3,0x3183,0x2164,0x2184,
0x1943,0x38E3,0xC0C5,0xF124,0xF983,0xF9A3,0xF9A4,0xF9A3,0xF9C2,0xF982,0xF123,0xF943,0xF123,0xC883,0x9843,
0x9843,0x9043,0x8843,0x9023,0x9823,0x9024,0xB044,0xB844,0x7864,0x8824,0x8823,0x4843,0x2843,0x1822,0x2822,
0x2822,0x3022,0x2863,0x7043,0xF0A2,0xC022,0x5001,0x5001,0x5801,0x6801,0x7021,0x7022,0x7822,0x8042,0x8842,
0x8842,0x8842,0x8042,0x8021,0x8041,0x8841,0x8862,0x9882,0x8082,0x1861,0x00A0,0x1121,0x29C2,0xCF9F,0xCF9F,
0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,
0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE79E,0xF679,0xFE58,0xF619,0xEF1F,0x8CD3,0x28A5,
0x9928,0xB188,0x9905,0x8063,0x7063,0x6043,0x5843,0x8043,0xA063,0xA8A4,0xB105,0xB125,0xB925,0xB125,0xB145,
0xB8A3,0xA043,0x8863,0x7023,0xC0C3,0xFA02,0xFA22,0xE9A1,0xE102,0xD0A2,0xAAA9,0x73CC,0x4247,0x52A7,0x4266,
0x29E5,0x3226,0x5B28,0x8C8A,0xA50C,0xB54D,0xAD2B,0xA50B,0xA4CC,0xAD2E,0xB54F,0xC5F0,0xAD4E,0x6B49,0x4A66,
0x39E5,0x31A4,0x3183,0x4224,0x4AC8,0x7BEA,0x7C09,0x7BEA,0x5267,0x6BA8,0x6347,0x94AB,0xB5AD,0xBDEE,0x9CEC,
0x8C2B,0x9CCE,0x4227,0x08E3,0x1944,0x1943,0x1963,0x4245,0x6B66,0x52A7,0x2163,0x1102,0x08C3,0x08A2,0x08C3,
0x2984,0x3164,0x5AC9,0x4AE5,0x4AE3,0x3241,0x2181,0x2962,0x2163,0x1964,0x2164,0x1944,0x3124,0xD965,0xF9C4,
0xD904,0xB8A4,0xD0E3,0xF163,0xF143,0xC0A3,0xA863,0xA862,0xA043,0x9843,0x9023,0x9043,0x8843,0x9843,0xA863,
0x9843,0x9844,0xA844,0xB844,0xB044,0x9024,0x6043,0x4023,0x3043,0x2063,0x1842,0x2822,0x4022,0x3801,0x6822,
0xD862,0xA822,0x5001,0x5801,0x6801,0x6801,0x7021,0x7821,0x8022,0x8042,0x8842,0x8042,0x8042,0x8842,0x8021,
0x7841,0x8041,0x8062,0x8862,0x7862,0x2041,0x2182,0x4285,0x3207,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,
0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,
0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7FF,0xE7FF,0xE7FF,0xEFFF,0x94F2,0x30A6,0x9928,0xB168,0x9906,0x8063,
0x7863,0x6063,0x6843,0x9843,0xC083,0xB8A4,0xB0E5,0xB146,0xB146,0xB167,0xC145,0xB063,0xA043,0x5062,0x6083,
0xE984,0xF9E3,0xFA43,0xFAA2,0xFA61,0xD962,0x72A7,0x6B68,0x6327,0x6B69,0x5326,0x2A05,0x29A5,0x6348,0x9CAC,
0xACED,0xAD0D,0xB58E,0xB5CE,0xBDCD,0xA54A,0xA50B,0xA4EB,0xA48B,0xA4AC,0x9C8B,0x8C2A,0x6B67,0x62C7,0x4A65,
0x29A6,0x31E6,0x31E6,0x5287,0x6307,0x4245,0x5266,0x6327,0x7388,0x6306,0x6307,0x4A26,0x6B47,0xA52E,0x39E6,
0x1943,0x1944,0x1944,0x4225,0x3162,0x08A3,0x08C3,0x00A2,0x08C3,0x10E3,0x4A67,0x5AE8,0x4A84,0x6367,0x4245,
0x29A1,0x2961,0x2962,0x2143,0x1904,0x2965,0x1904,0x1943,0x2124,0xA924,0xE0E4,0xB884,0xA884,0xC8A3,0xD083,
0xA843,0x9044,0x9044,0x9023,0x9043,0x9043,0x9043,0xA063,0xA043,0xA043,0x9043,0x9043,0x9843,0xA844,0xB844,
0xA023,0x6043,0x3083,0x3843,0x3842,0x2862,0x2042,0x3043,0x4802,0x4002,0x7822,0xE882,0x9001,0x5001,0x6001,
0x6801,0x6801,0x7021,0x7821,0x8022,0x8042,0x8042,0x8042,0x8842,0x8842,0x8842,0x8021,0x8041,0x8062,0x8062,
0x8042,0x3861,0x1102,0x08C3,0x08C3,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFFF,0xC6BA,0x49E9,0x90E7,0xCA4B,0xB9E8,0x7843,0x7063,0x6843,0x7043,0xB063,
0xD0C3,0xC0C4,0xB0C4,0xB126,0xB146,0xB946,0xC8C4,0xB063,0x9043,0x5063,0x90E3,0x9942,0xA962,0xC9A3,0xEA03,
0xFAC3,0xFAE2,0xBAC5,0x73E8,0x83C9,0x5AC7,0x5B27,0x4AC6,0x5AC8,0x8C6C,0xBDAF,0xA509,0xAD4C,0xB56C,0x9CC9,
0x9488,0x9CCB,0xA4AD,0xA4AD,0xA4AD,0xA4CC,0x8C4A,0x8C6A,0x8C69,0x9468,0x83E8,0x4A67,0x2986,0x1965,0x2965,
0x2985,0x2964,0x39A4,0x41E5,0x4205,0x39E5,0x39E5,0x39E6,0x4246,0x7BC8,0x52A7,0x08E3,0x1123,0x1103,0x39C5,
0x5285,0x4A65,0x29C5,0x4A88,0x29A3,0x29A3,0x4AC4,0x4AA2,0x29A2,0x31C3,0x39C5,0x2944,0x2963,0x2964,0x31C6,
0x2165,0x2144,0x2143,0x2142,0x1942,0x5902,0xB084,0xB8A4,0xE124,0xE0E4,0xB883,0x9843,0x9064,0x8864,0x9043,
0x9042,0x9022,0xA042,0xB083,0xA063,0x9043,0x8843,0x9043,0x9843,0xA844,0xB044,0x9824,0x7043,0x5843,0x4843,
0x5822,0x5802,0x5022,0x4822,0x5802,0x4802,0xB925,0xE0C3,0x7801,0x5801,0x6801,0x7001,0x7001,0x7801,0x7821,
0x8022,0x8042,0x8042,0x8042,0x8042,0x8042,0x8062,0x8041,0x8041,0x7863,0x8042,0x8042,0x4862,0x08A2,0x08A2,
0x08E2,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xEFFF,0xD73C,0x9A2A,0xB9C9,0xB1A7,0x7043,0x7063,0x7843,0x8063,0xB883,0xD0E3,0xC0E4,0xB8E5,0xB905,
0xC125,0xD0C3,0xC083,0xD0C3,0x9042,0xA0A4,0xF183,0xD164,0xB184,0x9143,0x9143,0xA1C4,0xB244,0xAA64,0x7B07,
0x7B26,0x8387,0xA4CB,0x94AA,0x94A9,0x94A8,0x94A8,0x9488,0x94AA,0xAD0C,0xBD6D,0xAD2C,0xA4CC,0x9CAC,0xA4CD,
0xA4CD,0xA4ED,0x946B,0x844A,0x8C69,0x8C48,0x8429,0x7BA9,0x52A7,0x29C6,0x31A6,0x2185,0x2984,0x31A5,0x31C4,
0x31C5,0x31C5,0x3183,0x31C4,0x4A67,0x29A6,0x1103,0x1123,0x1144,0x2184,0x4265,0x52A4,0x5B04,0x7B69,0x836B,
0x49E5,0x49A6,0x5227,0x6AE8,0x6B0A,0x5268,0x39A5,0x3184,0x2964,0x3165,0x5288,0x31A3,0x2162,0x29A2,0x4222,
0x6324,0x7C06,0xBA26,0xD8C4,0xC0C4,0x9864,0x9064,0x9063,0x9063,0x9063,0x9063,0x9043,0x8822,0xA862,0xB863,
0xA063,0x9043,0x9043,0x9843,0xA044,0xA844,0xA044,0x9044,0x8024,0x7823,0x6823,0x6022,0x6802,0x6022,0x6822,
0x6002,0x7022,0xF267,0xD8C4,0x7801,0x6801,0x7001,0x7821,0x7821,0x7821,0x7822,0x8042,0x8042,0x8842,0x8862,
0x8842,0x8043,0x8042,0x7841,0x7841,0x8062,0x8062,0x8042,0x5082,0x0882,0x0861,0x08A1,0xCF9F,0xCF9F,0xCF9F,
0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFFF,0xA36F,
0xBA0B,0xC2AA,0x7042,0x8063,0x9063,0xA883,0xB0A3,0xD103,0xC904,0xC105,0xC125,0xC125,0xC904,0xE104,0xD8E3,
0x9043,0xD123,0xD923,0xC8E4,0xD103,0xD104,0xC104,0xB125,0xB145,0xA9C5,0x7B89,0x8BEA,0x8BC9,0x5AA6,0x31E5,
0x29C4,0x6B49,0x94AC,0x9CAC,0xA50C,0xAD4C,0xB56D,0xB56D,0xB54E,0xAD0D,0xA4ED,0xB52E,0xB52E,0x9CCD,0x8C6B,
0x842B,0x8429,0x7C08,0x73C8,0x6B67,0x5AA6,0x4A46,0x3A06,0x39E6,0x39E6,0x3A06,0x39E6,0x39E6,0x31C5,0x31E6,
0x2185,0x29C4,0x4AA7,0x6367,0x6346,0x6BA6,0x4AC3,0x4A05,0x816B,0x894C,0x812C,0x718B,0xAC4F,0xE734,0xE753,
0xE753,0xDF13,0xA50E,0x5268,0x52C7,0x3A23,0x31E1,0x29A1,0x31C1,0x4242,0x6B63,0x6BA3,0x6324,0x81A5,0x9864,
0x9064,0x9064,0x9064,0x8864,0x9064,0x9043,0x9063,0x8843,0x9042,0xB083,0xA863,0x8843,0x9044,0x9844,0xA043,
0xA023,0xA023,0x9844,0x8823,0x8023,0x8023,0x7823,0x6003,0x6802,0x6002,0x6822,0x6002,0xA0C3,0xFA67,0xD842,
0xA001,0x8001,0x8001,0x7821,0x8022,0x8021,0x8042,0x8042,0x8842,0x8842,0x8862,0x8862,0x8863,0x8843,0x8042,
0x7841,0x7841,0x8042,0x8062,0x4882,0x10C1,0x10E1,0x1100,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xCFBF,
0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,
0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xA3D0,0xB22C,0xBA69,0x8042,0x9083,
0xB0A3,0xC8C3,0xC8E3,0xC904,0xC904,0xC104,0xC104,0xC124,0xC125,0xD124,0xB863,0xB864,0xD923,0xC8E3,0xC8E4,
0xC8E3,0xC904,0xC924,0xC944,0xC924,0xA2E6,0x6BC6,0x9C6B,0x9C0A,0x5286,0x21A5,0x3205,0x7389,0x948C,0xA4EC,
0xA52C,0xA50C,0xA4EC,0xB54E,0xBD90,0xAD0D,0x9C8C,0xB52F,0xAD0E,0x9CAD,0x948C,0x9CAC,0x844B,0x7BE8,0x7BE8,
0x6B86,0x5B05,0x5B04,0x5286,0x4A47,0x4206,0x41E6,0x4226,0x52A7,0x52E7,0x5306,0x73E8,0x94CA,0x8488,0x5B43,
0x31E2,0x1962,0x1123,0x3146,0x694B,0x614B,0x616A,0x6A0A,0x6AE7,0x9D6B,0x8487,0x8C67,0x94A8,0xAD6A,0xB5EC,
0x8467,0x3A00,0x3181,0x2982,0x2983,0x2984,0x2123,0x2925,0x2104,0x5985,0x98E6,0x8885,0x9064,0x9063,0x9864,
0x9064,0x8863,0x8843,0x8843,0xA063,0xA863,0x8843,0x8843,0x9844,0x9844,0xA043,0xA022,0xA022,0x9843,0x9043,
0x8823,0x8023,0x7023,0x6823,0x7822,0x6002,0x4021,0x5801,0xC9C5,0xFA28,0xD822,0xB001,0x9001,0x8001,0x8021,
0x8022,0x8822,0x8842,0x8042,0x8042,0x8842,0x8862,0x8862,0x8862,0x8863,0x8862,0x8062,0x7842,0x7842,0x8062,
0x48C2,0x1120,0x1120,0x10E0,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xA3D0,0x9128,0x90A5,0x9083,0x98A3,0xB0A3,0xC8E3,0xD103,0xC904,
0xC904,0xC0E4,0xC0E4,0xC104,0xC125,0xB946,0xE8E3,0xE8C3,0xC8E4,0xC0E4,0xB8E4,0xB904,0xC104,0xB924,0xB925,
0xA1E6,0x73E7,0x73E7,0x6347,0x7B8A,0x5AE8,0x29C5,0x29C5,0x5AE8,0x9C8C,0xA4EC,0xA50C,0xAD2C,0xBD6E,0xBD6E,
0xAD0D,0xAD2E,0xACEE,0xAD0E,0x9CAC,0x9CCD,0xA4ED,0x9CAC,0x8C6A,0x8449,0x8448,0x7BE7,0x6BA5,0x6364,0x5B07,
0x6309,0x6B67,0x8C8A,0x94C9,0x8466,0x6BC4,0x5304,0x4285,0x1982,0x1142,0x1963,0x1144,0x1964,0x1964,0x1143,
0x1123,0x1123,0x2184,0x6A29,0x28E4,0x4203,0x52C4,0x94AB,0x94C9,0x6BC3,0x4281,0x2983,0x2103,0x1923,0x2144,
0x1903,0x10E3,0x1903,0x2964,0x2162,0x5183,0xA147,0x8085,0x8885,0x9084,0x9084,0x8884,0x8863,0x8843,0xA063,
0xC0A3,0xA064,0x8864,0x9064,0x9064,0x9864,0x9844,0x9844,0x9843,0x9043,0x8844,0x8824,0x8023,0x7823,0x8023,
0x8023,0x7802,0x6002,0x6802,0xC987,0xE946,0xC001,0xA821,0x9801,0x8801,0x8821,0x8021,0x8021,0x8842,0x8842,
0x8042,0x8042,0x8042,0x8042,0x8062,0x8862,0x8862,0x8862,0x8042,0x7841,0x7863,0x4082,0x0080,0x2942,0x62C7,
0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xEFFF,0xB411,0x9128,0x90C5,0x98A4,0xA0A4,0xA8A3,0xB8E3,0xC904,0xC904,0xC904,0xC104,0xC104,0xC125,
0xC146,0xB925,0xE904,0xE8E3,0xC0C4,0xB8E4,0xB0E4,0xA8E5,0xB104,0xB105,0xA187,0x83A9,0x6BE5,0x6BC5,0x4B03,
0x6B06,0x7BC7,0x4AA6,0x3206,0x6B49,0x8C4B,0x9C8B,0x9CAB,0x9CEB,0xB54D,0xB54E,0xAD0D,0xA4ED,0x946B,0x8C4A,
0x946B,0x8C6A,0x9CCC,0x948B,0x8C8A,0x8C69,0x8447,0x5B46,0x4265,0x73A8,0xA54F,0x8C6B,0x6BA6,0x6365,0x4283,
0x29E3,0x1963,0x1103,0x1123,0x1943,0x1943,0x1922,0x1963,0x1963,0x1163,0x1943,0x1944,0x1944,0x39A6,0x4A06,
0x52A4,0x4AE1,0x5322,0x42A2,0x31E2,0x31C2,0x2143,0x1904,0x1124,0x1103,0x1923,0x1923,0x2983,0x29A1,0x29A0,
0x4223,0x3182,0x70C3,0x8085,0x8085,0x8885,0x8864,0x8864,0x8864,0x9063,0xB8C3,0xA083,0x9064,0x9064,0x9044,
0x8844,0x9044,0x9064,0x9864,0x9044,0x9043,0x9044,0x8823,0x8044,0x7823,0x8823,0x8023,0x7822,0x7803,0x9884,
0xF34B,0xD0E6,0xB001,0xA821,0xA021,0x9821,0x8821,0x8821,0x8022,0x8022,0x8042,0x8042,0x8042,0x8042,0x8042,
0x8062,0x8862,0x8862,0x8883,0x8063,0x7862,0x7862,0x6164,0x6B66,0x8CA6,0x8CE5,0xCF9F,0xCF9F,0xCF9F,0xCF9F,
0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFDF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xEFBE,0xD34C,0x9108,
0x98E5,0xA0C4,0xA0C4,0xA8C3,0xB0E3,0xB8E4,0xC103,0xC103,0xC124,0xC104,0xC124,0xC145,0xB925,0xD104,0xE0C3,
0xB8E4,0xB0E4,0xB104,0xB904,0xB8E4,0xA925,0x9369,0x8467,0x6BA6,0x6365,0x5B65,0x6B86,0x6B86,0x4AC6,0x3225,
0x6B6A,0xA4CD,0x9CAB,0x9CCB,0x94AB,0xA50C,0xB54E,0x9CCC,0x948B,0x8C6A,0x8C6A,0x8C69,0x9CEC,0xA4ED,0x94AB,
0x8C69,0x9CEC,0x8C6A,0x5B26,0x4A86,0x73A6,0x5B24,0x4265,0x3A44,0x3223,0x29E4,0x2185,0x2184,0x6B6A,0x9D2E,
0xB5AF,0xAD8F,0x948D,0x2985,0x1943,0x2185,0x39E6,0x29C3,0x31E2,0x4282,0x4282,0x4243,0x3A23,0x3203,0x31E4,
0x29A4,0x2165,0x10E4,0x1924,0x31A4,0x4AA6,0x5B25,0x52E3,0x3220,0x4243,0x7C0C,0x844B,0x7C0A,0x49E6,0x6044,
0x8085,0x8085,0x8084,0x8063,0x8864,0x9064,0x9084,0x8864,0x8864,0x9064,0x8864,0x8844,0x8844,0x9064,0x8844,
0x8864,0x9064,0x9844,0x9044,0x8024,0x7843,0x8843,0x8023,0x7803,0x9884,0xEBED,0xFD34,0xC8A6,0xA801,0xA821,
0xA821,0xA021,0x9021,0x8821,0x8021,0x7821,0x8022,0x8042,0x8042,0x8042,0x8042,0x8062,0x8862,0x8862,0x8883,
0x8883,0x8083,0x7842,0x7AA2,0x7CA4,0x4AE1,0x29C1,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,
0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xF73C,0xEB6A,0x9107,0xA105,0xA0E4,0xA8E4,0xA8C4,
0xB0E4,0xB0E4,0xB903,0xC104,0xB904,0xB8E4,0xB8E4,0xB904,0xB924,0xC904,0xD0C4,0xB8E5,0xB105,0xB0E5,0xB905,
0xA186,0x7AA6,0x6B66,0x5304,0x52C5,0x4A84,0x5B25,0x5B26,0x5B46,0x4AC6,0x3A65,0x7389,0xA4ED,0xA4CC,0xA50C,
0x9CAB,0xA50D,0xB56E,0x9CAB,0x948B,0xA4EC,0x9CEC,0x9CCB,0x9CCD,0xAD2E,0x8C4B,0x7BE8,0x8449,0x8C6A,0x7C06,
0x6BA6,0x6347,0x6345,0x4AC3,0x42A3,0x3A63,0x21A4,0x4267,0xA52E,0xCE90,0xBE0D,0x9CE9,0x7C08,0x8C0A,0x4A66,
0x29E3,0x4243,0x4243,0x31C3,0x29A3,0x2183,0x2144,0x2125,0x1944,0x2985,0x1943,0x1903,0x3185,0x52A6,0x8429,
0x6BA4,0x6B84,0x5B24,0x5B47,0x844E,0x9CCF,0x94AA,0x6346,0x5B29,0x634A,0x6AA9,0x70A4,0x8085,0x8884,0x88A4,
0x9084,0x9884,0x8084,0x8864,0x8864,0x8864,0x8844,0x8864,0x9064,0x9064,0x9044,0x9043,0x9844,0x9064,0x8844,
0x8044,0x8044,0x8044,0x8024,0x9864,0xEBCC,0xFE15,0xEB0F,0xA803,0xA821,0xA021,0xA821,0xA021,0x9821,0x9821,
0x8821,0x7821,0x8042,0x8042,0x8042,0x8042,0x8062,0x8062,0x8062,0x8062,0x8863,0x8084,0x8883,0x8083,0x4922,
0x1920,0x10C2,0x08A2,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xEF3C,0xF3EC,0xB9C7,0xB986,0xB966,0xA905,0xA0C4,0xA8C4,0xB0E4,0xB0E4,0xB904,
0xC125,0xB925,0xB8E4,0xB8C3,0xC8C3,0xC8C4,0xC8C5,0xB8E5,0xB905,0xB905,0x8964,0x5A86,0x6306,0x5284,0x3A23,
0x31C3,0x2963,0x31C3,0x31C3,0x4A85,0x4265,0x4286,0x842C,0xAD0E,0xA50C,0xA4EC,0x9CCB,0x9CCB,0xA4CC,0x8C4A,
0x9CAC,0xA4ED,0x9CCC,0xA4ED,0xAD0E,0xA4EE,0x9CAC,0x948A,0x7C27,0x7C08,0x73C8,0x6367,0x52C6,0x5B26,0x6B66,
0x6344,0x5B24,0x5327,0x8C8B,0x8449,0x5B26,0x5286,0x4225,0x39E3,0x4A43,0x4263,0x3A22,0x31C2,0x2984,0x1944,
0x1124,0x1124,0x1944,0x1123,0x1123,0x1944,0x3A05,0x73C9,0x8407,0x73A4,0x6345,0x3A23,0x2962,0x738C,0x9CEF,
0x844C,0x4265,0x3A04,0x5B26,0x73C9,0x6328,0x4245,0x58E3,0x98A5,0xA905,0xC124,0xC0E4,0xA0A4,0x9084,0x8064,
0x8064,0x8064,0x8864,0x9064,0x9864,0x9064,0x9864,0x9064,0x8864,0x8864,0x7884,0x7844,0x8044,0x8044,0x8023,
0xCA89,0xFDB4,0xFD14,0xC0E7,0x9801,0xA022,0xA022,0xA022,0xA022,0xA021,0x9822,0x9022,0x8021,0x7822,0x8042,
0x8042,0x8062,0x8063,0x8042,0x8061,0x8062,0x8083,0x8083,0x8883,0x60A3,0x2923,0x10C1,0x10C1,0x10E2,0xCF7F,
0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFBF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE79F,0xFCCF,0xFC29,0xFBC7,0xFCF2,0xD5F9,0xCD56,0xAA49,0xB0E4,0xB104,0xA8C4,0xB0C4,0xB146,0xC32E,0xCB6E,
0xD208,0xC8E3,0xD0A4,0xB906,0xA966,0x81E5,0x4A64,0x39E4,0x5A46,0x5285,0x4224,0x4A44,0x2143,0x2143,0x2123,
0x3163,0x4A23,0x5265,0x8C0C,0xBCED,0xACCC,0x8C8A,0x948A,0x9C8B,0x946B,0xA4CB,0x9C8B,0xACED,0xAD2D,0xAD0D,
0xBD90,0x9CAC,0x948B,0x94AA,0x8C69,0x8C88,0x7C28,0x7C07,0x7C07,0x5B05,0x6B87,0x83E9,0x8409,0x8409,0x52C6,
0x31A4,0x31A2,0x4A65,0x52A4,0x4A62,0x3A02,0x2983,0x2184,0x2164,0x1963,0x1964,0x1924,0x1944,0x1945,0x1943,
0x1943,0x4A86,0x9CEC,0x6345,0x31C2,0x2983,0x2964,0x4A67,0x8C4E,0xB592,0x4A66,0x4246,0x3A05,0x2143,0x2983,
0x2142,0x1902,0x2963,0x3123,0x8905,0xA0A5,0xA8A4,0xB8C4,0xA8A4,0x9084,0x8064,0x8064,0x8864,0x8864,0x8864,
0x8864,0x8864,0x8864,0x8064,0x8064,0x7084,0x3903,0x68A4,0x7844,0x7843,0x9084,0xF4AF,0xFE37,0xFBD1,0xA044,
0x8843,0x9044,0x9043,0x9842,0xA022,0xA022,0x9822,0x9842,0x8821,0x7821,0x7841,0x8042,0x8042,0x8063,0x8062,
0x8062,0x8062,0x8083,0x8083,0x7883,0x3124,0x1963,0x1122,0x10E4,0x1104,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,
0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7FF,0xF678,0xFC28,0xFCAD,
0xF75D,0xEFFF,0xF7FF,0xD6DB,0xAA09,0xB905,0xD2CC,0xD4F5,0xE69B,0xF7DF,0xF7FF,0xF7BF,0xE5D7,0xAA27,0x61E5,
0x5AE5,0x52C6,0x4224,0x31A4,0x3184,0x31A4,0x3A04,0x6364,0x4A43,0x71E5,0xAAA6,0xDB47,0xEBA7,0xEBC8,0xE3EA,
0xFBE9,0xEBA8,0x946A,0x844A,0x8C49,0x9C8B,0xACED,0xA4CD,0x9CCC,0x9CCC,0xAD2D,0xA4CD,0xACCD,0x9CCD,0x94CA,
0x8C89,0x94C9,0x8468,0x7C26,0x7C45,0x6BC5,0x6BA7,0x5B05,0x5AC6,0x4A64,0x4262,0x4261,0x4262,0x4243,0x4A25,
0x31A5,0x2163,0x1963,0x2164,0x1963,0x1942,0x1943,0x2143,0x2164,0x1942,0x29A3,0x4A85,0x7BE8,0x5AA6,0x3185,
0x2164,0x3A26,0x8C6E,0xAD52,0x5AE9,0x4226,0x2123,0x18E2,0x1901,0x21C1,0x1942,0x1904,0x2943,0x31C5,0x31E5,
0x39C5,0x6905,0x9084,0x9064,0x8865,0x8884,0x8884,0x8064,0x8864,0x8864,0x8864,0x8064,0x8064,0x7864,0x8064,
0x7864,0x38E3,0x1921,0x3902,0x6864,0x6824,0xB0E5,0xFC4E,0xFDB7,0xC98B,0x8023,0x8043,0x8843,0x8843,0x8844,
0x9043,0x9823,0x9842,0x9842,0x9022,0x7822,0x7841,0x7842,0x7842,0x8062,0x8062,0x8063,0x8062,0x8083,0x7883,
0x48C4,0x2165,0x1925,0x1905,0x10E5,0x1927
};

	static const uint16_t Bitmap2[] PROGMEM = 
{0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,
0xDFDF,0xE7BF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFBE,0xFD94,0xF6FC,0xEFFF,0xEFDF,0xEFDF,0xEFFF,
0xDF1C,0xE5B8,0xFF9E,0xF7FF,0xF7FF,0xEFFF,0xF7DF,0xF7DF,0xFFFF,0x8CD0,0x21C4,0x31E4,0x3A24,0x39E3,0x3183,
0x2963,0x3943,0x4A45,0xA446,0xEBA6,0xFBC7,0xFC08,0xFC07,0xFBE7,0xFBC6,0xFBA7,0xFB87,0xFB67,0xB429,0x846A,
0x948A,0xAD2C,0xA4EC,0x9C8B,0x946B,0x948B,0x946B,0x9CCC,0xA4ED,0xAD0D,0x9CCB,0x8C8A,0x9CEB,0x7406,0x6384,
0x6B66,0x6386,0x5323,0x4A81,0x4A62,0x5263,0x4223,0x31C4,0x31A5,0x2985,0x1965,0x1944,0x1964,0x1963,0x2163,
0x1943,0x1963,0x2184,0x2983,0x2981,0x7BEA,0x9D0F,0x7BEA,0x4A65,0x6A28,0x8ACB,0xC533,0xB5B3,0x7C0B,0x3A26,
0x4206,0x3A06,0x2165,0x2966,0x2145,0x29C5,0x31C4,0x31E3,0x4226,0x3A07,0x31E6,0x4266,0x31C4,0x5904,0x8884,
0x9065,0x9064,0x9064,0x8884,0x8064,0x8064,0x8064,0x8085,0x8084,0x8064,0x7884,0x4103,0x1943,0x2142,0x2962,
0x5104,0x7844,0xB8C4,0xFB6C,0xEBB1,0x8044,0x7843,0x7864,0x8043,0x8043,0x8844,0x8844,0x9043,0x9043,0x9823,
0x9042,0x8022,0x7841,0x7842,0x7842,0x7842,0x8062,0x8062,0x8062,0x7883,0x40E5,0x2125,0x1904,0x10E5,0x10E5,
0x18E5,0x1946,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFFF,0xE7FF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFFF,0xEFFF,0xF4F4,0xFCB2,
0xFDD7,0xF73E,0xF7FF,0xF7FF,0xEFDF,0x7C6D,0x4AA4,0x3A24,0x4264,0x31A3,0x2983,0x61C5,0xDAE9,0xAAA6,0xFB85,
0xFB85,0xFB85,0xFBA5,0xFB65,0xFB05,0xFA65,0xF245,0xFAA6,0xFA25,0xD369,0xA52C,0x9489,0x9CA9,0xA50B,0x9C8B,
0x946B,0x9CAC,0x9CAC,0x9CCC,0x9CCD,0x840B,0x8C6B,0x8449,0x7C08,0x6B67,0x6BA7,0x6BC6,0x52C1,0x4A83,0x4A63,
0x4A64,0x3A24,0x3205,0x21A4,0x2184,0x2184,0x1964,0x1944,0x1964,0x2185,0x2184,0x29A3,0x2141,0x3183,0x7368,
0x8C6C,0x7C2A,0x6B68,0x7BEB,0x5245,0xAC8F,0xA4EF,0x8B6B,0x8289,0x936B,0x73AA,0x4A88,0x31A5,0x4A48,0x39C6,
0x31C4,0x29C3,0x3A04,0x4227,0x29A6,0x2164,0x1943,0x31C3,0x3A05,0x31A4,0x4184,0x50C4,0x8064,0x9085,0x8885,
0x8885,0x8884,0x8084,0x8085,0x8084,0x70C5,0x5185,0x2142,0x31C2,0x5284,0x2963,0x4983,0xA8E4,0xE9C6,0xFA8A,
0xB108,0x7822,0x7863,0x7863,0x7844,0x8044,0x8064,0x8064,0x8064,0x8064,0x8864,0x9043,0x8822,0x7822,0x7821,
0x7841,0x7842,0x7842,0x8062,0x7863,0x4083,0x10E4,0x1905,0x1905,0x18E5,0x1925,0x2165,0x1902,0xCF7F,0xCF7F,
0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFFF,0xF79E,0xFBEC,0xFAC8,0xFAC8,0xFB8B,0xFC90,0xFD96,
0xFF5F,0xA574,0x6386,0x5323,0x4A63,0x31A3,0x2963,0xAAA7,0xFC4C,0xFBA8,0xFB43,0xFB63,0xFB43,0xFA43,0xE943,
0xE104,0xD8C4,0xD8C3,0xE903,0xE0E3,0xD1C7,0xACEC,0x9CE9,0x9CE9,0x9CE9,0x9C8B,0x8C2A,0x840A,0x7BEA,0x946C,
0x946C,0x8C2B,0x8C6B,0x73C7,0x8C2A,0x8C4A,0x5B43,0x4AA3,0x4AA3,0x5AE6,0x4AA5,0x3A64,0x3244,0x31E4,0x2184,
0x2984,0x2185,0x1964,0x2983,0x2162,0x2182,0x31C3,0x4A86,0x6BAB,0xA4EF,0xB571,0x6B48,0x2920,0x4204,0x948E,
0x62E8,0x5B06,0x3162,0x48E5,0x5926,0xAB0D,0xA2AC,0x4945,0x29A4,0x29A3,0x31E3,0x31A3,0x39E5,0x4208,0x2166,
0x1924,0x1923,0x1923,0x1922,0x2163,0x2963,0x1903,0x10C2,0x28E3,0x48C4,0x70A4,0x7885,0x7864,0x7064,0x7084,
0x50E3,0x3163,0x3A23,0x6B86,0x7C08,0x31A4,0x31A1,0xB2E8,0xFC4F,0xFC0E,0xE9CA,0x8044,0x7843,0x7842,0x7843,
0x7843,0x7863,0x7863,0x8064,0x8063,0x8063,0x8064,0x8084,0x8864,0x8042,0x7822,0x7841,0x7842,0x7842,0x7843,
0x4083,0x10A2,0x08A2,0x10E3,0x1945,0x1945,0x1102,0x10E1,0x1922,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,
0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,
0xEFDF,0xEFDF,0xEFDF,0xEFFF,0xF658,0xFBAB,0xFB49,0xFB8A,0xFBA9,0xFB68,0xFB27,0xFB4A,0xEBAB,0xB326,0x6223,
0x31C3,0x29A3,0x4984,0xE307,0xFB49,0xFB06,0xFAE3,0xFA42,0xF9C3,0xF902,0xE0A2,0xE0C3,0xE0E3,0xD8E4,0xD0E4,
0xC8E4,0xC905,0xAC2B,0x9D0A,0x94A9,0x8C49,0x8C2B,0x8C4A,0x8409,0x7BE9,0x9CCC,0x9CAC,0x9C8C,0xACEE,0xAD2F,
0x8C6A,0x5B04,0x4AA4,0x5AE6,0x3A65,0x42A3,0x3A63,0x3A24,0x3A66,0x3205,0x29C4,0x29C4,0x31C4,0x31C3,0x4244,
0x6348,0x73EB,0x7C0D,0x9D10,0xB5B2,0x8C4C,0x4224,0x7309,0x9C6E,0x8C8D,0x6348,0x39E5,0x2143,0x3964,0x69A7,
0x926B,0x4905,0x4944,0x39A3,0x31C3,0x52A6,0x5286,0x31A4,0x39E6,0x2165,0x1104,0x1903,0x1923,0x1923,0x1923,
0x2142,0x2985,0x1903,0x1942,0x18E3,0x1104,0x2927,0x28C5,0x3924,0x3944,0x28E2,0x1921,0x3A03,0x4A63,0x6365,
0x29A3,0x1921,0x31C1,0xB2C8,0xFC6E,0xFD74,0xC9EC,0x7023,0x7043,0x8042,0x8042,0x7843,0x7843,0x7842,0x7863,
0x7884,0x8063,0x8063,0x8063,0x7864,0x8064,0x8043,0x7842,0x7842,0x6842,0x38A2,0x10C1,0x08A2,0x10A2,0x10C2,
0x1102,0x08E1,0x10E1,0x2123,0x2984,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xCF9F,0xD79F,0xD79F,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,
0xDFDF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFFF,
0xF699,0xFB6A,0xFBCC,0xFBCB,0xFB27,0xFB49,0xFB07,0xFAC4,0xFAA3,0xFAA3,0xFA83,0xB263,0x49E3,0xAA65,0xFAA6,
0xFB29,0xFB49,0xFA02,0xFA02,0xFA63,0xF9E2,0xC8A3,0xC0A4,0xC0A4,0xC0A4,0xC0C4,0xC0C4,0xB8C5,0xA3EA,0x9D0A,
0x8C49,0x946A,0xA4AC,0x94AB,0x8429,0x8C4A,0xA4CC,0x9CAD,0xBDB0,0xAD4F,0x7C09,0x5B24,0x6326,0x6BA6,0x5B45,
0x7C0B,0x94EC,0x6366,0x3A23,0x31C4,0x31E3,0x5A03,0x9202,0xA9A3,0xB247,0xC490,0xA44E,0x6308,0x73CA,0x842B,
0x6B48,0x6B48,0x8C6E,0xA510,0x6329,0x2142,0x10E2,0x2124,0x51A6,0x4985,0x5164,0x7247,0x5246,0x29A3,0x4205,
0x6B08,0x7B89,0x4205,0x2962,0x2183,0x1104,0x1103,0x1923,0x1943,0x1922,0x2183,0x3206,0x31C6,0x1923,0x2142,
0x1903,0x10E4,0x2165,0x42A6,0x6367,0x29A4,0x29C3,0x6366,0x4A84,0x2981,0x1901,0x4202,0x31E2,0x1943,0x2902,
0x8A63,0xB388,0x7926,0x7044,0x7064,0x7843,0x8042,0x7842,0x7842,0x7842,0x7842,0x7843,0x7863,0x7863,0x7863,
0x7842,0x7864,0x8064,0x8063,0x7042,0x28A2,0x08A2,0x10A1,0x10C1,0x10E1,0x10E1,0x10E0,0x1922,0x1922,0x1902,
0x2122,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xFC8E,0xFBEA,0xFB69,
0xFAE8,0xFB48,0xFB87,0xFB06,0xFAA4,0xFA83,0xFAE3,0xFA82,0xD9A2,0xEAC5,0xFB68,0xFBCB,0xFB69,0xFA21,0xFAA3,
0xFA83,0xF162,0xC883,0xC0A4,0xB8A3,0xB8A4,0xB8C4,0xC0C4,0xC925,0xABCA,0x9CCA,0x9CAA,0xA4EB,0xA4EC,0x94AB,
0x7C09,0x9CAC,0xB54F,0xB590,0x8C8A,0x52E3,0x6B45,0x7BE8,0x7C07,0x6BC6,0x6345,0x8C8D,0x8C6D,0x52A6,0x4223,
0x5283,0x6368,0xBAEA,0xF9E4,0xE984,0xF1A5,0xF184,0xE307,0x9C2C,0x840B,0x39E3,0x4A65,0x7C0A,0x4245,0x2122,
0x10E2,0x1103,0x10E3,0x2964,0x69C5,0x6226,0x39E4,0x3183,0x3962,0x3162,0x3183,0x31A3,0x2942,0x2122,0x2142,
0x2143,0x2164,0x2164,0x2184,0x2164,0x3A26,0x52E7,0x29A5,0x1902,0x1901,0x2162,0x2983,0x1922,0x2142,0x2983,
0x2984,0x5306,0x73E7,0x4263,0x4A63,0x4245,0x31E2,0x3A21,0x3A02,0x1102,0x4262,0x4B21,0x42A2,0x5A42,0x70C4,
0x7044,0x7043,0x7842,0x7842,0x8042,0x7842,0x7842,0x7843,0x7843,0x7063,0x7063,0x7843,0x7063,0x7885,0x6864,
0x3082,0x0881,0x08A1,0x10E1,0x1100,0x10E0,0x1901,0x1921,0x1921,0x2141,0x2122,0x10E3,0xCF7F,0xCF7F,0xCF7F,
0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xE7DF,0xE7BF,0xE7BF,0xE7DF,0xE7BF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFFF,0xF4F4,0xFA67,0xFA47,0xFB29,0xFB47,0xFAC5,0xFA85,
0xFAE5,0xFB04,0xFB03,0xFAC3,0xFA62,0xFB06,0xFB49,0xFBED,0xFB49,0xFA61,0xFAC3,0xFAA3,0xFA43,0xD8E3,0xC084,
0xC0A4,0xC0A3,0xC8E4,0xE1A5,0xFA65,0xCBE9,0x9CEB,0xAD4C,0xB56D,0xA4EB,0x9CAB,0xAD2D,0xC5F1,0x94AD,0x5B04,
0x6325,0x946C,0x8409,0x7BC7,0x52A4,0x3A22,0x4222,0x31C3,0x2983,0x39C4,0x6329,0x9CCD,0x9D10,0x9B0A,0xD965,
0xC904,0xC9E6,0xDC6C,0x948B,0x6285,0x6962,0x5983,0x2142,0x1922,0x1942,0x1923,0x2164,0x31C5,0x4A86,0x4AA5,
0x39C2,0x5923,0x80E5,0x8925,0x9945,0x81C5,0x3183,0x2143,0x2964,0x2164,0x1943,0x1903,0x1923,0x1924,0x1925,
0x31E6,0x6B89,0x2124,0x1902,0x1902,0x1921,0x4A83,0x2182,0x10C3,0x2145,0x6368,0x7C49,0x4244,0x1902,0x5306,
0x5B26,0x5283,0x5AE3,0x31E1,0x3A62,0x3222,0x8464,0x7C25,0x4282,0x7C24,0x72E4,0x7065,0x7822,0x7842,0x7042,
0x7843,0x7843,0x7843,0x7843,0x7042,0x7063,0x7863,0x7063,0x6864,0x5884,0x28A3,0x10E2,0x10E1,0x08E0,0x1100,
0x1901,0x10E1,0x10C1,0x1922,0x1922,0x1102,0x1903,0x08C3,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,
0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xE7DF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,
0xEFDF,0xEFDF,0xEFDF,0xEFFF,0xF6BA,0xFB8A,0xFBA9,0xFBE9,0xFB67,0xFA85,0xFA64,0xF9E4,0xF9A4,0xF9A3,0xF9C3,
0xFAE5,0xFB07,0xFAEA,0xFBF0,0xFB08,0xFAC2,0xFAC2,0xFAE2,0xFAE3,0xFA63,0xE123,0xD8E3,0xE943,0xF983,0xF9E4,
0xFAA5,0xC388,0x948A,0x94AB,0x9CAB,0xBD6F,0xD654,0xA52E,0x5B24,0x52C1,0x6BA4,0x6B85,0x5B04,0x5AE4,0x5B03,
0x5B43,0x73C6,0x73C5,0x52A7,0x4A87,0x7B6C,0xDEF8,0xE759,0xCE96,0xB593,0xBC4F,0xC4A8,0x9C46,0x7286,0x6903,
0xA104,0xB0E4,0xD144,0x6944,0x1963,0x3163,0x4225,0x4264,0x4264,0x31C3,0x6184,0xA905,0x9884,0x9084,0x8884,
0x98A4,0x9105,0x5226,0x1942,0x1923,0x1103,0x1923,0x1943,0x1923,0x2123,0x39A3,0x8426,0x2983,0x10E1,0x2122,
0x2122,0x2143,0x10E3,0x2104,0x6349,0x844A,0x4AA5,0x2163,0x08A3,0x6B89,0x5B08,0x2162,0x2161,0x31C2,0x52A5,
0x52E5,0x6383,0x8483,0x8C66,0x4282,0x3201,0x5B64,0x6144,0x7823,0x7842,0x7042,0x7042,0x7042,0x7042,0x7043,
0x7043,0x7843,0x8124,0x5165,0x28E4,0x1902,0x08C0,0x08E0,0x29A2,0x2162,0x1902,0x1102,0x10E2,0x1942,0x1901,
0x10E1,0x08C2,0x08C3,0x08E2,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,
0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,
0xDFDF,0xDFDF,0xE7BF,0xE7DF,0xE7DF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,
0xEFFF,0xEDB5,0xFAE9,0xFB48,0xFA86,0xFA05,0xF9C4,0xF124,0xE8E4,0xF0E4,0xF9A4,0xFB28,0xFB0A,0xF30C,0xFB2C,
0xFB07,0xFAE3,0xFAE3,0xFB03,0xFB03,0xFB02,0xFAA2,0xFA62,0xFAA3,0xFB04,0xFB05,0xFB06,0xCD0F,0xA4ED,0xBD8F,
0xEF17,0xB5AF,0x6363,0x5B00,0x7383,0x73C5,0x6325,0x83C8,0x8C09,0x7BE8,0x73C7,0x6BA6,0x7BC8,0x6B65,0x83E8,
0x5AE7,0x5A69,0x630A,0x5AC9,0x49E5,0x49A4,0x6247,0x9A24,0xDA85,0xD9C4,0xA0A3,0xA883,0xA8A4,0xA125,0x69E6,
0x4244,0x5A85,0x49C4,0x3983,0x2923,0x08E2,0x8945,0xC8C5,0x9064,0x8864,0x8084,0x8084,0x8084,0x61E3,0x6364,
0x7365,0x73A6,0x73C7,0x31C2,0x2922,0x39A3,0x5A84,0x52A3,0x2982,0x2123,0x18E3,0x0882,0x10A3,0x2984,0x6BA7,
0x5B48,0x2143,0x0883,0x1905,0x6BA9,0x7407,0x4A86,0x2985,0x3184,0x39E3,0x5B05,0x5B04,0x73E4,0x7CA2,0x8463,
0x3201,0x2941,0x4AA2,0x5B62,0x7144,0x7022,0x7042,0x7042,0x7043,0x7043,0x7043,0x7063,0x58A3,0x3962,0x2162,
0x1100,0x2160,0x6347,0x6B89,0x3A24,0x3A09,0x2144,0x29A4,0x29A3,0x1943,0x10E2,0x10E3,0x10C3,0x08C3,0x08C2,
0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xE7BF,0xE7BF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFFF,0xDE18,0xD147,0xE1A7,
0xE146,0xE105,0xD905,0xE0E4,0xE0E4,0xE8C4,0xFAE8,0xFBCB,0xFC8F,0xFC90,0xFC0E,0xFA84,0xFB23,0xFB23,0xFB22,
0xFB23,0xFB66,0xFCEB,0xFDCE,0xFE2F,0xF62D,0xFE0F,0xFD0D,0xCD4E,0xC58B,0xCE2D,0xA52A,0x7BC6,0x7BC6,0x9CCB,
0x94AB,0x946A,0xAD2E,0x9CCD,0x8C2B,0x7BE9,0x7387,0x6B87,0x6B66,0x6B64,0x5B05,0x5304,0x5A88,0x3145,0x3985,
0x4984,0x6985,0xD266,0xF205,0xF1E5,0xFAE4,0xE9C4,0xB104,0x79A5,0x61C4,0x5964,0x5A05,0x5245,0x58C3,0x8063,
0x7883,0x28C2,0x88E4,0xC084,0x9043,0x8064,0x8884,0x88A5,0x70A5,0x2103,0x31A3,0x4204,0x4A44,0x41E3,0x5265,
0x840A,0x73C8,0x4265,0x1903,0x10C2,0x0062,0x1903,0x4A86,0x3A24,0x2982,0x1922,0x1104,0x10E3,0x31A5,0x6B6B,
0x52E6,0x29A2,0x5B25,0x7BE8,0x5AE6,0x52A4,0x6BC5,0x6BE2,0x7424,0x6401,0x63C1,0x29E0,0x4243,0x6326,0x6384,
0x4A22,0x70A3,0x7823,0x7042,0x7843,0x7043,0x60A3,0x3902,0x2121,0x1100,0x10E0,0x2162,0x6BA7,0xADAE,0x4A67,
0x2966,0x2987,0x2164,0x2163,0x1923,0x1103,0x08C2,0x1103,0x08C3,0x08A3,0x08C2,0xCF7F,0xCF7F,0xCF7F,0xCF7F,
0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xE7BF,0xE7BF,0xE7DF,0xE7BF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFFF,0xEFBF,0xC30D,0xC8E6,0xC0E6,0xC8E6,0xD905,0xD8E4,
0xE0C4,0xE105,0xFB69,0xFC0C,0xFCB0,0xFD12,0xFC4F,0xFA02,0xFAA3,0xFB24,0xFB43,0xEAC5,0x9B6B,0xC6B2,0xB64F,
0xA5AB,0x8CE8,0x84A9,0x94AA,0x6262,0x83A4,0x8406,0x9429,0x9C8C,0xA50C,0x9D0B,0x8C6A,0xAD0D,0xBD90,0xAD2D,
0x944A,0x8409,0x7387,0x73A7,0x7BE6,0x6324,0x6347,0x9CF0,0x7BAC,0x4965,0x7ACA,0xA3AC,0xE4B0,0xFC8E,0xF268,
0xF123,0xEA84,0xB204,0x79C4,0x79C3,0x6163,0x71A3,0xA1C3,0xA924,0x9064,0x8043,0x9043,0x8042,0x9883,0xA843,
0x8843,0x8063,0x8064,0x80A5,0x40C4,0x1103,0x29C5,0x4AA6,0x52E5,0x6346,0x73E8,0x4AC5,0x1922,0x08A3,0x0882,
0x2123,0x52E6,0x73E9,0x52C7,0x08C2,0x08A3,0x08C3,0x1903,0x2143,0x4A86,0x31E6,0x10E3,0x10E2,0x1101,0x39E2,
0x4A66,0x4205,0x5B46,0x6BA6,0x63A1,0x7422,0x6BC3,0x42E1,0x4AC2,0x5B25,0x5B42,0x31E1,0x4983,0x7063,0x7843,
0x68E3,0x4122,0x2141,0x1120,0x08C0,0x31E3,0x73AB,0x73CA,0x6BA7,0x52C6,0x2965,0x2985,0x2162,0x2142,0x2143,
0x10E3,0x08C2,0x08E3,0x08E4,0x08C3,0x08C2,0x0881,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,
0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFDF,0xDFDF,0xDFDF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,
0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xF7FF,0xDE39,0xB947,0xC106,0xC906,0xD0E5,0xD0C5,0xD8A4,0xE9A6,0xFC0C,0xFC90,
0xF3AF,0xFC92,0xEB6B,0xD121,0xC941,0xB961,0xB162,0x8A07,0x5226,0x4A84,0x3A21,0x31C0,0x2180,0x2981,0x4A03,
0x6B28,0x8C4B,0x9CCC,0x9CAC,0x9CAB,0x9CEB,0xA50C,0x9CEB,0xB54E,0xB54E,0xBD6F,0x9C8C,0x946A,0x8C09,0x8C09,
0x8428,0x9D0D,0xC614,0x9CCD,0x7B47,0xCC6F,0xFE56,0xFDD4,0xFD11,0xFC6D,0xD2EB,0x9185,0x69A3,0x81A3,0x91A3,
0x6943,0x8902,0xE9E3,0xFA45,0xE1E6,0x9044,0x8043,0x8042,0x8823,0x8022,0x8822,0x7822,0x7842,0x7843,0x98A4,
0x6265,0x63A6,0x6BE5,0x5B44,0x3A43,0x29A3,0x1903,0x08A2,0x10A2,0x2984,0x4AA5,0x8469,0x52E5,0x10C2,0x08A2,
0x08C2,0x10C2,0x1923,0x2143,0x1923,0x10E3,0x1925,0x2185,0x2184,0x29A3,0x2965,0x1905,0x31E3,0x29C3,0x2983,
0x5302,0x8466,0x7C47,0x4A86,0x2161,0x29A2,0x2981,0x2961,0x31C1,0x4943,0x50C3,0x2161,0x2180,0x31C0,0x31E3,
0x4A86,0x9CF0,0x6B6B,0x7408,0x5B08,0x2944,0x2964,0x1963,0x1101,0x2122,0x2123,0x08C3,0x10E3,0x08E3,0x08C4,
0x08C3,0x08C1,0x08C1,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,
0xDFDF,0xDFDF,0xDFDF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,
0xEFDF,0xF7FF,0xCCB3,0xC0C6,0xD106,0xD0E6,0xD8E5,0xE0A4,0xFAA9,0xFD32,0xFC91,0xFCD1,0xF3CD,0xA0C3,0xA8C1,
0xC921,0xD941,0xFA02,0xA9C5,0x2925,0x2123,0x2162,0x31A2,0x59A3,0xA9A4,0xD267,0xBC2A,0x94AA,0x9C8B,0x9C8B,
0x948A,0xA4CB,0xA50C,0x9CCA,0xA4EA,0xA4CC,0x946B,0x8C6A,0x7BE8,0x842A,0x9CCD,0xAD50,0x8C4C,0x6326,0x52C4,
0xBC0C,0xFD52,0xFC2C,0xFC6D,0xEBAA,0xAB09,0x8A66,0x69C4,0x6963,0x89A2,0xC9E2,0xB083,0xD923,0xE964,0xEA05,
0xB925,0x9064,0x8843,0x8023,0x8823,0x8022,0x7822,0x6802,0x6822,0x7022,0xD963,0x9243,0x29C3,0x2143,0x1104,
0x1903,0x1903,0x1103,0x4225,0x6B68,0x8469,0x4264,0x1102,0x0081,0x08C2,0x10E3,0x08C2,0x08A3,0x10E2,0x10C3,
0x0884,0x0863,0x10A3,0x1904,0x1925,0x2988,0x2126,0x1905,0x3204,0x31A4,0x1901,0x4262,0x4264,0x31C3,0x29A2,
0x29A2,0x2983,0x31A4,0x2162,0x29A1,0x1941,0x2140,0x3201,0x4AC4,0x7C27,0x73AA,0x39E5,0x4244,0x6B88,0x42A6,
0x1901,0x2162,0x2163,0x2142,0x2943,0x1902,0x08E3,0x10C3,0x10C3,0x08E3,0x08C3,0x10C2,0x08E2,0x10E2,0xCF7F,
0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD79F,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7DF,0xE7BF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFFF,0xE77D,0xC22B,
0xD107,0xD127,0xD8E6,0xE0E5,0xFB4A,0xFCD0,0xFCF2,0xFD32,0xB145,0xA022,0xF902,0xF901,0xF921,0xF941,0xF982,
0x8905,0x3945,0x6984,0xA144,0xF265,0xF2C6,0xEA05,0xF245,0xB3A9,0x94CB,0x9CAB,0xA4EB,0xAD0B,0xAD0B,0xA52B,
0x94C9,0x94AB,0x8408,0x9C8B,0xA4ED,0xBDD2,0x9CCC,0x8C47,0x8409,0x7388,0x5B04,0xB368,0xFC8E,0xFC6F,0xB34B,
0x61E4,0x8A04,0x79A3,0x8123,0xA0A4,0xD0A3,0xE123,0xD122,0xE123,0xD923,0xFA85,0xC229,0x9084,0x9043,0x8823,
0x8822,0x8822,0x7802,0x6002,0x6022,0x8062,0xFA84,0x99C5,0x1944,0x2124,0x18E3,0x2983,0x4245,0x844B,0x842A,
0x3A24,0x10E3,0x0883,0x08C3,0x10E3,0x1103,0x08A3,0x0862,0x10A2,0x5286,0x73C7,0x7C28,0x8429,0x5AE7,0x2145,
0x10E4,0x2947,0x2145,0x2964,0x31C3,0x31C2,0x31A2,0x2962,0x31A1,0x3A01,0x4242,0x31E3,0x2183,0x2182,0x2161,
0x1921,0x18E2,0x3A22,0x5305,0x6389,0x3A24,0x1921,0x1921,0x2141,0x2162,0x1901,0x31A2,0x29A4,0x2163,0x3183,
0x2964,0x10E3,0x10E3,0x10E2,0x08C2,0x08C3,0x08A1,0x08C2,0x10E2,0x10E2,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,
0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xDFBF,0xD7BF,0xDFBF,0xDFDF,0xDFBF,0xDFBF,0xDFBF,0xE7DF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xF7FF,0xDE18,0xC948,0xD927,0xD8E6,0xE147,
0xFC6F,0xFCF1,0xFCB0,0xF4B0,0x9843,0x9023,0xE8C2,0xF8E1,0xF8E1,0xF921,0xF941,0xF142,0xE103,0xE8A3,0xE903,
0xFB86,0xFBA9,0xFB48,0xFA65,0xF286,0xAC2B,0xA4EC,0xA50B,0xA52A,0x94C8,0x8466,0x94C9,0xBD8F,0xC5D0,0xC611,
0x9CED,0x8C6A,0x8C28,0xA4EB,0x944B,0x83EB,0x6B87,0x9367,0xE42F,0x6A88,0x41C3,0x6983,0xA1A4,0xC9C5,0xF248,
0xC863,0xB023,0x9802,0x9082,0xE923,0xF1A2,0xC904,0xA106,0x9884,0x9043,0x9023,0x8823,0x8823,0x7802,0x6002,
0x7043,0xA0E4,0xF9C3,0x9923,0x1944,0x31C4,0x6B67,0x94AA,0x6B87,0x4245,0x1922,0x10E2,0x08C3,0x10C3,0x10C2,
0x10E3,0x10E3,0x08A3,0x0861,0x2104,0x7BA8,0x63A5,0x8CC6,0xADC9,0xA568,0x9D0C,0x948C,0x8C27,0x8CA3,0x52C1,
0x2981,0x31A2,0x39E2,0x6365,0x7C65,0x6C03,0x3A21,0x1940,0x1920,0x31C2,0x29A3,0x2162,0x2141,0x2982,0x2161,
0x2140,0x2160,0x2981,0x31E3,0x1942,0x1921,0x1901,0x39A2,0x2984,0x31A3,0x2983,0x1103,0x10E3,0x1923,0x1902,
0x10E3,0x08C2,0x08A2,0x08A2,0x08C2,0x1101,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,
0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,
0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFFF,0xE659,0xD987,0xD927,0xD0C6,0xEA29,0xFD32,0xFD93,0xFD73,0xC1A7,
0x9002,0x8823,0xD082,0xF8C2,0xF8C2,0xF8E1,0xF901,0xF921,0xF921,0xF8C1,0xF0E2,0xFB08,0xFB49,0xFB07,0xFB05,
0xFB48,0xCB8B,0x9CAD,0x7BAA,0x94AE,0xCE31,0xC60F,0xCE2E,0xC5EE,0xAD2D,0xAD4E,0xAD2D,0xA50D,0x8C6A,0x7BA8,
0x7368,0x944C,0xB58F,0x7BEB,0x69E5,0x81E4,0xC287,0xEB4A,0xF1C6,0xF227,0xE208,0xB822,0xA823,0xA023,0x8802,
0xD923,0xF1C3,0xB0C4,0xA064,0x9064,0x9023,0x9043,0x9023,0x8822,0x7802,0x6802,0x7843,0x88A4,0xE983,0xCB26,
0x73E7,0x73C6,0x6346,0x31E4,0x1903,0x10E3,0x1923,0x1943,0x1103,0x1103,0x08E3,0x08E3,0x08E3,0x08C3,0x10C3,
0x2924,0x4206,0x21A2,0x29C1,0x29C0,0x29A0,0x3A61,0x6344,0x52E3,0x5B21,0x4262,0x4A83,0x4AC2,0x5362,0x6403,
0x5321,0x3A42,0x2180,0x3202,0x6327,0x6BA8,0x4263,0x31C1,0x4A81,0x4A61,0x6B83,0x6B82,0x4AC4,0x2983,0x10E1,
0x2123,0x49C4,0x6284,0x5284,0x2984,0x39C4,0x41C6,0x1904,0x2984,0x29C6,0x2965,0x18E3,0x08A2,0x08A2,0x10E3,
0x1922,0x1902,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,
0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,
0xEFDF,0xEFFF,0xEEFB,0xEA29,0xD947,0xC0A6,0xEB2D,0xFD53,0xFCF2,0xD1E8,0xA003,0x9043,0x8022,0xB843,0xE062,
0xE882,0xF8A2,0xF8C1,0xF8C1,0xF8C2,0xF0A2,0xF0A1,0xF144,0xF32B,0xFBEB,0xFC8C,0xFBCA,0xCB8C,0x39A7,0x31A6,
0x39C5,0x7328,0x940A,0x9489,0x94A9,0xA50C,0xC5D0,0xC5D0,0xBDCF,0xB5AD,0x94E9,0x8446,0x9CC9,0x6347,0x3A24,
0x7A65,0xFA67,0xEA28,0xDA08,0xB8A4,0xC0E4,0xB063,0xB187,0xA8A4,0xA843,0x9023,0xC0C3,0xE184,0xC186,0xA084,
0x9044,0x9043,0x9843,0x9023,0x8822,0x7802,0x7022,0x7864,0x7885,0xE1A4,0xAAA4,0x4264,0x31A5,0x2924,0x1903,
0x2103,0x1922,0x1103,0x1903,0x10E4,0x10E3,0x08C3,0x08E3,0x1923,0x29A3,0x2162,0x2943,0x2124,0x1962,0x1961,
0x1941,0x1941,0x31C2,0x4266,0x5307,0x3262,0x2A00,0x3A81,0x4AE1,0x5B42,0x63A3,0x6B83,0x7C05,0x94C9,0x846A,
0x6B88,0x3226,0x29A5,0x4AC3,0x5B21,0x4AA2,0x4262,0x3A42,0x5B26,0x2123,0x31C2,0x41E4,0x4A05,0x62E5,0x62E4,
0x31E4,0x2983,0x31E6,0x2185,0x21C5,0x19C5,0x1104,0x08C3,0x08A2,0x10E2,0x2161,0x10E1,0x10E1,0xCF7F,0xCF7F,
0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xE7BF,0xE7BF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFFF,0xEF9E,0xF2EB,
0xD926,0xC0E7,0xFC91,0xFDF3,0xEB8D,0xA822,0xA043,0x8843,0x8023,0xB083,0xD083,0xD862,0xE082,0xF0C1,0xF8E1,
0xF8E1,0xF8E2,0xF921,0xE8C2,0xC882,0xD0C4,0xF2EA,0xFBEB,0xDBEB,0x3945,0x3164,0x39C4,0x39C3,0x7387,0xB5AC,
0xAD6B,0x9D0A,0xA549,0xAD6A,0x9508,0x7C26,0x8407,0xA4ED,0x73A8,0x5265,0x6325,0x4AC5,0x91A6,0xE1A6,0xDA28,
0xE2CA,0xF2A9,0xE205,0xD28A,0xA864,0xA843,0x9023,0xB105,0xB8E4,0xD9A7,0x9885,0x9864,0x9843,0x9843,0x9843,
0x9022,0x7802,0x7043,0x7064,0x7884,0xB0C4,0x8144,0x31C5,0x2124,0x2103,0x18E4,0x2123,0x1942,0x1903,0x18E2,
0x2122,0x1921,0x2121,0x2962,0x2981,0x31C2,0x1922,0x10C2,0x2124,0x2183,0x31E2,0x4A63,0x5B44,0x5B62,0x4B01,
0x3280,0x3AC2,0x5324,0x5303,0x5B44,0x5303,0x7C04,0x9D2A,0xA56D,0x8C6B,0x52A4,0x2163,0x2187,0x1904,0x1922,
0x3A25,0x3202,0x1961,0x4242,0x6B48,0x10C2,0x10E2,0x2123,0x39C4,0x62C4,0x6AE7,0x5266,0x29C4,0x2164,0x2164,
0x1984,0x1963,0x10E4,0x10E3,0x10E3,0x2143,0x29A1,0x2161,0x2122,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,
0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xF7DF,0xDB0D,0xB886,0xD1AA,0xFDB4,0xF4D1,
0xB0A4,0xA043,0x9844,0x8043,0x9023,0xA8A3,0xA8C3,0xD883,0xD882,0xE0A2,0xE8C2,0xF0E2,0xF902,0xF0E2,0xC062,
0xC083,0xC082,0xD986,0xFBEA,0xE3C7,0x8C29,0x83E7,0x9488,0x94A7,0x94A6,0x94A7,0x8C66,0x9487,0x8C68,0x94AA,
0x94A9,0xA4CC,0xAD2D,0x8C49,0x73A6,0x7C28,0x6BA8,0x5AE8,0x6A67,0xEA68,0xF2EA,0xD1E8,0xB906,0xB8E5,0xB084,
0xA863,0xA843,0x9002,0xB187,0xDAA9,0xD166,0xA8A5,0xA084,0x9844,0x9843,0x9843,0x9022,0x7022,0x7043,0x7884,
0x7884,0x6883,0x50E3,0x3983,0x62E4,0x6B04,0x5AC4,0x4222,0x2962,0x3162,0x3162,0x3181,0x2941,0x2122,0x1103,
0x10E3,0x1922,0x2163,0x29A2,0x3A03,0x4262,0x5B63,0x7443,0x6402,0x4301,0x42A2,0x5B45,0x5346,0x42C5,0x4AC4,
0x29E1,0x4282,0xA52D,0xAD72,0x6B86,0x4AE1,0x42A2,0x29A3,0x1904,0x1943,0x1923,0x4266,0x3A43,0x3203,0x1102,
0x1921,0x10E2,0x10A3,0x20E4,0x4A04,0x5A65,0x5A86,0x4A25,0x3A05,0x2142,0x1921,0x1921,0x1922,0x1922,0x2142,
0x31E2,0x4A83,0x4283,0x31C2,0x2142,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,
0xD79F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,
0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xF7FF,0xD618,0xA8A6,0xE2ED,0xFD74,0xC1A7,0xA023,0xA043,0x9043,0x8823,
0x9843,0xC885,0xA1A5,0xA903,0xD0A3,0xE0C3,0xF0E2,0xF122,0xD8A3,0xB842,0xB862,0xB882,0xC8A2,0xC8A2,0xEA47,
0xE3A7,0x8408,0x8409,0x9489,0x9CAA,0xA4CB,0xAD0C,0xBD8F,0xB58E,0xB58D,0xB56E,0x946B,0x8C2A,0x73C6,0x73C6,
0x8428,0x73A7,0x5B06,0x52C6,0x4285,0x8A47,0xC106,0xB0E6,0xA8C5,0xA884,0xA884,0xA864,0xA843,0x9843,0x9023,
0xE32C,0xEB2C,0xA8A6,0xA084,0x9864,0xA043,0x9823,0x8822,0x7043,0x7063,0x7064,0x7884,0xA903,0x6922,0x2122,
0x41E2,0x4222,0x39E2,0x2981,0x1901,0x1902,0x2123,0x1903,0x2122,0x2142,0x39C3,0x41E3,0x31C2,0x3A02,0x3A42,
0x2A40,0x3260,0x2201,0x3242,0x3244,0x3A43,0x4AC3,0x5B62,0x5323,0x2160,0x1920,0x7C0A,0xB5B3,0x846B,0x73E8,
0x63C1,0x5360,0x6383,0x3204,0x1104,0x21A5,0x1923,0x2141,0x2141,0x10E1,0x1101,0x4262,0x4A65,0x3185,0x41C4,
0x5AA5,0x5AA5,0x41C4,0x2121,0x2981,0x5245,0x5247,0x3986,0x2964,0x2143,0x1922,0x3163,0x3184,0x1903,0x18E2,
0x1923,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xE7BF,0xE7BF,0xE7DF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,
0xEFDF,0xEFFF,0xE6FB,0xC128,0xFCB2,0xDB6D,0x9803,0xA064,0x9844,0x9043,0x8842,0xA863,0xC085,0xB0A5,0x4083,
0x4843,0xC064,0xF123,0xF1A3,0xB863,0xB042,0xB862,0xB862,0xC082,0xC0A2,0xC8A2,0xDB6A,0xA50C,0xAD2C,0xA4ED,
0xA4CB,0xB58D,0xC5EE,0xCE11,0xBD4E,0xA4CB,0x7305,0x6B06,0x8409,0x9CAA,0x7C27,0x6B86,0x5305,0x5325,0x5B26,
0x3A65,0x3A26,0x81A7,0xA8A6,0xA8A5,0xA8A4,0xA8A4,0xA884,0xA863,0x9863,0x8844,0xC9E9,0xDA4A,0xA885,0xA885,
0xA064,0xA043,0x9823,0x7822,0x7043,0x7864,0x7063,0x8084,0xE964,0x6144,0x1144,0x1123,0x1963,0x31C4,0x2983,
0x2141,0x2981,0x31A2,0x5A43,0x5AC4,0x6324,0x4AC2,0x42A2,0x2A00,0x29E1,0x2982,0x2943,0x1903,0x10A3,0x2144,
0x29E4,0x42A4,0x4AE2,0x4B21,0x3A60,0x5303,0x94CE,0x6B8A,0x31E3,0x52E5,0x7C29,0x42E2,0x3A22,0x31C4,0x1103,
0x1103,0x1902,0x2141,0x31C2,0x2161,0x1942,0x2142,0x6303,0x41A6,0x4225,0x4224,0x31A2,0x2961,0x5A45,0x51E5,
0x5225,0x62A8,0x39C6,0x2944,0x2144,0x10E3,0x31A5,0x3187,0x10C2,0x10E2,0x1923,0x1102,0xC77F,0xCF7F,0xCF7F,
0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFFF,0xEE7A,0xFAEA,
0xFBEE,0xB106,0x9864,0xA084,0x9864,0x8843,0x9843,0xB884,0xB884,0xC8C5,0x88A3,0x1041,0x9864,0xD884,0xE944,
0xB863,0xB042,0xB042,0xB062,0xB882,0xC0A2,0xC882,0xB349,0x94CB,0x938A,0x6A25,0x83A7,0xD6F0,0x9D29,0x6B25,
0x6264,0x7B66,0x9C89,0x946B,0x9CCC,0x94AA,0x8C69,0x6BA6,0x4AE4,0x4285,0x3244,0x3204,0x29C4,0x39E6,0x7905,
0xA8A5,0xA8C5,0xA8A5,0xA884,0xA064,0x9864,0x4082,0xC28A,0xEB2D,0xB906,0xA084,0xA064,0xA043,0x9803,0x7822,
0x7843,0x8064,0x7884,0x80C4,0x9184,0x3963,0x2161,0x2161,0x2161,0x2981,0x2982,0x31C3,0x39C3,0x4AA3,0x5B63,
0x5B63,0x4AA3,0x2181,0x1922,0x1923,0x1924,0x1903,0x10C2,0x10A3,0x10A2,0x1903,0x29C4,0x3A24,0x3223,0x4AC3,
0x8C6C,0x73EA,0x4AA4,0x29C0,0x1921,0x3A25,0x5B27,0x4AA7,0x3A04,0x2163,0x1942,0x2142,0x2182,0x5303,0x2982,
0x0040,0x2962,0x5A83,0x7B63,0x41E4,0x31A3,0x2961,0x4A42,0x41C3,0x5A86,0x4A25,0x2943,0x39C3,0x62A7,0x3186,
0x2143,0x3185,0x2945,0x1103,0x10E2,0x1902,0x1102,0x31C2,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,
0xCF9F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFFF,0xEEDB,0xFB8C,0xD24A,0xA064,0x9864,0x9864,
0x9043,0x9843,0xA864,0xB8A4,0xB8A4,0xC0A5,0xC0C4,0x3842,0x9064,0xC884,0xD0C4,0xB863,0xB063,0xA842,0xB062,
0xB882,0xC082,0xC8C4,0xBBCB,0x7369,0x30A2,0x3121,0x31A1,0x4A82,0x29A0,0x4A64,0xAD0D,0xBD8F,0xB54E,0xACED,
0x9CAC,0x9CAB,0x8C2A,0x6326,0x4AA5,0x4285,0x2A23,0x2A03,0x29E3,0x3205,0x39C5,0x9926,0xA8A6,0xA885,0xA064,
0xB0A5,0x80E5,0x20E3,0xCA88,0xF34D,0xE2AB,0xE248,0xC924,0xD186,0x98E4,0x58C3,0x5123,0x5143,0x4942,0x7183,
0x7284,0x73A6,0x5AE6,0x2963,0x2963,0x2983,0x2962,0x6B48,0x4A85,0x29A2,0x2982,0x2123,0x10C3,0x10C2,0x10C2,
0x10C3,0x10E3,0x1103,0x10C2,0x10A3,0x0882,0x18C3,0x10C3,0x29A2,0x7C28,0x8C8C,0x6347,0x29C1,0x31C1,0x3A22,
0x2141,0x31E5,0x3227,0x2164,0x2983,0x6326,0x2142,0x1922,0x1962,0x42E1,0x2140,0x10C1,0x39E2,0x4202,0x41A2,
0x4A25,0x2163,0x5AC4,0x4A44,0x41E4,0x2983,0x2962,0x5225,0x8B8A,0x5248,0x2944,0x2144,0x2144,0x10E3,0x10E2,
0x10E2,0x10E2,0x10E1,0x1901,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF7F,0xCF9F,0xCF9F,
0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xD7BF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xE7DF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,
0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEF7E,0xF30B,0xB907,0xA085,0x9884,0x9063,0x9043,0xA864,0xB884,0xC0A4,
0xC0C5,0xC0A5,0xC0C5,0x5042,0x7864,0xC0A5,0xB884,0xB064,0xB063,0xA842,0xB062,0xC082,0xC0A2,0xB0C5,0xB38B,
0x5226,0x20C4,0x2962,0x1941,0x1941,0x4A84,0xAD2E,0xAD2D,0xACED,0xB52E,0xAD0D,0x948C,0x7BC9,0x6327,0x5AE5,
0x4AE5,0x42A5,0x3A83,0x3A83,0x2A03,0x31E4,0x29C4,0x51A5,0xC9E7,0xF226,0xE206,0xC146,0x38E5,0x3103,0xF48F,
0xEBAF,0xF32B,0xFC0E,0xD2EA,0xA288,0x6184,0x4923,0x58E3,0x68C3,0x78A4,0x9124,0x59E4,0x5285,0x5A87,0x39A5,
0x2962,0x2942,0x4204,0x7C2B,0x39E5,0x2984,0x1944,0x1923,0x1102,0x08C1,0x10E2,0x10C3,0x0882,0x08A2,0x18C3,
0x10A3,0x0862,0x10A2,0x4AA8,0x8C8E,0x8C8D,0x52C7,0x4263,0x29A3,0x08E1,0x1101,0x1101,0x10E3,0x1124,0x1964,
0x6365,0x6346,0x2162,0x29A1,0x1941,0x3A82,0x5B64,0x3A43,0x5B42,0x5B02,0x4A43,0x4A26,0x2163,0x5285,0x3A23,
0x31E2,0x5264,0x4207,0x6288,0x5207,0x2943,0x2123,0x1902,0x1103,0x10E2,0x10E2,0x10E2,0x1101,0x1901,0x1921,
0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xDFDF,0xE7DF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,
0xEFDF,0xEFBF,0xEB4C,0xA885,0xA0A5,0x9884,0xA063,0xA863,0xB8A4,0xC0A4,0xC0A4,0xC0A5,0xB8C5,0xB8C5,0x7043,
0x6064,0xA8A6,0xB085,0xA863,0xA063,0xA863,0xB882,0xB882,0xA8C4,0x90E6,0xAB8C,0x8C4A,0x3124,0x2143,0x4A85,
0x7BE8,0xB56E,0xBD8E,0xA4EB,0x9CAB,0xAD2E,0x948B,0x946A,0x7BE9,0x5B06,0x5B06,0x4AA6,0x4AA6,0x42A5,0x3A63,
0x3A43,0x29C3,0x2163,0x21A3,0x6227,0xBA68,0xC309,0x61A7,0x1103,0x7A47,0xFDD4,0xF40F,0xEACB,0xBA8A,0x92C9,
0xBAEA,0x8085,0x8044,0x8044,0x7864,0x8864,0x5904,0x31A4,0x3184,0x2143,0x2142,0x2142,0x18E1,0x5AA5,0x8449,
0x2143,0x1923,0x1943,0x1964,0x1923,0x10E2,0x08A1,0x1902,0x4225,0x4226,0x10E2,0x10A2,0x4225,0x83EB,0xAD70,
0x6B6C,0x4A68,0x73CB,0x7C2D,0x4A87,0x31A3,0x10E2,0x29C2,0x5B04,0x52C5,0x6BA6,0x6343,0x6363,0x3A43,0x5AE2,
0x31A2,0x2182,0x4AA3,0x7407,0x6385,0x52E3,0x6BA6,0x4A64,0x1942,0x2162,0x39C3,0x6B84,0x62E7,0x2985,0x1103,
0x08E1,0x1101,0x1902,0x1903,0x1922,0x10E2,0x10E2,0x1101,0x1921,0x2142,0x2983,0xC77F,0xC77F,0xCF7F,0xCF7F,
0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xE7BF,0xE7BF,0xE7DF,
0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFBF,0xEFDF,0xE7BF,0xF44E,0xC0E4,
0xA0A4,0xA064,0xC083,0xC0A4,0xC0A4,0xC0C4,0xB8A4,0xB8A4,0xB8C5,0xB8C5,0x8863,0x5844,0x9885,0xA885,0xB063,
0xA863,0xA063,0xA064,0x9884,0x98C5,0x98C6,0xA3CC,0xAD4D,0x9C8B,0x944A,0xAD2C,0xA50C,0x9CEB,0x9CCA,0xAD2D,
0xAD0C,0x94AA,0x8C49,0x8427,0x842A,0x8409,0x6B87,0x5B26,0x52E7,0x3243,0x3203,0x3A44,0x21E2,0x1962,0x1964,
0x2184,0x2164,0x1944,0x21C6,0x1964,0x9268,0xFCB0,0xFCD1,0xE42F,0x8208,0xFD94,0xC28E,0x8024,0x8843,0x8064,
0x8064,0x8064,0x8864,0x5125,0x2164,0x2143,0x2142,0x1902,0x18E1,0x5265,0x8468,0x41C4,0x2103,0x1103,0x1964,
0x1123,0x10E3,0x5287,0xD6D4,0xF7D9,0xEF79,0xA553,0x948A,0xA52A,0x7BEB,0x4267,0x4246,0x3A45,0x4285,0x52E6,
0x73C8,0x94CB,0x8C6A,0x8C6A,0x63A5,0x6BC3,0x6363,0x6324,0x4263,0x5B45,0x5B24,0x4A61,0x3A62,0x4A44,0x5AE3,
0x73C6,0x4224,0x2161,0x29A1,0x31E4,0x31C3,0x31C3,0x2963,0x2986,0x2145,0x1102,0x1901,0x2142,0x1922,0x1102,
0x1103,0x1102,0x1102,0x1922,0x1942,0x2944,0x31A5,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,
0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xCFBF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFBF,0xEFDF,0xEFDF,0xFCB0,0xD144,0xB0A4,0xC8C3,0xD0C4,0xC8C4,
0xC8C4,0xC0C5,0xB8A4,0xB8A4,0xB8C5,0xB8C5,0x9864,0x6883,0x68E5,0xA0A6,0xA884,0xA863,0xA063,0xA063,0x98A4,
0x98E6,0x9947,0xACCD,0xA50B,0xB56D,0xB54D,0xA4EC,0xA50C,0xA50B,0xAD4C,0xBD8F,0xAD2C,0x8CA8,0x7BE6,0x7BC7,
0x73C8,0x6367,0x5305,0x3A83,0x52A6,0x3A84,0x42A5,0x5B08,0x5B26,0x5B47,0x6368,0x4AC6,0x3A26,0x4286,0x3247,
0x3227,0x9267,0xFD93,0xFD55,0xD38E,0x8A28,0xCB0C,0x7885,0x8065,0x8863,0x9064,0x8064,0x8043,0x8863,0x3904,
0x1123,0x1923,0x1923,0x1902,0x2122,0x3184,0x52E6,0x6365,0x31A4,0x10C2,0x10C3,0x1103,0x10E3,0x62C9,0xCE75,
0xAD72,0x6B4B,0x6309,0x7B8B,0x4226,0x2164,0x31C4,0x3203,0x3203,0x3A43,0x4AA4,0x4263,0x4243,0x6346,0x6B68,
0x4AA4,0x4263,0x1941,0x4242,0x52C1,0x6B85,0x5304,0x4261,0x9D2A,0x4AA4,0x2942,0x39E3,0x31E3,0x3201,0x5B03,
0x6305,0x4A85,0x2162,0x18E1,0x1902,0x1101,0x1921,0x1902,0x1901,0x2121,0x2142,0x2143,0x2123,0x2144,0x2144,
0x1903,0x08E2,0x08E2,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,
0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,
0xEFDF,0xEFDF,0xEFBF,0xEFBF,0xEFFF,0xFC8F,0xFAA5,0xF1E3,0xE103,0xC8A4,0xC8C5,0xC0E5,0xB8E5,0xB8C5,0xB8A4,
0xB0C5,0xB0C6,0x9844,0x6883,0x3924,0x80C7,0xA0C6,0xA863,0xA862,0xA083,0x90C5,0x90A6,0xA2CA,0xB56E,0xA50D,
0xB52E,0xB54E,0xB52D,0xAD2D,0x9D0B,0xB58D,0xA50E,0x8C8A,0x8C89,0x7C27,0x6BA6,0x6B66,0x73C7,0x6386,0x42A5,
0x5AC8,0x52C7,0x3224,0x4246,0x4AA9,0x6B89,0x63A8,0x5B68,0x3A87,0x3246,0x3246,0x29E5,0x5A88,0x9B4D,0xAAAB,
0x6A47,0x3165,0x3164,0x70E5,0x9065,0x9065,0x9864,0x9043,0x8083,0x5903,0x1943,0x1103,0x1903,0x2143,0x31C4,
0x3206,0x29C4,0x31C5,0x4286,0x5B65,0x62C5,0x3183,0x2122,0x1902,0x3966,0x41C6,0x39C5,0x2943,0x31C5,0x29A5,
0x3A25,0x4A86,0x4285,0x31C4,0x29A3,0x2123,0x2143,0x29C4,0x31C3,0x3183,0x4A43,0x5B26,0x4244,0x2161,0x29C1,
0x6381,0x29C3,0x29C2,0x3A43,0x31E3,0x2141,0x1921,0x2162,0x31C4,0x4203,0x6363,0x4AA3,0x29A3,0x2142,0x1921,
0x2142,0x1922,0x1902,0x1902,0x1901,0x1921,0x2963,0x3184,0x1102,0x10E2,0x10E2,0x08E2,0x0901,0x08E2,0xC77F,
0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xDFDF,0xDFDF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,
0xEFDF,0xEEFA,0xF308,0xF983,0xD105,0xC0C4,0xC0C5,0xC0E6,0xB8E6,0xB8E6,0xB0E5,0xB0A5,0xB0A5,0x9823,0x68C2,
0x29C3,0x48C5,0x88A6,0xA0A5,0xA883,0x98A4,0x88A5,0x9228,0x9CAC,0x9CEB,0x9CCB,0xAD2C,0xAD0D,0xA50C,0x94AA,
0x8C69,0xAD2E,0x8C8C,0x8C89,0xA50C,0x8428,0x6BA7,0x7C28,0x73C8,0x6386,0x5307,0x52C8,0x5AE8,0x52A6,0x52C7,
0x4A87,0x4AC9,0x42E9,0x42E7,0x3246,0x2A47,0x3226,0x4AA8,0x3A67,0x29C4,0x19A4,0x2A05,0x31C5,0x2963,0x4103,
0x58E4,0x60E5,0x60C3,0x50E3,0x4123,0x5103,0x70A3,0x60C3,0x4185,0x29E7,0x29E6,0x3206,0x31E5,0x2983,0x2964,
0x4246,0x5B26,0x6345,0x6B66,0x7365,0x7388,0x6B26,0x6325,0x4263,0x31E4,0x31E5,0x3A26,0x3206,0x39E5,0x2964,
0x31E5,0x2945,0x2124,0x2123,0x2164,0x2143,0x39C3,0x5AE5,0x52A5,0x52A4,0x29A2,0x31A1,0x2982,0x3202,0x2982,
0x29A1,0x10E1,0x1940,0x42A1,0x31E4,0x4A85,0x3A04,0x3A25,0x1942,0x10E1,0x2962,0x2104,0x10E2,0x1101,0x1941,
0x2142,0x1922,0x1903,0x08C1,0x1101,0x0901,0x1102,0x10E2,0x08E1,0x08C0,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,
0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,
0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFBF,0xEFDF,0xEFDF,0xEFDF,0xE7FF,0xB44F,0xC945,
0xC0C5,0xB8C5,0xB8E6,0xB906,0xC126,0xC107,0xB106,0xB8C5,0xE124,0x9842,0x5984,0x3A63,0x1903,0x4945,0x88A6,
0x9064,0x9167,0xA42C,0xA4EB,0x9CEA,0xAD2C,0xB54D,0xAD4D,0xA4EC,0x9CCA,0x94AA,0x94CB,0xAD2E,0x94AB,0x8C4B,
0x840A,0x8428,0x7C0A,0x842A,0x73C9,0x6388,0x5B29,0x52E9,0x5B08,0x52C7,0x4266,0x29C4,0x31E5,0x3A27,0x4AC9,
0x4ACA,0x21E7,0x2A27,0x42A7,0x2A24,0x21C3,0x29C5,0x2A06,0x31E5,0x4267,0x4945,0x60E4,0x58E3,0x60C3,0x70A3,
0x8083,0x9822,0x90C4,0x82C9,0x4AA8,0x1985,0x1944,0x1943,0x1122,0x1102,0x1923,0x2124,0x2124,0x31A4,0x4A65,
0x4A84,0x5285,0x5285,0x5A85,0x31A2,0x2184,0x2185,0x2144,0x2124,0x2985,0x2945,0x2965,0x2965,0x2143,0x1922,
0x1922,0x2983,0x52A4,0x4A43,0x10E2,0x1101,0x3A02,0x4AC4,0x2181,0x2162,0x1903,0x2164,0x10E3,0x10E1,0x4AC2,
0x2162,0x2181,0x29A3,0x2183,0x39E3,0x4244,0x31E4,0x2102,0x1101,0x1101,0x1922,0x1102,0x1902,0x2944,0x2124,
0x08E2,0x1923,0x1924,0x1103,0x08C1,0x08A1,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,
0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7DF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xEFDF,0xEFBF,0xEFDF,0xEFDF,0xEFDF,0xEFBF,0xEFBF,0xEFDF,0x9574,0x8BCE,0xAA6A,0xC9A7,0xB907,0xB907,
0xB907,0xB107,0xA0C6,0xD166,0xFA24,0x9883,0x2103,0x1903,0x2123,0x29A5,0x71C7,0x9064,0x90A5,0xA34B,0xB58E,
0xB56D,0xAD0E,0xB52E,0xAD2D,0xAD2D,0xAD2D,0x9CCB,0x94AA,0x94AA,0x94CA,0x7C09,0x6B88,0x8409,0x8C4B,0x73C9,
0x6349,0x6369,0x6B29,0x52A9,0x4AE8,0x4287,0x3A45,0x31E4,0x4226,0x4207,0x4A68,0x3A07,0x1964,0x2A07,0x42A9,
0x31E6,0x29C6,0x3A46,0x29E4,0x4287,0x3A47,0x5905,0x9865,0x9043,0x9823,0xA043,0x9842,0x7062,0x5205,0x4A88,
0x31C6,0x2164,0x1123,0x1103,0x1103,0x1122,0x1103,0x08E3,0x10E2,0x2964,0x2964,0x1903,0x18E3,0x18C3,0x18E3,
0x18E3,0x2965,0x2986,0x2145,0x2144,0x1924,0x1923,0x1123,0x1943,0x2163,0x2983,0x2984,0x31C4,0x3A23,0x1961,
0x29C2,0x4AC3,0x7C27,0x5B07,0x1923,0x2164,0x1923,0x1123,0x1924,0x18E3,0x2142,0x31E2,0x2161,0x2161,0x31C1,
0x4205,0x2143,0x1942,0x2142,0x1922,0x10E2,0x10E1,0x10E1,0x2121,0x3185,0x3145,0x10E4,0x1903,0x10E3,0x10E2,
0x10E2,0x08C1,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,
0xCF9F,0xCF9F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,
0xEFDF,0xEFBF,0xEFDF,0xEFDF,0xEFDF,0x9D95,0x7C91,0x9CCF,0xDB2C,0xB128,0xA0C6,0xA0C7,0xA0C6,0x9885,0xE9C6,
0xFA03,0x60A3,0x10E3,0x10C3,0x10C3,0x2164,0x7B89,0x9126,0x9064,0x9085,0xA2AB,0xAD0D,0x9CCD,0x9CCC,0xAD2D,
0xAD0D,0x9CCB,0x94CA,0x9CAB,0x8C8A,0x8467,0x8CA8,0x73C8,0x6367,0x73C9,0x6B88,0x6349,0x6348,0x5AE8,0x52A8,
0x4AA7,0x4AC7,0x4286,0x3A45,0x4226,0x4A47,0x4207,0x29A5,0x1985,0x4227,0x39C6,0x1103,0x21C6,0x29E5,0x4288,
0x4269,0x1124,0x30E4,0x9085,0x8864,0x80A3,0x7883,0x58C3,0x39A4,0x29A5,0x1924,0x1945,0x1945,0x1103,0x1103,
0x1103,0x1103,0x1103,0x1103,0x1944,0x29A5,0x1923,0x0882,0x0882,0x0882,0x10A2,0x10A2,0x10C2,0x1904,0x20E4,
0x1924,0x2145,0x29A5,0x31E5,0x29A5,0x31C5,0x31A5,0x2964,0x1923,0x18E3,0x3A03,0x3A44,0x6367,0x6BC6,0x31E3,
0x1063,0x10E2,0x1102,0x1102,0x1923,0x1923,0x1922,0x1101,0x2982,0x39E4,0x2162,0x1901,0x31A1,0x3A22,0x1923,
0x1922,0x2102,0x1901,0x3162,0x39A5,0x3966,0x41A6,0x2124,0x10E2,0x10E2,0x1103,0x1102,0x08E2,0xC75F,0xC77F,
0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,
0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xE7BF,0xE7DF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xEFDF,0xEFDF,0xEFDF,0xEFDF,0xDF5E,
0xCEDA,0xA570,0x94EC,0x8CCA,0xAB29,0xE30C,0xC187,0xA8C6,0xA0A6,0xB947,0xE1A6,0xE9A2,0x30C3,0x10C3,0x10C3,
0x10C2,0x1903,0x7389,0x9C0A,0x88A4,0x9084,0x9085,0x9A8A,0x9CEC,0xA4CC,0xA4CC,0xA4EB,0x948A,0x8C4A,0x948B,
0x9CEB,0x94CA,0x94EA,0x8C69,0x6BA9,0x7C08,0x840A,0x6B8A,0x6369,0x5AE7,0x4267,0x4268,0x4267,0x3A66,0x3226,
0x4266,0x4A47,0x4206,0x3205,0x29C5,0x7309,0x39C6,0x29C7,0x21C6,0x21E7,0x2165,0x10E3,0x08C2,0x1944,0x3925,
0x4965,0x4A07,0x2164,0x2163,0x2144,0x0903,0x1124,0x1104,0x08C3,0x1103,0x1103,0x1102,0x1922,0x1103,0x1104,
0x1965,0x1903,0x10E2,0x08A2,0x08A2,0x0882,0x10E3,0x18C3,0x10E2,0x10C2,0x0061,0x2143,0x6308,0x7BE9,0x3A05,
0x2944,0x1904,0x18E4,0x2146,0x2126,0x1905,0x4A66,0x7385,0x9C89,0x8C09,0x5AE6,0x20E4,0x10A2,0x1923,0x1963,
0x1963,0x1922,0x10E1,0x18E1,0x18E1,0x2922,0x4A23,0x4A43,0x4A43,0x5282,0x29A2,0x2162,0x2141,0x4203,0x8389,
0x72AB,0x20E4,0x3164,0x39A5,0x2944,0x2944,0x2122,0x10E2,0x10C2,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xC77F,
0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7DF,0xE7DF,0xE7BF,
0xE7BF,0xE7DF,0xE7DF,0xE7BF,0xE7BF,0xEFDF,0xEFDF,0xDF7F,0xD6FB,0xCE98,0xADD1,0x9D0B,0x94AA,0x8C89,0x7C28,
0x944A,0xFC2F,0xF26A,0xE228,0xEA87,0xFB29,0xFA85,0xA9A3,0x10C3,0x08C2,0x10C2,0x18E2,0x2944,0x7388,0xAD6C,
0x9308,0x8885,0x90A5,0x9228,0x94CB,0x9CCB,0xACEC,0xAD0D,0x9CAB,0x840A,0x83EA,0x94AB,0x94CA,0x8449,0x8C6A,
0x7BEB,0x844A,0x7BEA,0x632A,0x5B28,0x5B28,0x4AA8,0x52C7,0x4AA6,0x4246,0x29C4,0x31C5,0x5AAA,0x4207,0x4226,
0x72E7,0x7B4A,0x5246,0x31A6,0x29A6,0x2986,0x10E4,0x0903,0x21A6,0x2185,0x1124,0x29C5,0x4206,0x1943,0x1122,
0x1123,0x1144,0x1104,0x08C3,0x1103,0x1123,0x1103,0x1943,0x1923,0x10A2,0x1903,0x1924,0x10E2,0x0082,0x0061,
0x0041,0x0882,0x10E3,0x1902,0x1903,0x3183,0x7388,0x8CAB,0x4AA5,0x2964,0x1903,0x1904,0x10A3,0x10A3,0x1925,
0x2124,0x3185,0x2124,0x1903,0x4244,0x3A43,0x4263,0x2163,0x18A3,0x2123,0x1922,0x1901,0x10C1,0x2962,0x31C4,
0x10A3,0x10A2,0x52A5,0x5285,0x41E4,0x4A04,0x31C2,0x39A2,0x8C49,0xE756,0xB575,0x3187,0x31E3,0x39A6,0x2964,
0x1921,0x2963,0x2125,0x08C3,0x10E3,0xC75F,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,
0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7DF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,
0xE7DF,0xD71C,0xC679,0xB5F4,0xA54D,0x9CEB,0x9D0B,0x8CAB,0x844A,0x844A,0x7BE8,0x6BC6,0xABEB,0xFC0F,0xFC8E,
0xFBC9,0xFB69,0xEAE5,0x4163,0x10E2,0x10C2,0x10C2,0x10E2,0x29A3,0x7BC9,0x9CCC,0x9CCC,0x92A8,0x9B49,0x944A,
0x94A9,0x9CCA,0x9CEB,0x948B,0x8C6B,0xA50C,0x83EB,0x6B69,0x7BE8,0x8429,0x6B68,0x6329,0x6329,0x6369,0x5B29,
0x6348,0x4AA8,0x52A8,0x52C8,0x4AA8,0x4287,0x4267,0x3207,0x4A49,0x29C5,0x4A26,0x6AC8,0x5A67,0x5A67,0x39A4,
0x2964,0x1904,0x08E3,0x1965,0x1965,0x08E3,0x1103,0x31A5,0x39E5,0x1964,0x1944,0x1944,0x10E2,0x08C2,0x1903,
0x1944,0x1123,0x1122,0x1903,0x08A2,0x0881,0x1922,0x1902,0x08C2,0x5AE8,0x8CEA,0x6BA7,0x2183,0x1122,0x29C3,
0x6B85,0x8448,0x5B26,0x2963,0x10E2,0x18E4,0x1904,0x1924,0x10A3,0x10A3,0x2144,0x2984,0x29A4,0x2144,0x3A03,
0x5B05,0x6304,0x4222,0x31E1,0x1922,0x1101,0x2962,0x2143,0x1903,0x2163,0x2144,0x0883,0x18C2,0x2982,0x2123,
0x4A05,0x4A25,0x2162,0x41C4,0x62E7,0x530A,0x3A07,0x29C5,0x29A4,0x2963,0x31A3,0x2965,0x2145,0x1944,0x10E1,
0x08C1,0xC77F,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,
0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xE7DF,0xE7DF,0xD75D,0xADB1,0x9D2D,0xA52D,
0x94CB,0x844A,0x7409,0x7C0A,0x7C08,0x842A,0x7C08,0x73E7,0x6BC6,0xB44B,0xFCD0,0xFBAA,0xFB8A,0x6983,0x1902,
0x10C2,0x10A2,0x1902,0x31E2,0x3A23,0x7BC8,0x94AC,0x9CCC,0xAD4D,0xA54D,0xA50C,0x9CEB,0x9CEA,0x9CCB,0x8428,
0x8428,0x946B,0x8C0A,0x7388,0x6327,0x7389,0x7BC9,0x73CA,0x6329,0x6B89,0x6B8A,0x52E9,0x4287,0x4AA8,0x4268,
0x3207,0x3A47,0x3A07,0x3206,0x3A07,0x2185,0x4A26,0x5A67,0x5A87,0x5A46,0x4225,0x31A4,0x1924,0x1924,0x1944,
0x1925,0x1104,0x1945,0x41E6,0x39E6,0x29C5,0x2164,0x08E2,0x08C1,0x1923,0x2165,0x1124,0x1123,0x1102,0x10C2,
0x10C1,0x10E2,0x1902,0x20E2,0x7984,0xCB4A,0xBC6B,0x7C28,0x4A65,0x2141,0x4A81,0x3A42,0x10E1,0x10A2,0x18E3,
0x18E3,0x2104,0x1924,0x1924,0x10C3,0x10C3,0x2104,0x1903,0x2924,0x3185,0x29C1,0x2161,0x4244,0x3A03,0x2141,
0x2161,0x2142,0x2143,0x10E2,0x2943,0x2102,0x10E2,0x1903,0x3A02,0x4223,0x3164,0x39C4,0x4204,0x3183,0x2943,
0x2101,0x2101,0x2983,0x1922,0x1923,0x3985,0x49E7,0x2144,0x10E2,0x10C2,0x10C2,0x10C3,0xC77F,0xC77F,0xC77F,
0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xE7BF,0xD75E,0xB615,0x94CD,0x8C6B,0x94AC,0x846B,0x846E,0x6BA9,0x6B88,
0x7BE9,0x8469,0x73E7,0x73C7,0x6BC7,0x7C26,0xABC9,0xE349,0x9A47,0x1902,0x29A3,0x3A03,0x4A85,0x4A84,0x29C2,
0x31C3,0x7388,0x9CCC,0xA4ED,0xAD0E,0xA50D,0xAD2D,0x9CCC,0x9CAB,0x8C2A,0x8408,0x948A,0x944A,0x7387,0x6B68,
0x5AE7,0x7389,0x7369,0x738A,0x6B68,0x7388,0x6B49,0x4AA8,0x3A67,0x3A68,0x3228,0x29E7,0x3A06,0x29C6,0x29C6,
0x3207,0x29A5,0x4207,0x4A27,0x39C5,0x41C5,0x39C5,0x3185,0x2965,0x2144,0x1924,0x2144,0x1925,0x39A6,0x39E6,
0x2184,0x2984,0x10E2,0x08A2,0x08C2,0x1923,0x1944,0x1123,0x1923,0x10E2,0x10E2,0x10A1,0x08A1,0x30E2,0xBA07,
0xC985,0xA0A4,0x8843,0x4861,0x10C0,0x1943,0x29A4,0x20C4,0x2062,0x1082,0x08A3,0x10C3,0x2143,0x1924,0x1905,
0x18E3,0x2963,0x2182,0x08A3,0x18C3,0x3163,0x4A84,0x3A04,0x1101,0x1101,0x2142,0x39E2,0x1922,0x2143,0x2944,
0x10C2,0x0082,0x08C2,0x3A23,0x4262,0x4A44,0x4A64,0x4A43,0x39E3,0x2962,0x2122,0x2943,0x2963,0x31A4,0x3184,
0x2944,0x1903,0x18E2,0x2965,0x10C4,0x10C3,0x10E3,0x1903,0xC77F,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,
0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xCF9F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,
0xE7DF,0xE7DF,0xDF9F,0xA5D5,0x846C,0x5B48,0x73CA,0x73EB,0x73EC,0x7C2B,0x6B88,0x7C09,0x8C8A,0x73E7,0x8428,
0x7C08,0x73E5,0x5B83,0x4A82,0x29C1,0x29C3,0x4245,0x6BC7,0x73E6,0x5B45,0x3222,0x29E2,0x6346,0x9CCB,0x9CCD,
0xA4CD,0xA4ED,0xA50C,0x9CAC,0x7C29,0x73A7,0x6B87,0x840A,0x83C9,0x7389,0x6B48,0x6308,0x6327,0x73A9,0x73A9,
0x6B88,0x4AA7,0x4287,0x3A45,0x3228,0x2A07,0x3207,0x3208,0x21A5,0x31E6,0x21A5,0x31C6,0x29A5,0x31C6,0x39E6,
0x2964,0x3184,0x2985,0x2164,0x39C6,0x3186,0x2965,0x2164,0x2144,0x39A5,0x4206,0x39C4,0x39C4,0x1102,0x1102,
0x1942,0x2163,0x2163,0x1943,0x10E3,0x10C2,0x18E3,0x10A2,0x3943,0xA227,0x9064,0xA8C4,0x9083,0xA103,0xA924,
0x3882,0x08E2,0x3144,0x78C4,0x8084,0xA9E5,0x4165,0x10E3,0x4246,0x3A06,0x2965,0x2964,0x31E2,0x4282,0x42A5,
0x4264,0x31A3,0x2963,0x31E2,0x4223,0x2983,0x2143,0x2942,0x2982,0x1902,0x1103,0x0881,0x10E2,0x29C2,0x29E2,
0x3A23,0x3A03,0x5B45,0x6344,0x3181,0x2962,0x39E3,0x2122,0x1922,0x29A5,0x2964,0x3183,0x1903,0x18C2,0x2125,
0x10E4,0x1104,0x1925,0x18E4,0xC75F,0xC77F,0xC77F,0xC77F,0xCF7F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,
0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xE7DF,0xC698,
0x94EC,0x6368,0x6369,0x638A,0x6BCE,0x8CD1,0x846B,0x8C8A,0x8448,0x6BA7,0x73E9,0x7C27,0x7406,0x4AE4,0x29E2,
0x21A2,0x4AA5,0x4AA4,0x8429,0x8448,0x6365,0x5B05,0x3A23,0x6367,0x8C6A,0x842B,0x9C8D,0x9CCC,0x9CEB,0x9CCC,
0x8C4A,0x6326,0x73A8,0x7368,0x7389,0x7389,0x6328,0x6B86,0x7387,0x7BC9,0x7389,0x6B49,0x3A46,0x3A46,0x3226,
0x31E6,0x29E5,0x29E6,0x29E6,0x29C6,0x3207,0x29C7,0x29A6,0x29C5,0x31E6,0x31A6,0x3164,0x2984,0x2964,0x31C5,
0x39C6,0x3186,0x2965,0x1945,0x1924,0x31A5,0x39C5,0x41C5,0x2143,0x1921,0x2142,0x29A3,0x29A3,0x2983,0x2143,
0x18E3,0x18C3,0x18E3,0x1081,0xC2C8,0xE2EC,0x7823,0x8863,0xA8C3,0xFA85,0xF206,0x90E3,0x00A1,0x48C3,0x8064,
0x90E3,0xFAE7,0xCA69,0x28C4,0x18E4,0x3184,0x2964,0x31A3,0x31C2,0x3243,0x4AA6,0x4A86,0x2162,0x3A01,0x52C4,
0x73C8,0x52C5,0x4243,0x4225,0x2103,0x10E2,0x1123,0x08E3,0x08C2,0x08C2,0x2982,0x31C4,0x1921,0x31C1,0x3A02,
0x4A63,0x6B46,0x52A4,0x2142,0x2962,0x3182,0x4205,0x3184,0x20E4,0x10E3,0x1903,0x10C3,0x1925,0x2968,0x2105,
0xC75F,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,
0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xDFBF,0x9DB3,0x63AA,0x6BAB,0x8CAE,0x7C0C,
0x73EF,0x638A,0x6B89,0x846A,0x7C08,0x6B67,0x6368,0x6B87,0x5B64,0x3223,0x1982,0x3204,0x4284,0x4286,0x8449,
0x6366,0x31E3,0x2984,0x1903,0x5B07,0x9CCB,0x842A,0x7C0A,0x9CAC,0xBDAF,0xA4CC,0x8429,0x8C4A,0x840A,0x8409,
0x7387,0x7BE8,0x73A9,0x7C07,0x73E7,0x6B67,0x6348,0x6308,0x4AA5,0x5305,0x4286,0x3206,0x31E5,0x29C4,0x29E5,
0x31E6,0x29A6,0x2986,0x29C6,0x29C7,0x29C6,0x31C6,0x39C6,0x2985,0x2984,0x31C6,0x2965,0x3165,0x2144,0x2164,
0x4226,0x5248,0x31A6,0x3185,0x2142,0x1902,0x1902,0x1923,0x2123,0x10E3,0x10A2,0x10A2,0x10A2,0x08A2,0x38C3,
0xD104,0xB8C5,0x8043,0x7843,0xA0A3,0xE184,0xC8C3,0xB103,0x20C1,0x88A3,0x90A3,0xC143,0xF245,0xEA26,0x7965,
0x2142,0x31A3,0x29A4,0x1982,0x3A41,0x4262,0x2162,0x1920,0x4A62,0x31C3,0x1923,0x31C4,0x4203,0x4244,0x31C5,
0x10C2,0x2141,0x2161,0x08C2,0x08C2,0x1102,0x1922,0x1901,0x29C2,0x6345,0x8467,0x6B86,0x4A43,0x39A3,0x3143,
0x2163,0x1902,0x10C2,0x2943,0x2105,0x3145,0x2105,0x10C3,0x1925,0x29AA,0x18E5,0xC75F,0xC77F,0xC77F,0xC77F,
0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,
0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xE7FF,0x9DD5,0x4AC7,0x52E9,0x6B8C,0x636A,0x5B29,0x6BA9,0x7C09,0x73E8,
0x6367,0x6327,0x6B67,0x73E8,0x6BA6,0x3A63,0x2183,0x6367,0x42A5,0x5B47,0x7C29,0x5305,0x4264,0x39E4,0x1963,
0x7369,0x9CCB,0x844A,0x946B,0xA4ED,0xAD2D,0xA52C,0xA52C,0x94A9,0x73C7,0x6B48,0x7387,0x8448,0x73A7,0x73C7,
0x73C7,0x6BC6,0x6B86,0x6367,0x73A7,0x7BE9,0x6328,0x3A26,0x3205,0x29E5,0x4A68,0x31C6,0x21A5,0x21A6,0x2186,
0x2985,0x2164,0x2985,0x2985,0x2964,0x29A5,0x31A6,0x29A5,0x2964,0x39A5,0x4227,0x39C7,0x2965,0x2985,0x3164,
0x1903,0x08C2,0x10E3,0x10E3,0x10C2,0x0881,0x0881,0x0881,0x1081,0x00C2,0x48A3,0xA883,0xC0A2,0x9842,0x8042,
0x8042,0xA883,0xB8A3,0xB0C3,0x60E2,0xC0E3,0xD9A3,0xF224,0xC9A5,0xA126,0x80C5,0x4223,0x3A42,0x52C3,0x6304,
0x6326,0x31C2,0x18E1,0x1902,0x2984,0x10C1,0x0880,0x10C1,0x1902,0x3A24,0x1924,0x1922,0x4AC4,0x52C4,0x4A85,
0x3A24,0x1120,0x21A0,0x6BC6,0x8428,0x73A6,0x62C5,0x41C4,0x5A45,0x49C5,0x3963,0x3163,0x1902,0x08A2,0x10E2,
0x39A6,0x49EA,0x18C6,0x1905,0x1924,0x1924,0x1904,0xC75F,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,
0xCF7F,0xCF7F,0xCF9F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,
0xE7DF,0xE7DF,0xAE16,0x5B68,0x5B28,0x4288,0x4AC9,0x5B2A,0x73CB,0x844B,0x7C09,0x6347,0x5B07,0x73C8,0x7C0A,
0x73E8,0x5B24,0x5B26,0x6B87,0x5326,0x7409,0x6BC8,0x6366,0x52E6,0x4265,0x29E4,0x52E8,0xA4EC,0xA50C,0x8C6A,
0x948A,0xB56D,0xB56D,0xAD4C,0xA50A,0x9489,0x8408,0x8C48,0x8C29,0x8428,0x8447,0x73E7,0x6B88,0x73C9,0x7C09,
0x8C4A,0x73AA,0x6328,0x52E5,0x3205,0x29C5,0x3A07,0x1964,0x2185,0x2185,0x1944,0x29A5,0x2185,0x2143,0x2144,
0x1943,0x2164,0x2985,0x31C6,0x2985,0x31C6,0x31C6,0x1923,0x2163,0x49A6,0x80E5,0x7063,0x40C3,0x1123,0x10E2,
0x10C1,0x10C1,0x10C1,0x08A0,0x08A1,0x40C2,0x8883,0x9822,0xB902,0xC8C3,0x8822,0x7022,0x7822,0x8022,0x9042,
0xA0A3,0xC0C3,0xFA24,0xD964,0x8884,0x78A4,0x7864,0x5984,0x6347,0x6BA8,0x52A6,0x31E2,0x2141,0x1901,0x1902,
0x1902,0x10A1,0x10C1,0x10E2,0x2962,0x31E2,0x2124,0x2983,0x52A6,0x7C27,0x7C28,0x3A44,0x21A1,0x4AC2,0x6B86,
0x6305,0x39E4,0x49E5,0x41C4,0x5265,0x41C4,0x39A4,0x41C5,0x2103,0x1902,0x3163,0x49C6,0x2906,0x10A3,0x1924,
0x18E2,0x2167,0x2969,0xC75F,0xC75F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,
0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xDF9F,0xBE79,0x9D30,0x8C8C,
0x7409,0x5307,0x4288,0x52EB,0x638C,0x740B,0x73C9,0x73C8,0x5B07,0x6347,0x6368,0x6B88,0x6385,0x6386,0x6366,
0x5B66,0x63A7,0x6BA7,0x4AE5,0x3A25,0x3204,0x29A5,0x6B69,0xA4EC,0x9CEB,0x9CEA,0xA50B,0xB58E,0xAD6D,0xA52B,
0x9CCA,0x9CCA,0x94CA,0x9489,0x94A9,0x9CEA,0x8CA9,0x7C28,0x73E8,0x6B88,0x840A,0x946C,0x7369,0x52C6,0x4AC5,
0x3225,0x21A4,0x21A5,0x1985,0x2185,0x2184,0x1964,0x2165,0x2185,0x2984,0x2964,0x2163,0x2183,0x31A4,0x2985,
0x2964,0x1923,0x2144,0x2944,0x2164,0x5105,0x9885,0x9884,0x9043,0x5882,0x2922,0x1981,0x2181,0x1121,0x3922,
0x70E3,0x9885,0xA043,0xB8C3,0xC9A7,0x9884,0x8842,0xA882,0xD8E2,0xC081,0x9001,0xA842,0xD943,0xFA24,0xA0C4,
0x9084,0x8043,0x7965,0x8369,0x5AE6,0x31C3,0x10E1,0x2981,0x1901,0x2141,0x1901,0x10C1,0x0841,0x0861,0x1902,
0x2983,0x29C4,0x4244,0x4264,0x5AE5,0x6326,0x31C3,0x39A2,0x31A2,0x5285,0x4AA4,0x5303,0x4262,0x3A02,0x5A65,
0x5265,0x3983,0x39A4,0x41E7,0x2124,0x1902,0x2103,0x3144,0x2905,0x10A4,0x1903,0x2104,0x1906,0x2968,0xC75F,
0xC75F,0xC75F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,
0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xD79F,0xA5F5,0x7C2D,0x7C0A,0x5B48,0x4AA7,0x3A68,0x4AAA,
0x7C72,0x8D13,0x8C6C,0x8409,0x4AC6,0x5B07,0x5B47,0x6367,0x6BA6,0x7407,0x6B86,0x5B66,0x7408,0x6BA8,0x42A5,
0x31E4,0x29C4,0x1944,0x6B4A,0xAD2D,0x9CEB,0xA50C,0xAD2D,0xA4ED,0x9CCB,0x94C9,0xA4EB,0xA50B,0xA52B,0x8C8A,
0x8C4A,0x9CAC,0x94AA,0x94AA,0x844A,0x6BA8,0x8C4C,0x8C4C,0x5B09,0x4248,0x3225,0x29C4,0x2184,0x2184,0x2185,
0x1943,0x1965,0x1984,0x1964,0x1944,0x2985,0x2164,0x1923,0x29A4,0x4A25,0x29A3,0x3184,0x2143,0x1923,0x3185,
0x2984,0x6904,0x9865,0x9085,0xA084,0xA043,0x7062,0x40E1,0x1902,0x6184,0xB0E5,0xA045,0x9823,0xA842,0xA042,
0x9044,0x8884,0x8043,0x9882,0xE942,0xE8C2,0xB021,0xB041,0xF203,0xE1A5,0xB165,0x99E5,0x7285,0x72E5,0x6285,
0x31E2,0x2982,0x10E1,0x08E1,0x1101,0x10E0,0x2141,0x3A23,0x3A43,0x4A84,0x6B85,0x5B25,0x4243,0x7388,0x4206,
0x31A4,0x2962,0x2161,0x49E3,0x41C4,0x3183,0x3201,0x42E1,0x5304,0x8C69,0x7B69,0x62C6,0x49E4,0x5225,0x3164,
0x3965,0x62A8,0x6367,0x7C07,0x83E9,0x6347,0x4205,0x20E6,0x1905,0x2125,0xC77F,0xC77F,0xC77F,0xC77F,0xC77F,
0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,
0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xBEDB,0x63ED,0x5B4B,0x3AC9,0x3A8A,0x4B0D,0x428A,0x530D,0x7410,0x846B,0x73C9,
0x5B07,0x6B89,0x73EA,0x7C28,0x7408,0x73E9,0x5B47,0x5B27,0x7409,0x6BA7,0x5325,0x4AC4,0x4A85,0x2184,0x73A9,
0x9CEC,0x9CEC,0xA50B,0x9CEB,0x9CCB,0xA4CB,0x94AA,0x9C8A,0x94CA,0x8409,0x7BC9,0x8C4B,0x948C,0xA4CD,0x8C4A,
0x6BC7,0x6367,0x6B68,0x6B68,0x4A87,0x4A68,0x21A5,0x1963,0x1943,0x1944,0x1965,0x1103,0x1944,0x2185,0x1964,
0x1944,0x2945,0x2163,0x2163,0x2184,0x29A5,0x31C3,0x2983,0x2143,0x2163,0x31C5,0x2184,0x81A5,0xB0C5,0x9865,
0x9865,0x9064,0x8822,0x7001,0x78C3,0xB926,0xA823,0x9822,0x9023,0xA822,0x9863,0x8885,0x8864,0x9043,0x7821,
0x9841,0xB042,0xA001,0xB021,0xD102,0xA9E6,0x9388,0x9C69,0x9284,0xB9C5,0x8184,0x3A42,0x31E1,0x4243,0x52E4,
0x4AA3,0x6364,0x8C66,0x8C86,0x5322,0x3A42,0x2161,0x1942,0x2145,0x41E7,0x3165,0x5B06,0x6BC7,0x4A85,0x2980,
0x4A62,0x29A2,0x42A1,0x5B25,0x5B25,0xB5CD,0x948B,0xA449,0x6285,0x41E4,0x39A5,0x5226,0xB4CE,0xCE6F,0xDF6F,
0xDF2D,0xD70C,0xBE0C,0x842B,0x8448,0x7C04,0xC75F,0xC75F,0xC77F,0xC77F,0xCF7F,0xC77F,0xCF7F,0xCF7F,0xCF7F,
0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,
0xE7DF,0x8514,0x42EC,0x42EC,0x3AAC,0x2A09,0x4ACD,0x532D,0x63AB,0x94CC,0x6B68,0x4A86,0x3A46,0x73A9,0x6366,
0x6B88,0x6387,0x4285,0x73C8,0x7409,0x5B86,0x3243,0x3246,0x5B68,0x42A6,0x8C4C,0x9CEB,0xA50B,0xA52B,0xA50B,
0xA4EC,0xA4EC,0xA4EB,0x9CCB,0x8C6A,0x8C49,0x948B,0xA4EC,0x948A,0x9CCC,0x8C69,0x9CAB,0x944C,0x7389,0x5B07,
0x4AC6,0x4266,0x31E6,0x2185,0x1964,0x1944,0x1964,0x1124,0x1123,0x1944,0x2144,0x2164,0x2964,0x2163,0x2143,
0x1923,0x2164,0x2163,0x2963,0x2163,0x1922,0x1924,0x2164,0x3144,0xDA45,0xD165,0x9885,0x8864,0x8043,0x7842,
0x7822,0x7802,0x9022,0x9822,0x8802,0x9043,0x8864,0x8864,0x8863,0x8864,0x8022,0x8021,0x9001,0x9021,0xB9C4,
0xA3A7,0x946A,0xAB46,0xD226,0xD1C7,0xA906,0x6923,0x5B04,0x8C4A,0xA52A,0x8C67,0x5B03,0x52C3,0x7C06,0x7C46,
0x42A1,0x29A1,0x0881,0x18E3,0x2126,0x52A6,0x6323,0x6B84,0x94EB,0x7C27,0x5303,0x62E3,0x6BA5,0x63A3,0x6B66,
0x73A6,0x6B85,0x6385,0x6B47,0x41E4,0x39C2,0x39A5,0x4185,0x9C4B,0xACD0,0xA58A,0x9D27,0x7C25,0x5B23,0x8C67,
0x7BE7,0x5B02,0xC75F,0xC75F,0xC75F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,
0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xDFBF,0xB69B,0x5BCF,0x42EB,
0x324A,0x3209,0x532E,0x42CC,0x7C0C,0x842A,0x52E7,0x3A25,0x4246,0x6347,0x52E6,0x52E6,0x52C6,0x4AA6,0x6388,
0x7C08,0x6BE7,0x5327,0x3A87,0x638C,0x7C0C,0xA4CC,0x9CCC,0x94CC,0xA4EB,0xA4CC,0xA4CC,0xAD2D,0xAD2D,0x94AB,
0x9489,0x94AA,0x94CB,0xAD2D,0x9CCC,0x8C2B,0x6369,0x632A,0x738A,0x73AA,0x52E9,0x4286,0x3204,0x21A5,0x2165,
0x1104,0x1104,0x1944,0x1944,0x29A5,0x39E5,0x2184,0x1923,0x1923,0x2164,0x1903,0x1902,0x2143,0x2143,0x2964,
0x2163,0x1943,0x1923,0x2964,0x2184,0x81C5,0xFAA7,0xE1A4,0xB8C4,0x8843,0x7842,0x7822,0x7022,0x7001,0x8801,
0x8801,0x8843,0x8843,0x8843,0x8863,0x8884,0xA883,0x8801,0x98C2,0x9B06,0xA4AC,0x8A44,0xA943,0xFB4A,0xFBAD,
0xCA28,0xA8E4,0x9246,0xAD8C,0xA52B,0x9CE9,0x5B23,0x31C1,0x5B24,0x84A7,0x4283,0x08C1,0x08A1,0x0082,0x2964,
0x4245,0x6364,0x8426,0x7BC6,0x6B88,0x6BA5,0x6382,0x6BE1,0x8485,0x6345,0x8C8A,0x6348,0x3220,0x4AA1,0x6302,
0x6325,0x3983,0x2943,0x4167,0x49C5,0x4A05,0x4A62,0x3A20,0x2980,0x2160,0x29A1,0x2944,0x2966,0xC75F,0xC75F,
0xC77F,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,
0xD79F,0xD79F,0xD79F,0xD7BF,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xDFBF,0x8D96,0x63EE,0x29E6,0x2166,0x42AC,0x4ACC,
0x4289,0x6349,0x4AA6,0x3A25,0x3A26,0x3205,0x3205,0x31E5,0x31E4,0x29E5,0x52E8,0x8C8C,0x7C4E,0x73EE,0x6BCE,
0x5B4C,0x73AC,0x9CAD,0x9CEC,0x9CEB,0x9CCB,0xA4EC,0xB54D,0xAD2D,0x9CAB,0x9CCA,0x8C69,0x948A,0x94CA,0x9CCC,
0x7BC9,0x842A,0x73C8,0x5B25,0x7BE7,0x7BE9,0x52C7,0x42A6,0x29E5,0x1964,0x1123,0x1103,0x2144,0x1103,0x31C6,
0x3A08,0x2166,0x1944,0x1943,0x1923,0x1963,0x2965,0x1964,0x2144,0x1102,0x1943,0x2164,0x1944,0x1122,0x1943,
0x3185,0x3985,0xB9E6,0xFA66,0xFA04,0xB8A3,0x8043,0x8042,0x7822,0x7001,0x7001,0x8801,0x8842,0x8843,0x8863,
0x8863,0x8823,0x88C3,0xC42A,0xAD0B,0x82A4,0xD9A2,0xE0E3,0xE9A3,0xFB0A,0xFB6D,0xE2EB,0xB126,0x7A04,0x6BC6,
0x6305,0x52A3,0x5B24,0x5B45,0x4284,0x2163,0x08A1,0x10C2,0x08A2,0x0882,0x0882,0x4227,0x4A84,0x6306,0x5B04,
0x4282,0x52C3,0x4AE1,0x6BC0,0x6362,0x8468,0x5B06,0x29A2,0x6342,0x6AC1,0x49E2,0x62E5,0x5244,0x2923,0x4186,
0x4166,0x41A7,0x2962,0x2161,0x2161,0x2163,0x2125,0x2124,0x2144,0xC75F,0xC75F,0xC77F,0xC77F,0xC77F,0xCF7F,
0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,
0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xD79E,0x9596,0x21E6,0x21C8,0x532D,0x3227,0x2186,0x4AC7,0x3A66,0x29E5,
0x31E5,0x29A5,0x29A4,0x29C4,0x2184,0x1963,0x5B08,0x844C,0x5B4A,0x530A,0x4ACA,0x4ACB,0x5289,0x8C0C,0xA50C,
0xA50C,0x9CCB,0xACED,0xB52D,0xAD0C,0xA50B,0xA52B,0x8C68,0x948A,0xAD2C,0x9CCB,0x94AA,0xA4CC,0xA4CD,0x7C09,
0x946A,0x6B68,0x52C7,0x4267,0x29E5,0x2185,0x1123,0x1103,0x2986,0x2124,0x39E7,0x2185,0x1964,0x1143,0x1143,
0x1943,0x2144,0x2165,0x1923,0x1103,0x1943,0x1943,0x1944,0x1923,0x10E2,0x1923,0x31A5,0x1923,0x2902,0x8124,
0xC126,0xE925,0x9064,0x7843,0x7822,0x7002,0x6801,0x7801,0x8842,0x8842,0x8822,0x8882,0xB349,0xB56F,0x7C2A,
0x3121,0x6021,0xF123,0xA883,0xD964,0xD185,0xC1E8,0xA987,0x9905,0x5A44,0x4A84,0x2962,0x3A02,0x39E3,0x1902,
0x10C3,0x1102,0x10E2,0x10A2,0x10E2,0x2141,0x4242,0x3984,0x3163,0x5A64,0x6AC5,0x6325,0x5AE4,0x3A00,0x3A40,
0x3A21,0x6BA6,0x52E5,0x4AC3,0x8C65,0x5A24,0x5264,0x62A5,0x4A03,0x5A85,0x5207,0x2905,0x2145,0x2143,0x2163,
0x2163,0x1923,0x2103,0x2124,0x2947,0xC77F,0xC75F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xC77F,0xCF7F,0xCF7F,
0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD79F,0xD7BF,0xD7BF,0xD79F,0xD7BF,
0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,
0xE7BF,0xE7DF,0xA65A,0x5C30,0x53CF,0x4B4D,0x3ACB,0x3A89,0x29E6,0x3206,0x29E5,0x29C5,0x21A5,0x29A5,0x31C4,
0x29A4,0x29A4,0x6368,0x7408,0x5325,0x4B05,0x5246,0x4926,0x51C7,0x944C,0xAD0D,0xA50C,0xA52C,0xA50D,0xA4EC,
0x9CCB,0xA50C,0x9D0A,0x9D0A,0x94A9,0x94AA,0x9CCB,0x948A,0x948A,0x842A,0x7BC9,0x73A9,0x5B06,0x4286,0x31E5,
0x31E6,0x29C6,0x2165,0x1144,0x1965,0x2986,0x31E7,0x2164,0x1944,0x1943,0x1943,0x1964,0x2165,0x1924,0x2144,
0x2163,0x2184,0x2184,0x1944,0x1923,0x1122,0x2164,0x2964,0x1922,0x1102,0x08C1,0xA1A8,0xD106,0x9844,0x8044,
0x7823,0x7002,0x6802,0x7821,0x8022,0x8001,0xAA87,0xCDB2,0xA4EF,0x79C5,0x3842,0x1061,0x3862,0xA862,0x8842,
0xD9A5,0xD1C6,0xB9A6,0xA926,0x70C4,0x2142,0x2961,0x1922,0x1903,0x10C3,0x10C3,0x10A2,0x10C2,0x1924,0x1923,
0x1942,0x31A1,0x31C2,0x62C5,0x8387,0x7365,0x7305,0x8C08,0x73A6,0x4A62,0x4222,0x52E2,0x6382,0x73C4,0x6B45,
0x7BA6,0x6224,0x6284,0x6A44,0x5A64,0x4A66,0x31A6,0x1904,0x18E4,0x2103,0x1904,0x18E4,0x10A3,0x10C4,0x2105,
0x2927,0xC75F,0xC75F,0xC75F,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,
0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xDFBF,0xD77E,
0xD75D,0xC6DC,0x9512,0x848F,0x3246,0x1985,0x21A5,0x2185,0x21A5,0x2184,0x29A4,0x31C4,0x3A44,0x5306,0x6BC8,
0x5B66,0x52E5,0x5A66,0x4145,0x4165,0x8C2B,0x9CAC,0x9CCC,0xA50C,0x9CCC,0x9CCC,0xA4CC,0x948A,0x8C89,0x946A,
0x8C89,0x948A,0x9CCB,0x8467,0x948A,0x73C9,0x7389,0x7BC9,0x52E7,0x4266,0x4265,0x3A46,0x31C6,0x2165,0x1985,
0x1944,0x1925,0x1924,0x1124,0x1123,0x1103,0x1963,0x1963,0x1964,0x2164,0x2164,0x2144,0x1963,0x1923,0x1123,
0x1123,0x1102,0x2144,0x2964,0x1923,0x1922,0x4184,0xC968,0xA844,0x8864,0x8064,0x8023,0x7822,0x6801,0x7800,
0x9144,0xC48F,0xBD93,0x82EB,0x80C4,0x7843,0x4022,0x3041,0x4842,0x7822,0x6821,0xA0A3,0xC145,0xB946,0x9084,
0x48E2,0x2142,0x2982,0x2143,0x10A2,0x10C3,0x10E2,0x10A1,0x10A3,0x18E4,0x18E3,0x10A3,0x1924,0x2964,0x5AC5,
0x6B66,0x4A62,0x7BA7,0x83E7,0x73C4,0x6B63,0x62E4,0x6B84,0x7C23,0x6B64,0x6B65,0x4243,0x39E1,0x5205,0x6B05,
0x7347,0x2985,0x10E2,0x3A04,0x3986,0x31A5,0x3A65,0x5B27,0x6389,0x73CA,0x73CA,0x4A69,0xC75F,0xC75F,0xC75F,
0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,
0xD79F,0xD79F,0xD79F,0xD7BF,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xEFDF,0xDF5F,0xADF7,0x7C2A,0x6BC9,
0x3A65,0x08E4,0x10E4,0x1124,0x1965,0x21A4,0x3A65,0x52E5,0x5325,0x4B05,0x52E6,0x4AC6,0x51A6,0x5186,0x3964,
0x39E5,0x7BEA,0x9C8B,0x9CCC,0x9CEB,0x94AA,0x9CAC,0xAD0D,0xAD2C,0xA50B,0x9CEA,0x9CA9,0xA4EB,0x9CEB,0x8C69,
0x73C8,0x6B87,0x7389,0x6B68,0x4AE4,0x5AE7,0x6349,0x52C7,0x29C6,0x2185,0x2184,0x2185,0x1124,0x1103,0x1924,
0x1123,0x0903,0x1944,0x1963,0x2984,0x29A3,0x2184,0x2144,0x1123,0x1122,0x1142,0x08E2,0x10E2,0x1923,0x1924,
0x1943,0x2143,0xB249,0xC0C6,0xA023,0x9043,0x8043,0x8043,0x7802,0x7021,0xAB09,0xCE36,0x9BF1,0x70A5,0x8043,
0x8884,0x7043,0x5042,0x3841,0x4842,0x5822,0x5801,0x6001,0x7842,0x8064,0x5883,0x1902,0x1902,0x1901,0x1921,
0x1102,0x10E2,0x10E2,0x10C1,0x18C2,0x10A3,0x10C3,0x10C2,0x10E4,0x2125,0x4246,0x5AC5,0x2943,0x7B89,0x8C2B,
0x5B24,0x5B22,0x6B43,0x7BE9,0x6345,0x5AA3,0x4A82,0x4240,0x5B22,0x4A44,0x4A25,0x6B47,0x2984,0x1901,0x4A65,
0x6268,0x5246,0xA56C,0xBE91,0xC6B1,0xCEB3,0xC6B2,0xB5F1,0xC75F,0xC75F,0xC75F,0xC77F,0xC77F,0xC77F,0xC77F,
0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,
0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xE7BF,
0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xE7BF,0xCF3E,0xA5F7,0x84CE,0x6BA8,0x6389,0x2185,0x08E4,0x10E4,0x10C3,
0x1924,0x52C6,0x5326,0x5B26,0x4AC5,0x3A84,0x3224,0x49E5,0x4125,0x4145,0x3945,0x49E6,0x8409,0xA4CC,0xA50D,
0x9D0B,0x9D0B,0xA4EC,0xB54E,0x94CB,0x9CCB,0xAD2C,0xBD6E,0xA50D,0x8C6B,0x8C69,0x8428,0x946A,0x8C4A,0x6BA8,
0x5B27,0x5B28,0x5308,0x52E7,0x4287,0x29C6,0x1985,0x1964,0x2144,0x1103,0x1965,0x1944,0x0903,0x1924,0x1944,
0x31A7,0x29A6,0x2164,0x1944,0x1923,0x1963,0x1142,0x1122,0x1102,0x0903,0x1942,0x1122,0x3943,0xD1A9,0xA844,
0x9843,0x9043,0x8023,0x8023,0x7904,0x9C2D,0x9CD2,0x79A8,0x7843,0x8843,0x8863,0x8084,0x4082,0x4881,0x4861,
0x6063,0x6064,0x6021,0x6021,0x6822,0x6843,0x28E2,0x0901,0x10E1,0x10E2,0x10C1,0x1901,0x10E1,0x10C2,0x10C1,
0x18C1,0x18C3,0x2104,0x18E3,0x10C3,0x1904,0x3185,0x2943,0x4205,0x73A5,0x6364,0x6365,0x6343,0x4222,0x6385,
0x8C2B,0x6324,0x52E3,0x6364,0x6365,0x4224,0x39C3,0x39E4,0x2163,0x2160,0x5285,0x49C8,0x4206,0x62E9,0x84A9,
0x8CC9,0x8CAA,0x7C29,0x52E6,0xC75F,0xC75F,0xC77F,0xC77F,0xC75F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,
0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD79F,0xD79F,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,
0xE7BF,0xE7DF,0xD75E,0xC6FD,0x84D2,0x4B05,0x21E5,0x1124,0x10E4,0x1104,0x08C3,0x08E3,0x2A04,0x3A85,0x42A5,
0x2A04,0x3A64,0x4284,0x5205,0x3905,0x3905,0x4105,0x39A5,0x7BCA,0xACED,0xA50D,0xA56C,0x9D0B,0x94CA,0x9CEB,
0x8C69,0x8469,0xB56E,0xB52F,0xA4EC,0xA50C,0x9CAB,0x9489,0x7C08,0x5B26,0x5305,0x6368,0x5B27,0x5327,0x5308,
0x4AC7,0x29C5,0x1986,0x1944,0x1924,0x1924,0x2984,0x2164,0x1123,0x1964,0x29A6,0x29A7,0x3187,0x2145,0x1924,
0x1943,0x1103,0x1103,0x1103,0x1943,0x1122,0x1961,0x08E1,0x5944,0xD106,0xC0A4,0x9023,0x7063,0x8246,0x8B69,
0x4226,0x61A6,0x7884,0x8063,0x8063,0x8863,0x8883,0x8884,0x8842,0x8022,0x7802,0x7023,0x60A6,0x5823,0x6822,
0x7022,0x5083,0x1922,0x1121,0x1101,0x1122,0x1922,0x1901,0x10E0,0x08A0,0x08A1,0x08A2,0x1082,0x18E5,0x2125,
0x6368,0x39E5,0x28E3,0x18A2,0x39A3,0x8C69,0x8C6A,0x6306,0x5AE5,0x6343,0x63A4,0x94C9,0x73EA,0x3A02,0x5283,
0x8448,0x5AC7,0x6345,0x39C4,0x2984,0x29A3,0x6B07,0x622A,0x20C5,0x39A5,0x4A85,0x5305,0x3A23,0x2181,0x1921,
0xC75F,0xC75F,0xC75F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,
0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFDF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xE7BF,
0x8D31,0x4B05,0x1984,0x1104,0x10E4,0x1924,0x10E4,0x31E4,0x4265,0x21C4,0x3A44,0x4284,0x3224,0x4265,0x5A86,
0x4125,0x30C4,0x20C4,0x18C3,0x62E8,0xACED,0x94CB,0x9D0B,0x94CA,0x9CCB,0xAD0C,0x94AB,0x9CCB,0xB54E,0xAD2D,
0xB52E,0xA4EC,0x8429,0x7C08,0x8428,0x6B86,0x6B86,0x6368,0x6328,0x4AA6,0x5287,0x3225,0x21A5,0x2185,0x1104,
0x10E3,0x1924,0x2165,0x1924,0x1944,0x2166,0x29C7,0x29C6,0x2185,0x2165,0x1924,0x1123,0x1903,0x1122,0x1963,
0x1962,0x1942,0x2161,0x1961,0x6123,0xC084,0xA844,0xAA46,0xBD2F,0x83CB,0x3143,0x3883,0x7023,0x8042,0x8063,
0x8063,0x8063,0x8884,0x8843,0x8802,0x8002,0x8002,0x7002,0x6085,0x6064,0x6822,0x6843,0x2922,0x1962,0x2161,
0x1982,0x2181,0x1961,0x1101,0x08C1,0x08C1,0x0881,0x0862,0x0882,0x0882,0x10C4,0x31C7,0x4A88,0x62C6,0x4A04,
0x5AC4,0x8C87,0x9C8A,0x7366,0x6B04,0x6B82,0xA569,0xA54A,0xA54F,0x4A84,0x3A01,0x6BA4,0x73C8,0x7C08,0x6345,
0x41C5,0x2164,0x39C5,0x5A4B,0x28E6,0x20E5,0x1903,0x1101,0x10E0,0x10E0,0x1102,0xC75F,0xC75F,0xC75F,0xC75F,
0xC77F,0xC77F,0xCF7F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,
0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xEFDF,0xCF1C,0x4309,0x1965,0x1104,
0x1104,0x1924,0x08E3,0x1104,0x29A4,0x2A04,0x21A4,0x5306,0x6385,0x52E4,0x5B06,0x41E4,0x20E3,0x10A3,0x10C2,
0x6B68,0xAD0C,0x948B,0x8C8A,0xA4EB,0x9CCC,0x948B,0xA4EC,0xA4CD,0x9C8B,0xAD0D,0xAD4D,0x9CAB,0x8C69,0x8C49,
0x8C49,0x7C08,0x73C7,0x52C6,0x3A27,0x3205,0x3A04,0x29C4,0x2985,0x29A5,0x1964,0x08E3,0x1104,0x10E3,0x1123,
0x2185,0x2185,0x21A6,0x21A5,0x2184,0x1963,0x2163,0x2163,0x1123,0x1923,0x2143,0x1942,0x1942,0x1962,0x1921,
0x80C3,0xC309,0xB4AD,0x940C,0x9288,0x7146,0x3843,0x5864,0x7844,0x8043,0x8063,0x8064,0x8063,0x90C4,0xA8A3,
0x9802,0x9822,0x9042,0x6002,0x6043,0x6064,0x6022,0x48A2,0x1941,0x10E1,0x1101,0x1122,0x1941,0x1121,0x1941,
0x1941,0x0902,0x1921,0x0880,0x2142,0x39E3,0x3184,0x3164,0x39A4,0x83A8,0x8C47,0x8405,0x6B24,0x6344,0x7C26,
0x3A01,0x3221,0x8C8B,0x5B24,0x73C9,0x6BA6,0x6BA5,0x73E5,0x5B42,0x52E3,0x5AE4,0x4A62,0x41E4,0x31A4,0x39C7,
0x20C5,0x18E4,0x18E3,0x10E1,0x1101,0x1942,0x2143,0xC75F,0xC75F,0xC75F,0xC75F,0xC77F,0xC77F,0xC77F,0xC77F,
0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD7BF,0xD79F,0xD79F,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,
0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xA619,0x21E8,0x1145,0x1104,0x10E4,0x1104,0x10E3,0x21A3,
0x3A64,0x3A84,0x3A65,0x52E5,0x5B45,0x5325,0x5B45,0x5AE4,0x4243,0x1902,0x1924,0x7BCA,0xA4CC,0x9CAB,0x8C6A,
0x8C8B,0x8C8B,0x840A,0xB54F,0xAD0F,0xA4ED,0xACEE,0xAD2D,0xA50C,0x8449,0x6386,0x8C49,0x8409,0x7BE8,0x52E6,
0x3205,0x4AA6,0x3A25,0x21C4,0x21A4,0x1925,0x1104,0x10E3,0x10E3,0x1103,0x1943,0x29A6,0x21A6,0x2184,0x2184,
0x1963,0x10E2,0x1104,0x1924,0x1103,0x1122,0x1923,0x1963,0x1942,0x1941,0x7328,0xC4CD,0xACED,0x8A66,0x9063,
0xB126,0x7906,0x3822,0x68A4,0x8064,0x8044,0x8063,0x8063,0x8064,0x60E3,0xD184,0xC042,0xB862,0x9883,0x6022,
0x6842,0x6044,0x6064,0x2902,0x1101,0x10E1,0x10E1,0x1922,0x1942,0x1901,0x1141,0x2182,0x2161,0x52C2,0x52A3,
0x39E3,0x39C4,0x3183,0x3184,0x2144,0x5A64,0x6B04,0x8C08,0x5AE6,0x4280,0x8C69,0x73A8,0x52E2,0x6344,0x6385,
0x5B25,0x7C08,0x94CA,0x94AB,0x5B04,0x6B84,0x6323,0x7364,0x62C3,0x4A23,0x4205,0x20E5,0x18C4,0x18C3,0x1923,
0x1943,0x2142,0x2181,0xC75F,0xC75F,0xC77F,0xC75F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,
0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,
0xE7BF,0xE7BF,0xE7BF,0xD77E,0x8D54,0x2A68,0x1965,0x1104,0x1104,0x1944,0x4AC5,0x5305,0x6386,0x7406,0x7406,
0x5B25,0x4AE5,0x5B45,0x6BA6,0x6BC4,0x4AC3,0x1943,0x4A67,0x846A,0x9CCB,0x8C8A,0x7C49,0x8C6A,0x9CCC,0xAD4E,
0xAD6E,0xB56E,0xB54D,0xAD0C,0x9CEB,0x7C28,0x8448,0x948B,0x8429,0x6BC7,0x2A05,0x3A66,0x42C7,0x29E5,0x29E5,
0x29C5,0x1144,0x1124,0x1945,0x10E3,0x1104,0x1123,0x1945,0x21A7,0x19A5,0x1144,0x1103,0x1103,0x1944,0x1944,
0x1143,0x1122,0x1102,0x29A2,0x6367,0x9CEB,0xBD90,0xA38C,0x98A2,0xB844,0xB064,0xC987,0x9865,0x7823,0x80A5,
0x8064,0x8064,0x8064,0x8084,0x50C3,0x08C2,0x8164,0xE0C3,0xC0A3,0x8862,0x7042,0x7063,0x6022,0x5844,0x3903,
0x1101,0x10C1,0x10E2,0x3182,0x3A02,0x31E3,0x4243,0x2962,0x4263,0x4A64,0x2122,0x29A3,0x3183,0x52C6,0x5246,
0x5265,0x7346,0x7304,0x8BC8,0x83EB,0x5B04,0x5B05,0x73A7,0x6322,0x6BA3,0x7BE7,0x8C07,0x6B45,0x52C4,0x7387,
0x5263,0x6346,0x842A,0x4A44,0x5A84,0x39A4,0x3163,0x2945,0x18E4,0x18E3,0x1922,0x1922,0x1901,0x10E2,0xBF5F,
0xC75F,0xC77F,0xC77F,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,
0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7DF,
0xEFFF,0xA5F7,0x4AE8,0x21A5,0x08E4,0x1924,0x3A26,0x4AC6,0x6BA7,0x5B46,0x6B87,0x52C5,0x5B26,0x73E8,0x8467,
0x73E7,0x6BA7,0x4264,0x4A85,0x846A,0xAD2D,0xA50B,0x8C69,0x8C8A,0xAD2D,0xB52D,0xAD4D,0xB54E,0xBD90,0xAD2D,
0x948A,0x94AA,0x8C69,0x73E8,0x73E6,0x5B45,0x1963,0x21C5,0x31E5,0x1964,0x3204,0x21A4,0x1124,0x08C3,0x1923,
0x1944,0x1924,0x2984,0x1923,0x1925,0x2125,0x2143,0x1963,0x2184,0x2184,0x1962,0x29C2,0x4AC4,0x6B87,0xAD4C,
0xA54D,0x5307,0x78C2,0xB884,0xB8A5,0xB884,0xC0C4,0xD166,0x9823,0x9844,0x88C6,0x8084,0x8084,0x8064,0x60E3,
0x2123,0x10E2,0x2102,0xB904,0xC083,0x9042,0x6083,0x38A3,0x6042,0x6023,0x48C3,0x1101,0x1922,0x2123,0x39E3,
0x2983,0x10A2,0x2963,0x2942,0x3182,0x4203,0x2122,0x10E2,0x2983,0x6326,0x6B08,0x83A8,0x62C6,0x52A2,0x6B44,
0x83C7,0x6304,0x4A22,0x5262,0x7B86,0x8C28,0x7366,0x8428,0x94AA,0x4AA5,0x4243,0x5AC5,0x4A64,0x4A45,0x31A2,
0x2961,0x3184,0x20E3,0x1902,0x2123,0x1901,0x1900,0x10C2,0x08A2,0x08A2,0xC75F,0xC75F,0xC77F,0xC75F,0xC77F,
0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,
0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xE7BF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xEFDF,0xDF7E,0x7C8E,0x3226,
0x1104,0x08E3,0x10E4,0x3A04,0x4AC5,0x5B66,0x6346,0x5B06,0x6347,0x6BA7,0x6365,0x5B45,0x52E5,0x4265,0x6B48,
0x948C,0x8C6B,0x9CCC,0x9CEA,0x9CCA,0xB52E,0xB56D,0xB56E,0xB54E,0xAD4E,0xA50B,0xAD2C,0x8429,0x6BA8,0x6B87,
0x6306,0x5AC7,0x29A5,0x2184,0x3224,0x2185,0x3A65,0x21C4,0x0923,0x1103,0x1903,0x2143,0x3185,0x1903,0x1103,
0x1903,0x2124,0x2143,0x2122,0x3A04,0x3A05,0x6B88,0xA56A,0xAD8E,0x7BE8,0x4A85,0x2162,0x1902,0x90C4,0xB8A4,
0xB8A4,0xB864,0xE1A5,0xE9C6,0xB063,0x9843,0x88A6,0x8084,0x8064,0x60A4,0x1902,0x10E1,0x10E1,0x08E1,0x48C3,
0xB084,0x7082,0x18E2,0x2102,0x6042,0x6022,0x48C3,0x1941,0x1922,0x10E1,0x10A1,0x1082,0x0081,0x1902,0x2163,
0x1901,0x1101,0x4AA4,0x1942,0x1902,0x2982,0x2122,0x3184,0x3162,0x4243,0x7345,0x93E8,0x8C49,0x83E9,0x6286,
0x7B87,0x6B26,0x4203,0x4222,0x6367,0x4AC3,0x3202,0x3201,0x31E2,0x5B05,0x39E3,0x2961,0x2962,0x1901,0x1901,
0x2142,0x2942,0x18C2,0x10C2,0x10E1,0x1922,0xC75F,0xC75F,0xC75F,0xC75F,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,
0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,
0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xEFFF,0xB636,0x5308,0x3246,0x29A5,0x29C5,0x73A7,
0x6367,0x6387,0x5B45,0x4AC4,0x6386,0x5B45,0x4AA4,0x52C4,0x4264,0x3203,0x52E6,0x844B,0x9CCB,0x9CEB,0x94E9,
0xA54B,0xAD0C,0xBDAF,0xBD8F,0xB56F,0xB56E,0xB56E,0x94AB,0x6BC6,0x6345,0x7BA8,0x5AE5,0x3203,0x1163,0x1144,
0x52C6,0x3A45,0x29A5,0x2A05,0x21A4,0x2163,0x1103,0x1103,0x1923,0x1103,0x1103,0x1923,0x2103,0x5285,0x948A,
0xB58F,0x8C89,0x73C8,0x62E6,0x2983,0x2124,0x2104,0x2144,0x1922,0x88C4,0xB8C5,0xB8A4,0xB883,0xD945,0xE985,
0xC8A3,0x9822,0x88A5,0x8885,0x7843,0x30A2,0x10E2,0x08C1,0x10C2,0x08A2,0x10C1,0x40C3,0x18E2,0x08E1,0x28A1,
0x6043,0x5842,0x40C4,0x1102,0x10E1,0x08C0,0x0860,0x0881,0x08C1,0x1102,0x08A1,0x10E1,0x29A2,0x31A5,0x39E5,
0x4A87,0x1903,0x1921,0x2121,0x2142,0x8429,0x6B08,0x5245,0x83C8,0x5246,0x31E2,0x52E3,0x6B66,0x4224,0x2162,
0x3201,0x4AC1,0x5304,0x63A6,0x29A2,0x4AA3,0x31C3,0x1921,0x2181,0x2162,0x18C2,0x31C3,0x2142,0x10A1,0x10E2,
0x2143,0x1903,0xBF5F,0xC75F,0xC75F,0xC75F,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,
0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,
0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xEFDF,0xC698,0x7C2C,0x4AE9,0x3226,0x29A5,0x21A5,0x29A4,0x5B25,0x5B45,0x5324,
0x5325,0x52E4,0x52E5,0x3A43,0x3A44,0x4283,0x52E6,0x7C0A,0xA4ED,0xAD2C,0x9CE9,0x9CEA,0xA50C,0xBD8F,0xBD6F,
0xB56E,0xAD2D,0x9D0C,0x73E6,0x73E8,0x7BE8,0x7B89,0x7BA9,0x6B67,0x6B67,0x3A44,0x21A4,0x52C5,0x3A45,0x3205,
0x5287,0x4A46,0x1944,0x10E3,0x1903,0x31A4,0x5B07,0x8C6B,0x9CEE,0x9CEA,0x7C09,0x4225,0x2143,0x18E2,0x2103,
0x1903,0x1944,0x2965,0x10E3,0x08C1,0x70A3,0xC0A5,0xB884,0xB864,0xE9A3,0xF9A3,0xD0C2,0x9022,0x9085,0x7843,
0x7042,0x20C1,0x08E1,0x1121,0x1901,0x10A1,0x10E0,0x1100,0x08C1,0x08E1,0x30A2,0x6043,0x6042,0x3883,0x08E1,
0x1901,0x10C0,0x0880,0x08A1,0x10A2,0x2183,0x5AC6,0x5AA7,0x3184,0x10A3,0x08E2,0x21A3,0x10E1,0x10C1,0x2141,
0x31A1,0x7B69,0x5AC6,0x5AE3,0xB56A,0x7368,0x3221,0x31E2,0x6B26,0x4A64,0x52E2,0x52A3,0x29A2,0x3A42,0x7409,
0x31C4,0x2121,0x2141,0x29A1,0x5284,0x2963,0x3162,0x2942,0x2122,0x10E2,0x1903,0x2143,0x18E3,0xC75F,0xC75F,
0xC75F,0xC75F,0xC77F,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,
0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,
0xEFDF,0xC699,0x63AC,0x3A67,0x4286,0x1984,0x3205,0x5B25,0x6BA6,0x6366,0x6386,0x52E5,0x52E6,0x6346,0x4263,
0x3203,0x3A43,0x52C6,0x73E9,0x948C,0xAD2C,0x9509,0xA54A,0xBD8E,0xBD6E,0xB54D,0xA4EC,0x9CCA,0x94AA,0x6BA7,
0x5B86,0x73E8,0x6326,0x6306,0x5AE5,0x5B06,0x73A8,0x4265,0x31E6,0x2145,0x2145,0x2966,0x1905,0x31A4,0x6B68,
0x9CEB,0xA50B,0x9CE9,0x7C08,0x5AC7,0x31C3,0x1924,0x18E4,0x10E4,0x10C3,0x10C3,0x18E3,0x1944,0x18E3,0x10C3,
0x0082,0x48A3,0xB0A5,0xA864,0xD9A4,0xFA83,0xF1A2,0xA862,0xA063,0x9885,0x8022,0x5882,0x18E2,0x1101,0x1101,
0x08A1,0x2141,0x39E2,0x2162,0x10E1,0x08C1,0x1882,0x5864,0x6043,0x2882,0x1101,0x1121,0x1101,0x10A1,0x10A1,
0x2103,0x2964,0x3A26,0x31C4,0x10C2,0x10E1,0x10E2,0x08C2,0x0081,0x39C3,0x6304,0x3A00,0x6B45,0x6B25,0x6366,
0x6B86,0x6B47,0x62E6,0x2142,0x4222,0x7366,0x5AC5,0x3A03,0x31A2,0x2161,0x1920,0x2162,0x3A43,0x31C2,0x31A1,
0x41E3,0x41E4,0x31A4,0x2123,0x1922,0x10E1,0x10E2,0x18C2,0x2103,0xC75F,0xC75F,0xC75F,0xC75F,0xC75F,0xC77F,
0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,
0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,
0xDFBF,0xE7BF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xEFDF,0xB658,0x6BED,0x5B6B,
0x638A,0x5B49,0x6BA7,0x7406,0x6365,0x3A84,0x4285,0x4AA4,0x3A44,0x4AA5,0x52E5,0x3203,0x52C4,0x6347,0x7C29,
0x94AB,0xA50C,0xA52A,0xAD4C,0xB56D,0xAD2D,0xAD0C,0xA50C,0x9CEB,0x948B,0x6BE7,0x5384,0x5344,0x5305,0x6326,
0x6326,0x5B25,0x6B87,0x4246,0x2125,0x2965,0x2125,0x2144,0x7BCC,0xC5D2,0xB56F,0x73A7,0x4224,0x2984,0x2985,
0x2965,0x2125,0x2126,0x1925,0x1905,0x1905,0x10E4,0x10E4,0x10E4,0x10C2,0x0882,0x0061,0x38A2,0xA064,0xC124,
0xFAE4,0xE204,0xA8A4,0x9863,0xA084,0x9885,0x8885,0x38C3,0x10E2,0x10E1,0x08A1,0x1902,0x39C4,0x1903,0x08A2,
0x08A2,0x10C2,0x0881,0x2082,0x3883,0x1081,0x10E1,0x1121,0x1122,0x1901,0x10E1,0x10A2,0x0862,0x08C2,0x1941,
0x2162,0x4243,0x29A0,0x10E1,0x10C1,0x39E3,0x7B87,0x6B65,0x6B83,0x6322,0x4A83,0x5AA5,0x7367,0x840A,0x31C3,
0x3A01,0x52A5,0x3A03,0x4241,0x4222,0x3A02,0x29C2,0x4243,0x3A04,0x2162,0x2962,0x2962,0x41C3,0x31A3,0x2942,
0x2122,0x18E2,0x10C2,0x10A2,0x10A2,0xC75F,0xBF5F,0xC75F,0xC75F,0xC75F,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,
0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,
0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,
0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xEFDF,0xAE18,0x6BEF,0x6BCD,0x5B4A,0x4AE9,0x73E7,0x6BC6,
0x5B45,0x5305,0x3223,0x3203,0x29E3,0x2A03,0x3203,0x3A23,0x3A22,0x4AA5,0x7428,0x948B,0xAD2C,0xA52B,0x9CEB,
0xAD4D,0xB54D,0xAD4C,0xA50B,0x94AB,0x842B,0x6BE8,0x5B66,0x4AE4,0x4284,0x4264,0x4A85,0x5B27,0x5B27,0x2965,
0x3186,0x29A6,0x2965,0x4A46,0x9C8F,0x5AAA,0x2965,0x1905,0x2145,0x2946,0x2145,0x2145,0x2966,0x2146,0x2125,
0x2145,0x1944,0x1923,0x1924,0x10C3,0x10C3,0x10E2,0x1122,0x3943,0xC1A6,0xFAC6,0xD244,0x4903,0x5904,0x80A4,
0x9885,0x9885,0x90A6,0x48A3,0x08C1,0x10A1,0x10A2,0x10A2,0x1083,0x18A2,0x10A1,0x08A1,0x10A2,0x10C2,0x10A1,
0x10C1,0x08E1,0x10C1,0x2162,0x2161,0x18E2,0x10E2,0x10A1,0x0841,0x0882,0x1942,0x2161,0x3201,0x6BE4,0x29A1,
0x2141,0x2961,0x18E1,0x6305,0x7BE5,0x9C8A,0x62E6,0x7B86,0x8C28,0x8429,0x52A5,0x29A1,0x3A21,0x4222,0x3A21,
0x6BC3,0x6305,0x4223,0x39C3,0x2942,0x1942,0x29C1,0x2141,0x2121,0x41C3,0x20E2,0x18C2,0x18E2,0x08A2,0x08C3,
0x10A3,0xC75F,0xC75F,0xC75F,0xC75F,0xC75F,0xC77F,0xC77F,0xC77F,0xC77F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,0xCF7F,
0xCF7F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xCF9F,0xD79F,0xD79F,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,0xD7BF,
0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xDFBF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,0xE7BF,
0xE7BF,0xE7BF,0xE7BF,0xE7DF,0xADF7,0x3AAA,0x3249,0x29E6,0x1985,0x5307,0x5B45,0x5B25,0x5B45,0x3A44,0x4284,
0x4AC3,0x3223,0x4263,0x52C4,0x6345,0x52A6,0x7C29,0x9CCB,0xAD2C,0xAD4B,0xAD4C,0xAD4C,0xB56E,0x9D0B,0x94CA,
0x9CEA,0x94AA,0x7426,0x63C5,0x5B85,0x4AE4,0x5B46,0x6367,0x52E4,0x31E5,0x2145,0x2966,0x2966,0x39A5,0x3184,
0x2145,0x2926,0x2146,0x2105,0x2145,0x1925,0x2125,0x2965,0x2145,0x1905,0x1905,0x1924,0x1904,0x1924,0x2144,
0x1923,0x1923,0x1942,0x1923,0x4184,0xEBCE,0x9167,0x20E2,0x1902,0x1923,0x1904,0x30A3,0x30C3,0x78C5,0x8885,
0x20A3,0x0881,0x08A2,0x10A2,0x18C2,0x18C2,0x10C2,0x08C2,0x10A1,0x10A2,0x1922,0x1102,0x1941,0x1941,0x1941,
0x1921,0x10E1,0x10A1,0x10A1,0x0861,0x10E1,0x3222,0x1942,0x2181,0x5B02,0x3201,0x29A0,0x2981,0x2121,0x2122,
0x5B03,0x8CA7,0xA529,0x94C9,0x7BE6,0x6B43,0x7364,0x6324,0x6B65,0x5244,0x39E3,0x6345,0x4A64,0x4283,0x29A0,
0x3202,0x31C2,0x3A21,0x2141,0x1901,0x4223,0x2141,0x0880,0x1901,0x10E2,0x08C2,0x10E3,
};

	
	for(uint16_t i=0; i<11616; i++) {
		
		pix = pgm_read_word(&Bitmap[i]);
		//pix = 0x07E0;
		glcdSetPixel(x, y++,pix );
		if(y == 176) {
			y=0;
			x++;
		}
    
	}
	
	for(uint16_t i=0; i<11616; i++) {
		
		pix = pgm_read_word(&Bitmap2[i]);
		//pix = 0x07E0;
		glcdSetPixel(x, y++,pix );
		if(y == 176) {
			y=0;
			x++;
		}


	}
}

void testBitmaps_4(void) {
	uint8_t x=0, y=175;
	glcdColor_t pix;
	
	for(uint16_t i=0; i<23232; i++) {
		pix = 0x07E0;
		glcdSetPixel(x, y--, pix);
		if(y == 255) {
			y=175;
			x++;
		}
	}
}


void glcdRandomClipRect(void) {

    while (1) {
      glcdSetRect(glcd_Clip, lfsr(7) +3, lfsr(7) +3, lfsr(7)+3, lfsr(7)+lfsr(5)+lfsr(4));
      if ((glcd_Clip.X1 < glcd_Clip.X2) & (glcd_Clip.Y1 < glcd_Clip.Y2)) {break;}
    }
}

int main(void) {
#define cnt  1

#ifndef USE_AUTOINIT
    glcdDisplayInit();
#endif
  
//    glcdClearScreen(BLACK);
//    glcdDisplayOn();
	
	//ClearScreen
	glcdFillRect(0, 0, 131, 175, BLUE);
	
    uint8_t o = 0;

    //demoScreen_2();
	//demoScreen_2();
	
	testBitmaps_3();
/*	
	//TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTtt
    #define TOP 90
    #define GRID 2
	glcdSetColors(BLACK, NONE);
  
    glcdLine(30, TOP, SCREEN_WIDTH-30, TOP);
    glcdLine(30, TOP+1*GRID, SCREEN_WIDTH-30, TOP+1*GRID);
    glcdLine(30, TOP+2*GRID, SCREEN_WIDTH-30, TOP+2*GRID);
    glcdLine(30, TOP+3*GRID, SCREEN_WIDTH-30, TOP+3*GRID);
    glcdLine(30, TOP+4*GRID, SCREEN_WIDTH-30, TOP+4*GRID);
	//TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTtt
*/	
	

    while (1) {

//      glcdSetOrientation(o++);         // next orientation
//     glcdClearScreen(1);              // clear screen, ignore clipping


/*

// some tests with known parameters to check if lib is correct working
     glcdRectangle(10,100,20,140);
     
     glcdLine(0, 0, 40, 20);

     glcdLine(80, 80, 40, 40);
     glcdLine(82, 82, 120, 40);
     glcdLine(84, 84, 40, 120);
     glcdLine(86, 86, 120, 120);


//      glcdRandomClipRect();


      glcd_Flags.Clipping = 0;         // deactivate clipping
      glcdSetColor(0, BLACK);
      glcdSetColor(2, BLACK);
      glcdSetColor(3, NONE);
      glcdFrame(glcd_Clip.X1 -2, glcd_Clip.Y1 -2, glcd_Clip.X2 +2, glcd_Clip.Y2 +2);


      glcd_Flags.Clipping = 1;         // activate clipping

      testRects(cnt);
      testLines2(cnt);
      testLines(cnt);
      testEllipses(cnt);
      testEllipses2(cnt);

      testSymbols(cnt);
      testBitmaps();

      testOrientation();

      glcdRandomClipRect();
*/
    }
}

